package org.rcisoft.business.excelimport.importMethod;

import lombok.extern.slf4j.Slf4j;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.rcisoft.business.excelimport.common.BaseTitleHead;
import org.rcisoft.business.excelimport.tbexceljzmessageimport.dao.TbExcelJzMessageImportRepository;
import org.rcisoft.business.excelimport.tbexceljzmessageimport.entity.TbExcelJzMessageImport;
import org.rcisoft.business.jzmessage.dao.JzMessageRepository;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.sdictionary.entity.SDictionary;
import org.rcisoft.business.sdictionary.service.SDictionaryService;
import org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl;
import org.rcisoft.business.suser.dao.SUserRepository;
import org.rcisoft.business.suser.entity.SUser;
import org.rcisoft.common.ResultServiceExceptionEnums;
import org.rcisoft.core.component.CyApplicationContextHolder;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.*;
import java.util.regex.Pattern;

@Slf4j
public class PoiMethod {

    private SDictionaryService sDictionaryServiceImpl = CyApplicationContextHolder.getBean(SDictionaryService.class);

    private SUserRepository sUserRepository = CyApplicationContextHolder.getBean(SUserRepository.class);

    private JzMessageRepository jzMessageRepository = CyApplicationContextHolder.getBean(JzMessageRepository.class);

    private TbExcelJzMessageImportRepository tbExcelJzMessageImportRepository = CyApplicationContextHolder
            .getBean(TbExcelJzMessageImportRepository.class);

    //表头
    //表头的汉字，用的excelimport包下的common包的枚举类，若excel表头的位置发生改变，此处需要变化--------------------------------------------------------------------------------------------------------------
    private static String[][] tableHead = {
            {BaseTitleHead.TABLE_HEAD_JZ_CODE.getStatus(), BaseTitleHead.TABLE_HEAD_JZ_NAME.getStatus(),
                    BaseTitleHead.TABLE_HEAD_OPERATOR.getStatus(), BaseTitleHead.TABLE_HEAD_JZ_EVM.getStatus(),
                    BaseTitleHead.TABLE_HEAD_PROJECT_ID.getStatus(), BaseTitleHead.TABLE_HEAD_TASK_LINE.getStatus(),
                    BaseTitleHead.TABLE_HEAD_QY.getStatus(), BaseTitleHead.TABLE_HEAD_PROJECT_STATUS.getStatus(),
                    BaseTitleHead.TABLE_HEAD_CURRENT_MAN.getStatus(), BaseTitleHead.TABLE_HEAD_PROJECT_MAN.getStatus(),
                    BaseTitleHead.TABLE_HEAD_CREATE_DATE.getStatus()},// 代缴
            {BaseTitleHead.TABLE_HEAD_UP_USER.getStatus(), BaseTitleHead.TABLE_HEAD_OPERATOR.getStatus(),
                    BaseTitleHead.TABLE_HEAD_DEMAN_ID.getStatus(), BaseTitleHead.TABLE_HEAD_BUILD_WAY.getStatus(),
                    BaseTitleHead.TABLE_HEAD_JZ_NAME.getStatus(), BaseTitleHead.TABLE_HEAD_QY.getStatus(),
                    BaseTitleHead.TABLE_HEAD_MOBILE_RELATION.getStatus(), BaseTitleHead.TABLE_HEAD_MOBILE_CONTACT.getStatus(),
                    BaseTitleHead.TABLE_HEAD_LONGITUDE.getStatus(), BaseTitleHead.TABLE_HEAD_DIMENSION.getStatus(),
                    BaseTitleHead.TABLE_HEAD_CURRENT_MAN.getStatus(), BaseTitleHead.TABLE_HEAD_PROJECT_MAN.getStatus(),
                    BaseTitleHead.TABLE_HEAD_CREATE_DATE.getStatus()},//移动
            {BaseTitleHead.TABLE_HEAD_UP_USER.getStatus(), BaseTitleHead.TABLE_HEAD_OPERATOR.getStatus(),
                    BaseTitleHead.TABLE_HEAD_DEMAN_ID.getStatus(), BaseTitleHead.TABLE_HEAD_BUILD_WAY.getStatus(),
                    BaseTitleHead.TABLE_HEAD_JZ_NAME.getStatus(), BaseTitleHead.TABLE_HEAD_QY.getStatus(),
                    BaseTitleHead.TABLE_HEAD_LONGITUDE.getStatus(), BaseTitleHead.TABLE_HEAD_DIMENSION.getStatus(),
                    BaseTitleHead.TABLE_HEAD_CURRENT_MAN.getStatus(), BaseTitleHead.TABLE_HEAD_PROJECT_MAN.getStatus(),
                    BaseTitleHead.TABLE_HEAD_CREATE_DATE.getStatus()}//铁塔
    };

    //--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
    //与tableHead的字段对应，为JzMessage的实体类的名称，若jzMessage的实体类名有变化，此处需要变-------------------------------------------------------------------------------------------------
    private static String[][] excelTableHead = {
            {"jzCode", "jzName", "jzYys", "jzEwm", "projectCode", "businessLine", "jzQy", "projectAddress", "jzCurUser", "jzProjectOwner",
                    "jzCreateDate"},
            {"jzUpCustom", "jzYys", "jzRequire", "jzConstruct", "jzName", "jzQy", "jzMobileRelation", "jzMobilePhone", "jzLongitude", "jzLatitude",
                    "jzCurUser", "jzProjectOwner", "jzCreateDate"},
            {"jzUpCustom", "jzYys", "jzRequire", "jzConstruct", "jzName", "jzQy", "jzLongitude", "jzLatitude", "jzCurUser", "jzProjectOwner",
                    "jzCreateDate"}
    };

    //----------------------------------------------------------------------------------------------------------------------------------------------------------------------
    //需要添加的错误数据和正确数据
    public List<TbExcelJzMessageImport> errorData;

    public List<TbExcelJzMessageImport> correctData;
    //错误的位置 （!!!不算上表头取得的位置，下标从0开始 即第2行第2列为(1, 1) ）
    //public List<Pair<Integer, Integer>> errorPos; //已经不用此数据

    //加载数据字典和数据库的固定数据-----------------------------------
    public HashMap<NewPair<String, String>, String> dataMap;

    public List<String> haveProjectCode;

    public HashMap<String, String> userMap;

    public HashMap<String, String> deptMap;

    public String deptId;

    //-------------------------------------------------------------
    //无参构造 初始化数据
    public PoiMethod() {
        errorData = new ArrayList();
        correctData = new ArrayList();
        haveProjectCode = new ArrayList<>();
        //errorPos = new ArrayList<>();
        dataMap = new HashMap<NewPair<String, String>, String>();
        //获取数据字典的数据
        List<SDictionary> sDictionaries = sDictionaryServiceImpl.findAll(new SDictionary());
        for (SDictionary sd : sDictionaries) {
            NewPair<String, String> keyP = new NewPair(sd.getType(), sd.getName());
            if (dataMap.get(keyP) == null) {
                dataMap.put(keyP, sd.getValue());
            } else {
                dataMap.put(keyP, "error");
            }
        }
        //获取数据库中当前登录人所在部门的人员信息

        List<SUser> userInfo = sUserRepository.queryAllUserInfoByDept(CyUserUtil.getAuthenDept());
        for (SUser u : userInfo) {
            NewPair<String, String> keyP = new NewPair(u.getDeptId(), u.getName());
            if (dataMap.get(keyP) == null) {
                dataMap.put(keyP, u.getBusinessId());
            } else {
                dataMap.put(keyP, "error");
            }
        }

        List<SUser> sUserList = sUserRepository.selectAll();
        userMap = new HashMap<>();
        deptMap = new HashMap<>();
        for (SUser sUser : sUserList) {
            if (userMap.get(sUser.getName()) == null || deptMap.get(sUser.getName()) == null) {
                userMap.put(sUser.getName(), sUser.getBusinessId());
                deptMap.put(sUser.getName(), sUser.getDeptId());
            } else {
                userMap.put(sUser.getName(), "error");
                deptMap.put(sUser.getName(), "error");
            }
            /*if(deptMap.get(sUser.getName()) == null){
                deptMap.put(sUser.getName(),sUser.getDeptId());
            } else {
                deptMap.put(sUser.getName(), "error");
            }*/
        }
    }

    //判断是否能将字符串转换成Bigdecimal
    public boolean isBigDecimal(String str) {
        if (str == null || str.trim().length() == 0) {
            return false;
        }
        char[] chars = str.toCharArray();
        int sz = chars.length;
        int i = (chars[0] == '-') ? 1 : 0;
        if (i == sz)
            return false;

        if (chars[i] == '.')
            return false;//除了负号，第一位不能为'小数点'

        boolean radixPoint = false;
        for (; i < sz; i++) {
            if (chars[i] == '.') {
                if (radixPoint)
                    return false;
                radixPoint = true;
            } else if (!(chars[i] >= '0' && chars[i] <= '9')) {
                return false;
            }
        }
        return true;
    }

    /*获取所有包含移动的value*/
    public List<String> getYDValue(String type) {
        String YD = "移动";
        List<String> listValue = new ArrayList<>();
        if (type.equals("代缴")) {
            for (Map.Entry<String, String> map : SDictionaryServiceImpl.jzDjYys.entrySet()) {
                if (map.getKey().contains(YD)) {
                    listValue.add(map.getValue());
                }
            }
        } else if (type.equals("铁塔")) {
            for (Map.Entry<String, String> map : SDictionaryServiceImpl.jzTtYys.entrySet()) {
                if (map.getKey().contains(YD)) {
                    listValue.add(map.getValue());
                }
        }
        }else if (type.equals("移动")) {
            for (Map.Entry<String, String> map : SDictionaryServiceImpl.jzYdYys.entrySet()) {
                if (map.getKey().contains(YD)) {
                    listValue.add(map.getValue());
                }
            }
        }
        return listValue;
    }

    //  添加数据 --- & 数据验证
    private boolean addData(TbExcelJzMessageImport tbExcelJzMessageImportCorrect, TbExcelJzMessageImport tbExcelJzMessageImportError, String head,
                            String value, String excelType, String excelId) {

        Pattern pattern = Pattern.compile("[0-9]*");
        //非空判断已经放到了每个方法里面
        String mapValue = null;
        //项目编号
        if (BaseTitleHead.TABLE_HEAD_JZ_CODE.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzCode("");
                tbExcelJzMessageImportCorrect.setJzCode("");
                return false;
            } else if (value.length() > 100) {
                tbExcelJzMessageImportError.setJzCode(value + " ");
                return false;
            }
            tbExcelJzMessageImportError.setJzCode(value);
            tbExcelJzMessageImportCorrect.setJzCode(value);
        }
        //二维码
        else if (BaseTitleHead.TABLE_HEAD_JZ_EVM.getStatus().equals(head)) {
            if (this.getYDValue("代缴").contains(tbExcelJzMessageImportCorrect.getJzYys())) {
                if (StringUtils.isEmpty(value)) {
                    tbExcelJzMessageImportError.setJzEwm("");
                    tbExcelJzMessageImportCorrect.setJzEwm("");
                    return false;
                }
                if (value.length() < 6) {
                    tbExcelJzMessageImportError.setJzEwm(value + " ");
                    return false;
                } else if ("ROOMID".equals(value.substring(0, 6))) {
                    if (value.substring(6).length() == 12
                            && pattern.matcher(value.substring(6)).matches()) {
                        tbExcelJzMessageImportError.setJzEwm(value);
                        tbExcelJzMessageImportCorrect.setJzEwm(value);
                    } else {
                        tbExcelJzMessageImportError.setJzEwm(value + " ");
                        return false;
                    }

                } else if ("ZY".equals(value.substring(0, 2))) {
                    if (value.substring(2).length() == 21
                            && pattern.matcher(value.substring(2)).matches()) {
                        tbExcelJzMessageImportError.setJzEwm(value);
                        tbExcelJzMessageImportCorrect.setJzEwm(value);
                    } else {
                        tbExcelJzMessageImportError.setJzEwm(value + " ");
                        return false;
                    }

                } else {
                    tbExcelJzMessageImportError.setJzEwm(value + " ");
                    return false;
                }
            } else if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzEwm("");
            } else {
                tbExcelJzMessageImportError.setJzEwm(value);
                return false;
            }
        }
        //项目编号
        else if (BaseTitleHead.TABLE_HEAD_PROJECT_ID.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setProjectCode("");
                tbExcelJzMessageImportCorrect.setProjectCode("");
                return false;
            } else if (value.length() > 100) {
                tbExcelJzMessageImportError.setProjectCode(value);
                return false;
            }
            //***项目编号***！！！每次都要去查,必须没有
            JzMessage jzMessage1 = new JzMessage();
            jzMessage1.setNormal();
            jzMessage1.setProjectCode(value);
            JzMessage jzMessage = jzMessageRepository.queryProjectCodeExcel(jzMessage1);
            //若已存在该项目编号
            TbExcelJzMessageImport tbExcelJzMessageImport = tbExcelJzMessageImportRepository.queryProjectCodeExcel(value, excelId);
            boolean haveExit = false;
            for (String isExit : haveProjectCode) {
                if (isExit.equals(value)) {
                    haveExit = true;
                    break;
                }
            }
            if (jzMessage != null || tbExcelJzMessageImport != null || haveExit == true) {
                tbExcelJzMessageImportError.setProjectCode(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setProjectCode(value);
                tbExcelJzMessageImportCorrect.setProjectCode(value);
            }
        }
        //业务线
        else if (BaseTitleHead.TABLE_HEAD_TASK_LINE.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setBusinessLine("");
                tbExcelJzMessageImportCorrect.setBusinessLine("");
                return false;
            }
            mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_TASK_LINE.getTableType(), value));
            //若不存在该业务线
            if (mapValue == null || "error".equals(mapValue)) {
                tbExcelJzMessageImportError.setBusinessLine(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setBusinessLine(value);
                tbExcelJzMessageImportCorrect.setBusinessLine(mapValue);
            }
        }
        //区域
        else if (BaseTitleHead.TABLE_HEAD_QY.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzQy("");
                tbExcelJzMessageImportCorrect.setJzQy("");
                return false;
            }
            //根据区域name获取区域id
            mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_QY.getTableType(), value));
            //若不存在此区域
            if (mapValue == null || "error".equals(mapValue)) {
                tbExcelJzMessageImportError.setJzQy(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setJzQy(value);
                tbExcelJzMessageImportCorrect.setJzQy(mapValue);
            }
        }
        //移动关系
        else if (BaseTitleHead.TABLE_HEAD_MOBILE_RELATION.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzMobileRelation("");
                tbExcelJzMessageImportCorrect.setJzMobileRelation("");
                return false;
            } else if (value.length() > 100) {
                tbExcelJzMessageImportError.setJzMobileRelation(value + " ");
                return false;
            }
            tbExcelJzMessageImportError.setJzMobileRelation(value);
            tbExcelJzMessageImportCorrect.setJzMobileRelation(value);
        }
        //项目地址
        else if (BaseTitleHead.TABLE_HEAD_PROJECT_STATUS.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setProjectAddress("");
                tbExcelJzMessageImportCorrect.setProjectAddress("");
                return false;
            } else if (value.length() > 100) {
                tbExcelJzMessageImportError.setProjectAddress(value + " ");
                return false;
            }
            tbExcelJzMessageImportError.setProjectAddress(value);
            tbExcelJzMessageImportCorrect.setProjectAddress(value);
        }
        //阶段负责人
        else if (BaseTitleHead.TABLE_HEAD_CURRENT_MAN.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzCurUser("");
                tbExcelJzMessageImportCorrect.setJzCurUser("");
                deptId = "";
                return false;
            }
            mapValue = userMap.get(value);
            deptId = deptMap.get(value);
            if (mapValue == null || "error".equals(mapValue)) {
                tbExcelJzMessageImportError.setJzCurUser(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setJzCurUser(value);
                tbExcelJzMessageImportCorrect.setJzCurDept(deptId);
                tbExcelJzMessageImportCorrect.setJzCurUser(mapValue);
            }
        }
        //项目负责人
        else if (BaseTitleHead.TABLE_HEAD_PROJECT_MAN.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzProjectOwner("");
                tbExcelJzMessageImportCorrect.setJzProjectOwner("");
                return false;
            }
            //若不存在项目负责人或其重名
            mapValue = userMap.get(value);
            if (mapValue == null || "error".equals(mapValue) || !deptId.equals(deptMap.get(value))) {
                tbExcelJzMessageImportError.setJzProjectOwner(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setJzProjectOwner(value);
                tbExcelJzMessageImportCorrect.setJzCurDept(deptId);
                tbExcelJzMessageImportCorrect.setJzProjectOwner(mapValue);
            }
        }
        //移动项目经理的手机号
        else if (BaseTitleHead.TABLE_HEAD_MOBILE_CONTACT.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzMobilePhone("");
                tbExcelJzMessageImportCorrect.setJzMobilePhone("");
                return false;
            } else {
                if (value.length() != 11) {
                    tbExcelJzMessageImportError.setJzMobilePhone(value);
                    return false;
                } else {
                    String regex = "^1[3|4|5|7|8|6|9][0-9]\\d{4,8}$";
                    Pattern p = Pattern.compile(regex);
                    Matcher m = p.matcher(value);
                    if (m.matches()) {
                        tbExcelJzMessageImportError.setJzMobilePhone(value);
                        tbExcelJzMessageImportCorrect.setJzMobilePhone(value);
                    } else {
                        tbExcelJzMessageImportError.setJzMobilePhone(value);
                        return false;
                    }
                }
            }

        }
        //上游客户
        else if (BaseTitleHead.TABLE_HEAD_UP_USER.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzUpCustom("");
                tbExcelJzMessageImportCorrect.setJzUpCustom("");
                return false;
            }
            //获取上游客户的值
            if (BaseTitleHead.TABLE_HEAD_OPERATOR_YD.getStatus().equals(excelType)) { //移动
                mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_UP_YDUSER.getTableType(), value));
            } else if (BaseTitleHead.TABLE_HEAD_OPERATOR_TT.getStatus().equals(excelType)) { //铁塔
                mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_UP_TTUSER.getTableType(), value));
            }
            //若不存在该上游客户
            if (mapValue == null || "error".equals(mapValue)) {
                tbExcelJzMessageImportError.setJzUpCustom(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setJzUpCustom(value);
                tbExcelJzMessageImportCorrect.setJzUpCustom(mapValue);
            }
        }
        //运营商
        else if (BaseTitleHead.TABLE_HEAD_OPERATOR.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzYys("");
                tbExcelJzMessageImportCorrect.setJzYys("");
                return false;
            }
            //根据运营商name去获取其id
            if (BaseTitleHead.TABLE_HEAD_OPERATOR_YD.getStatus().equals(excelType)) { // 移动
                mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_OPERATOR_YD.getTableType(), value));
            } else if (BaseTitleHead.TABLE_HEAD_OPERATOR_TT.getStatus().equals(excelType)) { // 铁塔
                mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_OPERATOR_TT.getTableType(), value));
            } else if (BaseTitleHead.TABLE_HEAD_OPERATOR_DJ.getStatus().equals(excelType)) {
                mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_OPERATOR_DJ.getTableType(), value));
            }
            //若不存在该运营商
            if (mapValue == null || "error".equals(mapValue)) {
                tbExcelJzMessageImportError.setJzYys(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setJzYys(value);
                tbExcelJzMessageImportCorrect.setJzYys(mapValue);
            }
        }
        //需求号判断
        else if (BaseTitleHead.TABLE_HEAD_DEMAN_ID.getStatus().equals(head)) {
            //需求号判断
            if (this.getYDValue("移动").contains(tbExcelJzMessageImportCorrect.getJzYys())
                    || this.getYDValue("铁塔").equals(tbExcelJzMessageImportCorrect.getJzYys())) {
                if (StringUtils.isEmpty(value)) {
                    tbExcelJzMessageImportCorrect.setJzRequire("");
                    tbExcelJzMessageImportError.setJzRequire("");
                    return false;
                } else if (value.length() > 100) {
                    tbExcelJzMessageImportError.setJzRequire(value);
                    return false;
                }
                tbExcelJzMessageImportCorrect.setJzRequire(value);
                tbExcelJzMessageImportError.setJzRequire(value);
                //数字验证
             /*   if (pattern.matcher(value).matches()) {

                } else {
                    tbExcelJzMessageImportError.setJzRequire(value + " ");
                    return false;
                }*/
            } else {
                if ("".equals(value) || value == null) {
                    tbExcelJzMessageImportError.setJzEwm("");
                } else {
                    tbExcelJzMessageImportError.setJzRequire(value);
                }
            }
        }
        //建设方式
        else if (BaseTitleHead.TABLE_HEAD_BUILD_WAY.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzConstruct("");
                tbExcelJzMessageImportCorrect.setJzConstruct("");
                return false;
            }
            //若不存在该建设方式
            mapValue = dataMap.get(new NewPair<>(BaseTitleHead.TABLE_HEAD_BUILD_WAY.getTableType(), value));
            if (mapValue == null || "error".equals(mapValue)) {
                tbExcelJzMessageImportError.setJzConstruct(value + " ");
                return false;
            } else {
                tbExcelJzMessageImportError.setJzConstruct(value);
                tbExcelJzMessageImportCorrect.setJzConstruct(mapValue);
            }
        }
        //基站名
        else if (BaseTitleHead.TABLE_HEAD_JZ_NAME.getStatus().equals(head)) {
            if (StringUtils.isEmpty(value)) {
                tbExcelJzMessageImportError.setJzName("");
                tbExcelJzMessageImportCorrect.setJzName("");
                return false;
            } else if (value.length() > 100) {
                tbExcelJzMessageImportError.setJzName(value + " ");
                return false;
            }
            tbExcelJzMessageImportError.setJzName(value);
            tbExcelJzMessageImportCorrect.setJzName(value);
        }
        //经度
        else if (BaseTitleHead.TABLE_HEAD_LONGITUDE.getStatus().equals(head)) {
            if (isBigDecimal(value) == false) {
                tbExcelJzMessageImportCorrect.setJzLongitude(new BigDecimal(-1));
                tbExcelJzMessageImportError.setJzLongitude(new BigDecimal(-1));
            } else if (new BigDecimal(value).compareTo(new BigDecimal(180.000000)) == 1 || value.charAt(0) == '-') {
                tbExcelJzMessageImportCorrect.setJzLongitude(new BigDecimal(value));
                tbExcelJzMessageImportError.setJzLongitude(new BigDecimal(value));
                return false;
            } else {
                tbExcelJzMessageImportCorrect.setJzLongitude(new BigDecimal(value));
                tbExcelJzMessageImportError.setJzLongitude(new BigDecimal(value));
            }
        }
        //纬度
        else if (BaseTitleHead.TABLE_HEAD_DIMENSION.getStatus().equals(head)) {
            if (isBigDecimal(value) == false) {
                tbExcelJzMessageImportCorrect.setJzLatitude(new BigDecimal(-1));
                tbExcelJzMessageImportError.setJzLatitude(new BigDecimal(-1));
            } else if (new BigDecimal(value).compareTo(new BigDecimal(90.000000)) == 1 || value.charAt(0) == '-') {
                tbExcelJzMessageImportCorrect.setJzLatitude(new BigDecimal(value));
                tbExcelJzMessageImportError.setJzLatitude(new BigDecimal(value));
                return false;
            } else {
                tbExcelJzMessageImportCorrect.setJzLatitude(new BigDecimal(value));
                tbExcelJzMessageImportError.setJzLatitude(new BigDecimal(value));
            }
        }
        //基站创建日期
        else if (BaseTitleHead.TABLE_HEAD_CREATE_DATE.getStatus().equals(head)) {
            if (StringUtils.isNotEmpty(value)) {
                String[] strings = value.split("-");
                String[] str1 = {"1", "01", "3", "03", "5", "05", "7", "07", "8", "08", "10", "12"};
                String[] str2 = {"4", "04", "6", "06", "9", "09", "11"};

                int y = Integer.parseInt(strings[0]);

                if (strings.length != 3
                        || strings[0].length() != 4
                        || Integer.parseInt(strings[1]) > 12
                        || (Arrays.asList(str1).contains(strings[1]) && Integer.parseInt(strings[2]) > 31)
                        || (Arrays.asList(str2).contains(strings[1]) && Integer.parseInt(strings[2]) > 30)) {
                    tbExcelJzMessageImportCorrect.setJzCreateDate(null);
                    tbExcelJzMessageImportError.setJzCreateDate(null);
                    return false;
                } else if ("2".equals(strings[1])) {
                    if ((y % 4 == 0 && y % 100 != 0) || (y % 400 == 0)) {
                        if (Integer.parseInt(strings[2]) > 29) {
                            tbExcelJzMessageImportCorrect.setJzCreateDate(null);
                            tbExcelJzMessageImportError.setJzCreateDate(null);
                            return false;
                        }
                    } else {
                        if (Integer.parseInt(strings[2]) > 28) {
                            tbExcelJzMessageImportCorrect.setJzCreateDate(null);
                            tbExcelJzMessageImportError.setJzCreateDate(null);
                            return false;
                        }
                    }
                }

                try {
                    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                    tbExcelJzMessageImportCorrect.setJzCreateDate(sdf.parse(value));
                    tbExcelJzMessageImportError.setJzCreateDate(sdf.parse(value));
                } catch (ParseException e) {
                    tbExcelJzMessageImportCorrect.setJzCreateDate(null);
                    tbExcelJzMessageImportError.setJzCreateDate(null);
                    return false;
                }
            } else {
                tbExcelJzMessageImportCorrect.setJzCreateDate(null);
                tbExcelJzMessageImportError.setJzCreateDate(null);
                return false;
            }
        }
        return true;
    }

    //判断类型选取表头 代缴站 0 移动 1 铁塔 2
    private Integer checkHead(String excelType) {
        for (int i = 0; i < excelType.length(); i++) {
            if (!Character.isDigit(excelType.charAt(i))) {
                return null;
            }
        }
        Integer chooseHead = Integer.parseInt(excelType);
        if (chooseHead >= 3 || chooseHead < 0) {
            return null;
        }
        return chooseHead;
    }

    // 验证表头
    private boolean excelReadhead(MultipartFile file, String excelType) throws Exception {
        //判断为哪一个
        Integer chooseHead = checkHead(excelType);
        if (chooseHead == null)
            return false;
        //读取excel文件
        InputStream inputStream = file.getInputStream();
        /*        POIFSFileSystem poifsFileSystem = new POIFSFileSystem(inputStream);*/
        XSSFWorkbook book = new XSSFWorkbook(inputStream);
        XSSFSheet sheet = book.getSheetAt(0);
        //表头那一行
        XSSFRow titleRow = sheet.getRow(0);
        if (titleRow.getLastCellNum() != tableHead[chooseHead].length) {
            return false;
        }
        //表头那个单元格
        boolean isCorrect = true;
        for (int i = 0; i < tableHead[chooseHead].length; i++) {
            titleRow.getCell(i).setCellType(CellType.STRING);
            String cellBody = titleRow.getCell(i).getStringCellValue();
            if (tableHead[chooseHead][i].equals(cellBody)) {
                continue;
            } else {
                isCorrect = false;
                break;
            }
        }
        if (isCorrect == false) {
            return false;
        }
        return true;
    }

    //读取再次提交的List，并进行验证
    public int excelListCheck(String excelType, String excelId, List<Map<String, Object>> excelList) {

        //选择的表头
        Integer chooseHead = checkHead(excelType);
        //记录错误数据的新的list的行
        //int cnt = 0;
        // 判断是否为完全正确
        int isAllCorrect = 1;

        for (int i = 0; i < excelList.size(); i++) {
            boolean isTrue = true;
            TbExcelJzMessageImport tbExcelJzMessageImportCorrect = new TbExcelJzMessageImport();
            TbExcelJzMessageImport tbExcelJzMessageImportError = new TbExcelJzMessageImport();
            //设置基站类型
            tbExcelJzMessageImportCorrect.setJzType(Integer.toString(chooseHead));
            tbExcelJzMessageImportError.setJzType(Integer.toString(chooseHead));
            int errorNumLine = 0;
            for (int j = 0; j < excelTableHead[chooseHead].length; j++) {
                String value = excelList.get(i).get(excelTableHead[chooseHead][j]).toString().trim();
                if (value == null || "".equals(value)) {
                    errorNumLine++;
                }
                //添加数据
                //去除前后空格
                if (addData(tbExcelJzMessageImportCorrect, tbExcelJzMessageImportError, tableHead[chooseHead][j], value, excelType, excelId) ==
                        false) {
                    //如果存在错误的话
                    isTrue = false;
                    //errorPos.add(new Pair<Integer, Integer>(cnt,j)); //已经不用
                }
            }
            //如果改行数据全为空则不插入————————————————————————————————！！！
            if (errorNumLine == excelTableHead[chooseHead].length)
                continue;
            //如果这一行的数据为正确的
            if (isTrue == true) {
                tbExcelJzMessageImportCorrect.setExcelId(excelId);
                correctData.add(tbExcelJzMessageImportCorrect);
                haveProjectCode.add(tbExcelJzMessageImportCorrect.getProjectCode());
            } else {
                tbExcelJzMessageImportError.setExcelId(excelId);
                errorData.add(tbExcelJzMessageImportError);
                //cnt++;
                isAllCorrect = 2;
            }
        }
        return isAllCorrect;
    }

    // 返回值 0 : 表头不正确 1: 完全正确 2：含有错误数据 读取excel表格
    public int excelReadList(MultipartFile file, String excelType, String excelId, List<Map<String, Object>> excelList) throws Exception {
        if (excelList != null && excelList.size() > 0) {
            return excelListCheck(excelType, excelId, excelList);
        }
        if (file != null && excelReadhead(file, excelType) == false) {
            return 0;
        }
        if (file == null)
            return 0;
        InputStream inputStream = file.getInputStream();
        /*POIFSFileSystem poifsFileSystem = new POIFSFileSystem(inputStream);*/
        XSSFWorkbook book = new XSSFWorkbook(inputStream);
        XSSFSheet sheet = book.getSheetAt(0);

        //选择的表头
        Integer chooseHead = checkHead(excelType);

        //记录错误数据的新的list的行
        // int cnt = 0;
        // 判断是否为完全正确
        int isAllCorrect = 1;

        if (sheet.getLastRowNum() == 0) {
            isAllCorrect = 3;
        }
        for (int i = 1; i < sheet.getLastRowNum() + 1; i++) {
            XSSFRow row = sheet.getRow(i);
            //判断是否为正确数据
            boolean isTrue = true;
            TbExcelJzMessageImport tbExcelJzMessageImportCorrect = new TbExcelJzMessageImport();
            TbExcelJzMessageImport tbExcelJzMessageImportError = new TbExcelJzMessageImport();
            //设置基站类型
            tbExcelJzMessageImportCorrect.setJzType(Integer.toString(chooseHead));
            tbExcelJzMessageImportError.setJzType(Integer.toString(chooseHead));
            //判断改行为空数据的有几条
            int errorNumLine = 0;
            String cellBody;
            for (int j = 0; j < tableHead[chooseHead].length; j++) {
                cellBody = "";
                //如果表格数据为null  基站创建日期，基站二维码，需求号需要单独验证
                if (!BaseTitleHead.TABLE_HEAD_CREATE_DATE.getStatus().equals(tableHead[chooseHead][j]) &&
                        !BaseTitleHead.TABLE_HEAD_JZ_EVM.getStatus().equals(tableHead[chooseHead][j]) &&
                        !BaseTitleHead.TABLE_HEAD_DEMAN_ID.getStatus().equals(tableHead[chooseHead][j])) {
                    if (row.getCell(j) == null) {
                        errorNumLine++;
                        addData(tbExcelJzMessageImportCorrect, tbExcelJzMessageImportError, tableHead[chooseHead][j], null, excelType, excelId);
                        isTrue = false;
                        continue;
                    }
                    row.getCell(j).setCellType(CellType.STRING);
                    //去除前后的空格
                    cellBody = row.getCell(j).toString().trim();
                    //验证改行数据是否为空
                    if ("".equals(cellBody) || cellBody == null) {
                        errorNumLine++;
                    }
                    //经纬度判断
                    else if (BaseTitleHead.TABLE_HEAD_LONGITUDE.getStatus().equals(tableHead[chooseHead][j]) ||
                            BaseTitleHead.TABLE_HEAD_DIMENSION.getStatus().equals(tableHead[chooseHead][j])) {
                        String[] strings = cellBody.split("\\.");
                        if (strings.length != 2) {
                            isTrue = false;
                        } else if (strings[1].length() != 6) {
                            isTrue = false;
                        } else {
                            Pattern pattern = Pattern.compile("[0-9]*");
                            boolean longitude = pattern.matcher(strings[0]).matches();
                            if (longitude) {
                                longitude = pattern.matcher(strings[1]).matches();
                                if (!longitude) {
                                    isTrue = false;
                                }
                            } else {
                                isTrue = false;
                            }
                        }
                    }
                } else if (row.getCell(j) != null) {
                    if (BaseTitleHead.TABLE_HEAD_CREATE_DATE.getStatus().equals(tableHead[chooseHead][j])) {
                        if (row.getCell(j) == null || "".equals(row.getCell(j).toString())) {
                            errorNumLine++;
                            addData(tbExcelJzMessageImportCorrect, tbExcelJzMessageImportError, tableHead[chooseHead][j], null, excelType, excelId);
                            isTrue = false;
                            continue;
                        } else {
                            //SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                            log.debug("===================" + j);
                            if (row.getCell(j).getCellTypeEnum() == CellType.NUMERIC) {
                                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                                double numericCellValue = row.getCell(j).getNumericCellValue();
                                Date javaDate = DateUtil.getJavaDate(numericCellValue);
                                cellBody = sdf.format(javaDate);
                            } else {
                                cellBody = row.getCell(j).getStringCellValue().trim();
                            }
                            //cellBody = sdf.format(HSSFDateUtil.getJavaDate(row.getCell(j).getNumericCellValue()));
                        }
                    } else {
                        row.getCell(j).setCellType(CellType.STRING);
                        cellBody = row.getCell(j).getStringCellValue().trim();
                    }
                }
                //添加数据
                if (addData(tbExcelJzMessageImportCorrect, tbExcelJzMessageImportError, tableHead[chooseHead][j], cellBody, excelType, excelId) ==
                        false) {
                    //如果存在错误的话
                    isTrue = false;
                    //新的errorData中第cnt行第j列-----------------------errorPos cnt 和 j从0 0开始
                    //errorPos.add(new Pair<Integer, Integer>(cnt,j)); 已经不用
                }

            }
            //如果改所有数据全为空的则不插入---------------------------！！！！！
            if (errorNumLine == tableHead[chooseHead].length)
                continue;
            //如果这一行的数据为正确的
            if (isTrue == true) {
                tbExcelJzMessageImportCorrect.setExcelId(excelId);
                correctData.add(tbExcelJzMessageImportCorrect);
                haveProjectCode.add(tbExcelJzMessageImportCorrect.getProjectCode());
            } else {
                tbExcelJzMessageImportError.setExcelId(excelId);
                errorData.add(tbExcelJzMessageImportError);
                // cnt++;
                isAllCorrect = 2;
            }
        }
        return isAllCorrect;
    }
}
