package org.rcisoft.business.excelimport.tbexcelinfo.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.excelimport.tbexcelinfo.entity.TbExcelInfo;
import org.rcisoft.business.excelimport.tbexcelinfo.service.TbExcelInfoService;

import java.util.List;

/**
* Created by zyj on 2019-8-3 0:55:38.
*/
@RestController
@RequestMapping("/tbexcelinfo")
public class TbExcelInfoController extends CyPaginationController<TbExcelInfo> {

    @Autowired
    private TbExcelInfoService tbExcelInfoServiceImpl;


    @ApiOperation(value="添加", notes="添加")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid TbExcelInfo tbExcelInfo, BindingResult bindingResult) {
        CyPersistModel data = tbExcelInfoServiceImpl.save(tbExcelInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        tbExcelInfo);
    }
    @ApiOperation(value="逻辑删除", notes="逻辑删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,TbExcelInfo tbExcelInfo) {
        tbExcelInfo.setBusinessId(businessId);
        CyPersistModel data = tbExcelInfoServiceImpl.removeLogical(tbExcelInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="删除", notes="删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,TbExcelInfo tbExcelInfo) {
        tbExcelInfo.setBusinessId(businessId);
        CyPersistModel data = tbExcelInfoServiceImpl.remove(tbExcelInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="修改", notes="修改")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid TbExcelInfo tbExcelInfo, BindingResult bindingResult) {
        tbExcelInfo.setBusinessId(businessId);
        CyPersistModel data = tbExcelInfoServiceImpl.merge(tbExcelInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        tbExcelInfo);
    }

    @ApiOperation(value="查询单一", notes="查询单一")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        tbExcelInfoServiceImpl.findById(businessId));
    }

    @ApiOperation(value="查询集合", notes="查询集合")
    @GetMapping(value = "/queryTbExcelInfos")
    public CyResult queryTbExcelInfos(TbExcelInfo tbExcelInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            tbExcelInfoServiceImpl.findAll(tbExcelInfo));
    }

    @ApiOperation(value="分页查询集合", notes="分页查询集合")
    @GetMapping(value = "/queryTbExcelInfoByPagination")
    public CyGridModel listByPagination(TbExcelInfo tbExcelInfo) {
        tbExcelInfoServiceImpl.findAllByPagination(getPaginationUtility(), tbExcelInfo);
        return getGridModelResponse();
    }
}
