package org.rcisoft.business.excelimport.tbexcelinfo.service.impl;

import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.excelimport.tbexcelinfo.dao.TbExcelInfoRepository;
import org.rcisoft.business.excelimport.tbexcelinfo.entity.TbExcelInfo;
import org.rcisoft.business.excelimport.tbexcelinfo.service.TbExcelInfoService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by zyj on 2019-8-3 0:55:38.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TbExcelInfoServiceImpl extends CyBaseService  implements TbExcelInfoService {

    @Autowired
    private TbExcelInfoRepository tbExcelInfoRepository;


    /**
    * 保存 
    * @param tbExcelInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(TbExcelInfo tbExcelInfo){
        //增加操作
        CyUserUtil.setCurrentPersistOperation(tbExcelInfo);
        int line = tbExcelInfoRepository.insertSelective(tbExcelInfo);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"新增了ID为"+
tbExcelInfo.getBusinessId()+"的信息","新增");
        log.info(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            tbExcelInfo.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 
    * @param tbExcelInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TbExcelInfo tbExcelInfo){
        int line = tbExcelInfoRepository.deleteByPrimaryKey(tbExcelInfo.getBusinessId());
        this.dbInfo(CyUserUtil.getAuthenUsername()+"删除了ID为"+
tbExcelInfo.getBusinessId()+"的信息","删除");
        log.info(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            tbExcelInfo.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }
    /**
    * 逻辑删除 
    * @param tbExcelInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TbExcelInfo tbExcelInfo){
        CyUserUtil.setCurrentMergeOperation(tbExcelInfo);
        tbExcelInfo.setDeleted();
        int line = tbExcelInfoRepository.logicalDelete(tbExcelInfo);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
tbExcelInfo.getBusinessId()+"的信息","逻辑删除");
        log.info(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
            tbExcelInfo.getBusinessId()+"的信息");

        return new CyPersistModel(line);
    }
    /**
    * 修改 
    * @param tbExcelInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TbExcelInfo tbExcelInfo){
        CyUserUtil.setCurrentMergeOperation(tbExcelInfo);
        int line = tbExcelInfoRepository.updateByPrimaryKeySelective(tbExcelInfo);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"修改了ID为"+
tbExcelInfo.getBusinessId()+"的信息","修改");
        log.info(CyUserUtil.getAuthenUsername()+"修改了ID为"+
            tbExcelInfo.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 
    * @param id
    * @return
    */
    @Override
    public TbExcelInfo findById(String id){
        return tbExcelInfoRepository.selectByPrimaryKey(id);
    }

    /**
    * 分页查询 
    * @param tbExcelInfo
    * @return
    */
    @Override
    public List<TbExcelInfo> findAllByPagination(CyPageUtil<TbExcelInfo> paginationUtility,
        TbExcelInfo tbExcelInfo){
        tbExcelInfo.setNormal();
        return tbExcelInfoRepository.queryTbExcelInfos(tbExcelInfo);
    }
    /**
    * 查询list 
    * @param tbExcelInfo
    * @return
    */
    @Override
    public List<TbExcelInfo> findAll(TbExcelInfo tbExcelInfo){
        tbExcelInfo.setNormal();
        return tbExcelInfoRepository.queryTbExcelInfos(tbExcelInfo);
    }

    /**
     * 根据userId查询表中是否有未完成的任务
     * @param userId
     * @return
     */
    @Override
    public List<TbExcelInfo> findByUserId(String userId) {
        return tbExcelInfoRepository.findByUserId(userId);
    }

}
