package org.rcisoft.business.hijzmessage.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.hijzmessage.entity.HiJzMessage;
import org.rcisoft.business.hijzmessage.service.HiJzMessageService;

import java.util.List;

/**
* Created by lpy on 2019-7-26 15:45:51.
*/
@RestController
@RequestMapping("/hijzmessage")
public class HiJzMessageController extends CyPaginationController<HiJzMessage> {

    @Autowired
    private HiJzMessageService hiJzMessageServiceImpl;


    @ApiOperation(value="添加基站历史信息表", notes="添加基站历史信息表")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid HiJzMessage hiJzMessage, BindingResult bindingResult) {
        CyPersistModel data = hiJzMessageServiceImpl.save(hiJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        hiJzMessage);
    }
    @ApiOperation(value="逻辑删除基站历史信息表", notes="逻辑删除基站历史信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,HiJzMessage hiJzMessage) {
        hiJzMessage.setBusinessId(businessId);
        CyPersistModel data = hiJzMessageServiceImpl.removeLogical(hiJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="删除基站历史信息表", notes="删除基站历史信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,HiJzMessage hiJzMessage) {
        hiJzMessage.setBusinessId(businessId);
        CyPersistModel data = hiJzMessageServiceImpl.remove(hiJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="修改基站历史信息表", notes="修改基站历史信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid HiJzMessage hiJzMessage, BindingResult bindingResult) {
        hiJzMessage.setBusinessId(businessId);
        CyPersistModel data = hiJzMessageServiceImpl.merge(hiJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        hiJzMessage);
    }

    @ApiOperation(value="查询单一基站历史信息表", notes="查询单一基站历史信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        hiJzMessageServiceImpl.findById(businessId));
    }

    @ApiOperation(value="查询基站历史信息表集合", notes="查询基站历史信息表集合")
    @GetMapping(value = "/queryHiJzMessages")
    public CyResult queryHiJzMessages(HiJzMessage hiJzMessage) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            hiJzMessageServiceImpl.findAll(hiJzMessage));
    }

    @ApiOperation(value="分页查询基站历史信息表集合", notes="分页查询基站历史信息表集合")
    @GetMapping(value = "/queryHiJzMessageByPagination")
    public CyGridModel listByPagination(HiJzMessage hiJzMessage) {
        hiJzMessageServiceImpl.findAllByPagination(getPaginationUtility(), hiJzMessage);
        return getGridModelResponse();
    }
}
