package org.rcisoft.business.hijzmessage.service.impl;

import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.hijzmessage.dao.HiJzMessageRepository;
import org.rcisoft.business.hijzmessage.entity.HiJzMessage;
import org.rcisoft.business.hijzmessage.service.HiJzMessageService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by lpy on 2019-7-26 15:45:51.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class HiJzMessageServiceImpl extends CyBaseService  implements HiJzMessageService {

    @Autowired
    private HiJzMessageRepository hiJzMessageRepository;


    /**
    * 保存 基站历史信息表
    * @param hiJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(HiJzMessage hiJzMessage){
        //增加操作
        CyUserUtil.setCurrentPersistOperation(hiJzMessage);
        int line = hiJzMessageRepository.insertSelective(hiJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"新增了ID为"+
hiJzMessage.getBusinessId()+"的基站历史信息表信息","新增基站历史信息表");
        log.info(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            hiJzMessage.getBusinessId()+"的基站历史信息表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 基站历史信息表
    * @param hiJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(HiJzMessage hiJzMessage){
        int line = hiJzMessageRepository.deleteByPrimaryKey(hiJzMessage.getBusinessId());
        this.dbInfo(CyUserUtil.getAuthenUsername()+"删除了ID为"+
hiJzMessage.getBusinessId()+"的基站历史信息表信息","删除基站历史信息表");
        log.info(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            hiJzMessage.getBusinessId()+"的基站历史信息表信息");
        return new CyPersistModel(line);
    }
    /**
    * 逻辑删除 基站历史信息表
    * @param hiJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(HiJzMessage hiJzMessage){
        CyUserUtil.setCurrentMergeOperation(hiJzMessage);
        hiJzMessage.setDeleted();
        int line = hiJzMessageRepository.logicalDelete(hiJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
hiJzMessage.getBusinessId()+"的基站历史信息表信息","逻辑删除基站历史信息表");
        log.info(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
            hiJzMessage.getBusinessId()+"的基站历史信息表信息");

        return new CyPersistModel(line);
    }
    /**
    * 修改 基站历史信息表
    * @param hiJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(HiJzMessage hiJzMessage){
        CyUserUtil.setCurrentMergeOperation(hiJzMessage);
        int line = hiJzMessageRepository.updateByPrimaryKeySelective(hiJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"修改了ID为"+
hiJzMessage.getBusinessId()+"的基站历史信息表信息","修改基站历史信息表");
        log.info(CyUserUtil.getAuthenUsername()+"修改了ID为"+
            hiJzMessage.getBusinessId()+"的基站历史信息表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 基站历史信息表
    * @param id
    * @return
    */
    @Override
    public HiJzMessage findById(String id){
        return hiJzMessageRepository.selectByPrimaryKey(id);
    }

    /**
    * 分页查询 基站历史信息表
    * @param hiJzMessage
    * @return
    */
    @Override
    public List<HiJzMessage> findAllByPagination(CyPageUtil<HiJzMessage> paginationUtility,
        HiJzMessage hiJzMessage){
        hiJzMessage.setNormal();
        return hiJzMessageRepository.queryHiJzMessages(hiJzMessage);
    }
    /**
    * 查询list 基站历史信息表
    * @param hiJzMessage
    * @return
    */
    @Override
    public List<HiJzMessage> findAll(HiJzMessage hiJzMessage){
        hiJzMessage.setNormal();
        return hiJzMessageRepository.queryHiJzMessages(hiJzMessage);
    }

}
