package org.rcisoft.business.jzmessage.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.rcisoft.business.exportexclemodel.util.ExcelDownload;
import org.rcisoft.business.jzmessage.entity.FileUpload;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.jzmessage.service.JzMessageService;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.sys.dept.entity.SysDept;
import org.rcisoft.sys.dept.service.impl.SysDeptServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.parameters.P;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.web.authentication.WebAuthenticationDetailsSource;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.*;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Created by lpy on 2019-7-24 17:40:17.
 */
@RestController
@RequestMapping("/jzmessage")
@Slf4j
public class JzMessageController extends CyPaginationController<JzMessage> {

    @Autowired
    private JzMessageService jzMessageServiceImpl;
    @Autowired
    private SysDeptServiceImpl sysDeptServiceImpl;
    @Autowired
    private UserDetailsService jwtUserDetailServiceImpl;

    @Value("${global.path.base_upload_location}")
    public  String BASE_UPLOAD_LOCATION;
    @Value("${global.path.temp_location}")
    public  String TEMP_LOCATION;
    @Value("${global.path.jz_location}")
    public  String JZ_LOCATION;

    @Value("${global.keyUser}")
    private String key_user;
    @Value("${global.workflowT}")
    private String workflowT;

    @ApiOperation(value = "添加基站信息表", notes = "添加基站信息表")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid JzMessage jzMessage, BindingResult bindingResult) {
        CyPersistModel data = jzMessageServiceImpl.save(jzMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessage);
    }

    @ApiOperation(value = "逻辑删除基站信息表", notes = "逻辑删除基站信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, JzMessage jzMessage) {
        jzMessage.setBusinessId(businessId);
        CyPersistModel data = jzMessageServiceImpl.removeLogical(jzMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "删除基站信息表", notes = "删除基站信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, JzMessage jzMessage) {
        jzMessage.setBusinessId(businessId);
        CyPersistModel data = jzMessageServiceImpl.remove(jzMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "修改基站信息表", notes = "修改基站信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid JzMessage jzMessage, BindingResult bindingResult) {
        jzMessage.setBusinessId(businessId);
        CyPersistModel data = jzMessageServiceImpl.merge(jzMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessage);
    }

    @ApiOperation(value = "查询单一基站信息表", notes = "查询单一基站信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.findById(businessId));
    }

    @ApiOperation(value = "查询基站信息表集合", notes = "查询基站信息表集合")
    @GetMapping(value = "/queryJzMessages")
    public CyResult queryJzMessages(JzMessage jzMessage) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.findAll(jzMessage));
    }

    @ApiOperation(value = "分页查询基站信息表集合", notes = "分页查询基站信息表集合")
    @GetMapping(value = "/queryJzMessageByPagination")
    public CyGridModel listByPagination(JzMessage jzMessage) {
        SysDept sysDept = new SysDept();
        sysDept.setNormal();
        List<SysDept> deptList = sysDeptServiceImpl.findAll(sysDept);
        jzMessageServiceImpl.findAllByPagination(getPaginationUtility(), jzMessage, deptList);
        return jzMessageServiceImpl.dealwith(getGridModelResponse());
    }

    @ApiOperation(value = "启动流程实例", notes = "启动流程实例")
    @GetMapping(value = "/startProcessInstance")
    public CyResult startProcessInstance(JzMessage jzMessage) {
        CyPersistModel result = jzMessageServiceImpl.startProcessInstance(jzMessage);
        return CyResultGenUtil.builder(result,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }
    /*
    * 修改启动流程
    * */
    @ApiOperation(value = "修改启动流程", notes = "修改启动流程")
    @PostMapping(value = "/startProcessInstance")
    public CyResult startProcessInstanceXG(JzMessage jzMessage) {
        CyPersistModel result = jzMessageServiceImpl.startProcessInstance(jzMessage);
        return CyResultGenUtil.builder(result,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }
    @ApiOperation(value = "所有状态改成选址", notes = "所有状态改成选址")
    @PostMapping(value = "/changeStatus")
    public CyResult changeStatus(@RequestParam("projectCode") String projectCode) {
        return CyResultGenUtil.builder(jzMessageServiceImpl.changeStatus(projectCode),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                projectCode);
    }

    @ApiOperation(value = "完成任务", notes = "完成任务")
    @GetMapping(value = "/completeTask")
    public CyResult completeTask(JzMessage jzMessage) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.completeTask(jzMessage));
    }
    /*
    * 修改完成任务
    * */
    @ApiOperation(value = "修改完成任务", notes = "修改完成任务")
    @PostMapping(value = "/completeTask")
    public CyResult completeTaskXG(JzMessage jzMessage) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.completeTask(jzMessage));
    }

    @ApiOperation(value = "导出excl信息", notes = "导出excl信息")
    @RequestMapping(method = RequestMethod.POST, value = "/export")
    public CyResult exportExcl(HttpServletResponse response, JzMessage jzMessage, String username) {
        //excl信息
        UserDetails userDetails = this.jwtUserDetailServiceImpl.loadUserByUsername(username);
        UsernamePasswordAuthenticationToken authentication = new UsernamePasswordAuthenticationToken(userDetails, (Object) null, userDetails.getAuthorities());
        authentication.setDetails((new WebAuthenticationDetailsSource()).buildDetails(request));
        SecurityContextHolder.getContext().setAuthentication(authentication);
//        String exclName =DateFormat.getDateInstance().format(new Date()) + ".xls";
        String originalName = CyIdGenUtil.uuid() + ".xls";
        SysDept sysDept = new SysDept();
        sysDept.setNormal();
        List<SysDept> deptList = sysDeptServiceImpl.findAll(sysDept);
        HSSFWorkbook wb = new HSSFWorkbook();

        String url = BASE_UPLOAD_LOCATION+"/"+TEMP_LOCATION;
        //下载到指定位置
        File dir = new File(url);
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File file = new File(dir+JzFileController.RIGHTSEPARATOR+originalName);
        if (!file.exists()){
            try {
                file.createNewFile();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        try {
            wb = jzMessageServiceImpl.exportExcl(response, jzMessage, deptList);
            //打开下载路径保存文件夹
//            OutputStream os = response.getOutputStream();
            OutputStream outputStream = new FileOutputStream(file);
            wb.write(outputStream);
            outputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        String finallyPath = TEMP_LOCATION+"/"+originalName;
        FileUpload fileUpload = new FileUpload();
        fileUpload.setFileName(originalName);
        fileUpload.setFilePath(finallyPath);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                fileUpload);
    }

    @ApiOperation(value = "返回当前登录人", notes = "返回当前登录人")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/getLoginPerson")
    public CyResult getLoginPerson() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                CyUserUtil.getAuthenUsername());
    }


    @ApiOperation(value = "添加基站信息", notes = "添加基站信息")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/addMessage")
    public CyResult addMessage(@Valid JzMessage jzMessage, BindingResult bindingResult) throws ParseException {
        List<JzMessage> jzMessages =new ArrayList<>();
        if(jzMessage.getJzCreateDateStr() != null && jzMessage.getJzCreateDateStr() != ""){
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            jzMessage.setJzCreateDate(sdf.parse(jzMessage.getJzCreateDateStr()));
        }
        jzMessages.add(jzMessage);
        CyPersistModel data = jzMessageServiceImpl.batchSave(jzMessages);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessage);
    }

    @ApiOperation(value = "金蝶添加基站信息", notes = "金蝶添加基站信息")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/KingDeeaddMessage")
    public CyResult KingDeeaddMessage(@Valid JzMessage jzMessage, BindingResult bindingResult) throws ParseException {
        if(StringUtils.isNotEmpty(jzMessage.getJzCreateDateStr())){
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            jzMessage.setJzCreateDate(sdf.parse(jzMessage.getJzCreateDateStr()));
        }
        CyPersistModel data = jzMessageServiceImpl.KingDeeSave(jzMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessage);
    }

    @ApiOperation(value = "三级经理更换业务员", notes = "三级经理更换业务员")
    @PostMapping(value = "/changeUser")
    public CyResult changeUer(@RequestParam("jzMessageId") String jzMessageId,@RequestParam("userId") String userId)  {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.changeUser(jzMessageId,userId));
    }

    @ApiOperation(value = "根据id查询基站状态", notes = "根据id查询基站状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @PostMapping(value = "/detail2/{businessId:\\w+}")
        public CyResult changeUer(@PathVariable String businessId)  {
            return CyResultGenUtil.builder(new CyPersistModel(1),
                    CyMessCons.MESSAGE_ALERT_SUCCESS,
                    CyMessCons.MESSAGE_ALERT_ERROR,
                    jzMessageServiceImpl.findJzMessage(businessId));
    }


    @PostMapping(value = "/successLo")
    public CyResult sucessLo(@RequestParam("mid") String mid){
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.loginSuccess(mid,key_user));
    }

    @PostMapping(value = "/getWorkflowT")
    public CyResult getWorkflowT(){
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                workflowT + CyUserUtil.getAuthenBusinessId() +workflowT);
    }

    @ApiOperation(value = "当前阶段负责人是否已在流程中", notes = "当前阶段负责人是否已在流程中")
    @GetMapping(value = "/isCUserInProcess")
    public CyResult isChangeUserInProcess(JzMessage jzMessage)  {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.isChangeUserInProcess(jzMessage));
    }

    @ApiOperation(value = "取消需求取消", notes = "取消需求取消")
    @GetMapping(value = "/cancelNeed")
    public CyResult cancelNeed(JzMessage jzMessage)  {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.cancelNeed(jzMessage));
    }
    /**
     * 根据项目编号和模板类型判断当前流程是否结束
     */
    @ApiOperation(value = "查询当前流程是否结束",notes = "查询当前流程是否结束")
    @GetMapping(value = "/processIsEnd")
    public CyResult processIsEnd(@RequestParam("projectCode") String projectCode,@RequestParam("templateType")String templateType){

        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                jzMessageServiceImpl.processIsEnd(templateType,projectCode));
    }
}
