package org.rcisoft.business.jzmessage.service.impl;

import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.activiti.engine.HistoryService;
import org.activiti.engine.RepositoryService;
import org.activiti.engine.RuntimeService;
import org.activiti.engine.TaskService;
import org.activiti.engine.history.HistoricProcessInstance;
import org.activiti.engine.history.HistoricTaskInstance;
import org.activiti.engine.history.HistoricVariableInstance;
import org.activiti.engine.task.Task;
import org.activiti.model.CyPIAndTaskModel;
import org.activiti.service.CyWfService;
import org.apache.commons.lang3.StringUtils;
import org.apache.ibatis.annotations.Update;
import org.apache.poi.hssf.usermodel.*;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.ss.util.CellRangeAddress;
import org.rcisoft.business.hijzmessage.dao.HiJzMessageRepository;
import org.rcisoft.business.hijzmessage.entity.HiJzMessage;
import org.rcisoft.business.hijzmessage.service.HiJzMessageService;
import org.rcisoft.business.jzmessage.common.*;
import org.rcisoft.business.jzmessage.dao.JzMessageRepository;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.jzmessage.service.JzMessageService;
import org.rcisoft.business.jzmessage.util.*;
import org.rcisoft.business.processDesign.dao.ProcessMidRepository;
import org.rcisoft.business.processDesign.dao.WorkflowTemplateHiRepository;
import org.rcisoft.business.processDesign.entity.ProcessMid;
import org.rcisoft.business.processDesign.entity.WorkflowTaskDateMes;
import org.rcisoft.business.processDesign.entity.WorkflowTemplateHi;
import org.rcisoft.business.processDesign.service.ProcessMidService;
import org.rcisoft.business.processDesign.service.impl.AllMesssageServiceImpl;
import org.rcisoft.business.processDesign.service.impl.TaskServiceImpl;
import org.rcisoft.business.sdictionary.dao.SDictionaryRepository;
import org.rcisoft.business.sdictionary.entity.SDictionary;
import org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl;
import org.rcisoft.business.suser.dao.SUserRepository;
import org.rcisoft.business.suser.entity.SUser;
import org.rcisoft.business.suser.service.SUserService;
import org.rcisoft.business.userwarning.entity.UserWarning;
import org.rcisoft.business.userwarning.service.UserWarningService;
import org.rcisoft.common.*;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyCommonPageGridModel;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.result.CyResultCode;
import org.rcisoft.core.result.CyResultServiceExceptionEnums;
import org.rcisoft.core.result.CyResultSystemExceptionEnums;
import org.rcisoft.core.service.CyBaseService;
import org.rcisoft.core.service.CyRedisService;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyJwtUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.sys.dept.entity.SysDept;
import org.rcisoft.sys.dept.service.SysDeptService;
import org.rcisoft.sys.user.dao.SysUserRepository;
import org.rcisoft.sys.user.entity.SysUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.util.*;

import static org.rcisoft.business.jzmessage.util.ChangeUtil.jzMessageToHistory;

/**
 * Created by lpy on 2019-7-24 17:40:17.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class JzMessageServiceImpl extends CyBaseService implements JzMessageService {
    @Autowired
    JzMessageRepository jzMessageRepository;
    @Autowired
    HiJzMessageRepository hiJzMessageRepository;
    @Autowired
    ProcessMidRepository processMidRepository;
    @Autowired
    SDictionaryRepository sDictionaryRepository;
    @Autowired
    StartProcessHelper helper;
    @Autowired
    Relevance relevance;
    @Autowired
    TaskServiceImpl taskServiceImpl;
    @Autowired
    ProcessMidService processMidServiceImpl;
    @Autowired
    WorkflowTemplateHiRepository workflowTemplateHiRepository;
    @Autowired
    UserWarningService userWarningServiceImpl;
    @Autowired
    SUserRepository sUserRepository;
    @Autowired
    SysDeptService sysDeptServiceImpl;
    @Autowired
    ExclUtil exclUtil;
    @Autowired
    private AuthenticationManager authenticationManager;
    @Autowired
    private CyWfService cyWfServiceImpl;
    @Autowired
    private RepositoryService repositoryService;
    @Autowired
    private RuntimeService runtimeService;
    @Autowired
    private TaskService taskService;
    @Autowired
    private HistoryService historyService;
    @Autowired
    private AllMesssageServiceImpl messsageService;
    @Autowired
    private HiJzMessageService hiJzMessageServiceImpl;
    @Autowired
    private SysUserRepository sysUserRepository;
    @Autowired
    private CyRedisService cyRedisService;
    @Autowired
    private SUserService sUserService;
    @Autowired
    private OptimizeQuery optimizeQuery;

    public static boolean isNeedFieldNull(JzMessage jzMessage) {
        boolean flag = true;
        if (StringUtils.isNotEmpty(jzMessage.getJzName()) || StringUtils.isNotEmpty(jzMessage.getJzCode())) {
            flag = false;
        } else if (StringUtils.isNotEmpty(jzMessage.getProjectCode()) || StringUtils.isNotEmpty(jzMessage.getJzCurUser())) {
            flag = false;
        } else if (StringUtils.isNotEmpty(jzMessage.getJzQy()) || StringUtils.isNotEmpty(jzMessage.getJzCurDept())) {
            flag = false;
        } else if (StringUtils.isNotEmpty(jzMessage.getBusinessLine()) || StringUtils.isNotEmpty(jzMessage.getJzYys())) {
            flag = false;
        } else if (StringUtils.isNotEmpty(jzMessage.getJzUpCustom()) || StringUtils.isNotEmpty(jzMessage.getJzState())) {
            flag = false;
        }
        return flag;
    }

    /**
     * 保存 基站信息表
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(JzMessage jzMessage) {
        //增加操作
        CyUserUtil.setCurrentPersistOperation(jzMessage);
        int line = jzMessageRepository.insertSelective(jzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息", "新增基站信息表");
        log.info(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 基站信息表
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(JzMessage jzMessage) {
        int line = jzMessageRepository.deleteByPrimaryKey(jzMessage.getBusinessId());
        this.dbInfo(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息", "删除基站信息表");
        log.info(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * -
     * 逻辑删除 基站信息表
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(JzMessage jzMessage) {
        CyUserUtil.setCurrentMergeOperation(jzMessage);
        jzMessage.setDeleted();
        int line = jzMessageRepository.logicalDelete(jzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息", "逻辑删除基站信息表");
        log.info(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 基站信息表
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(JzMessage jzMessage) {
        CyUserUtil.setCurrentMergeOperation(jzMessage);
        int line = jzMessageRepository.updateByPrimaryKeySelective(jzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername() + "修改了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息", "修改基站信息表");
        log.info(CyUserUtil.getAuthenUsername() + "修改了ID为" +
                jzMessage.getBusinessId() + "的基站信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 基站信息表
     *
     * @param id
     * @return
     */
    @Override
    public JzMessage findById(String id) {
        return jzMessageRepository.selectByPrimaryKey(id);
    }

    /**
     * 分页查询 基站信息表
     *
     * @param jzMessage
     * @return
     */
    @Override
    public List<JzMessage> findAllByPagination(CyPageUtil<JzMessage> paginationUtility,
                                               JzMessage jzMessage, List<SysDept> deptList) {
        //调用关联类进行分页
        JzMessage myJzMessage = relevance.helpPagination(jzMessage, deptList);//分页查询时的条件
        List<JzMessage> jzMessages = jzMessageRepository.queryJzMessages(myJzMessage);
        optimizeQuery.helpOptimizeQuery(jzMessages, "0");
  /*      for (JzMessage item : jzMessages) {//设置基站类型
            if (StringUtils.isEmpty(item.getJzType())) {
                continue;
            }
            if (item.getJzType().equals("0")) {
                item.setTypeName(TypeEnum.DJ.getname()); //设置基站名称
                item.setYysName(item.getYysDjName());//设置运营商名字
            }
            if (item.getJzType().equals("1")) {
                item.setTypeName(TypeEnum.YD.getname());
                item.setYysName(item.getYysYdName());
                item.setUpperName(item.getUpperYdName()); //设置上游客户名字
            }
            if (item.getJzType().equals("2")) {
                item.setTypeName(TypeEnum.TT.getname());
                item.setYysName(item.getYysTtName());
                item.setUpperName(item.getUpperTtName());
            }
        }*/
        return jzMessages;
    }

    /**
     * 查询list 基站信息表
     *
     * @param jzMessage
     * @return
     */
    @Override
    public List<JzMessage> findAll(JzMessage jzMessage) {
        jzMessage.setNormal();
        return jzMessageRepository.queryJzMessages(jzMessage);
    }

    /**
     * 创建流程部署并启动流程实例
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel startProcessInstance(JzMessage jzMessage) {
        if (StringUtils.isEmpty(jzMessage.getSelect())) {
            throw new CyServiceException(CyResultSystemExceptionEnums.PARAMETER_ERROR);
        } else if (!ProcessMapBpmn.BS_MODIFY_INFO.getCode().equals(jzMessage.getSelect())) {
            if (StringUtils.isEmpty(jzMessage.getTemplateId())) {
                throw new CyServiceException(CyResultSystemExceptionEnums.PARAMETER_ERROR);
            }
        }
        String userBid = CyUserUtil.getAuthenBusinessId();
        boolean weihu = false;
        //查询维护部人员
        List<SUser> maintainPersonList = sUserService.getMaintainPersonList();
        for (SUser sUser : maintainPersonList) {
            if (sUser.getBusinessId().equals(userBid)) {
                weihu = true;
                break;
            }
        }
        /*如果是金蝶跑流程*/
        if (StringUtils.isNotEmpty(jzMessage.getProjectCode())&&StringUtils.isEmpty(jzMessage.getBusinessId())) {
            String businessId = this.selectBusinessIdByProjectCode(jzMessage);
            jzMessage.setBusinessId(businessId);
        }
        log.debug("当前登录人id：" + userBid);
        JzMessage myJzMessage = jzMessageRepository.selectByPrimaryKey(jzMessage.getBusinessId());
        if ("0".equals(myJzMessage.getJzType())) {
            //如果启动的是代缴站
            if (jzMessage.getSelect().equals(ProcessMapBpmn.BS_MODIFY_INFO.getCode())) {
                myJzMessage.setSelect(ProcessMapBpmn.BS_MAINTANCE_CHANGE.getCode());
            } else if (jzMessage.getSelect().equals(ProcessMapBpmn.BS_STAND_DOWN.getCode())) {
                //如果是代缴站只走维护部拆站
                myJzMessage.setSelect(ProcessMapBpmn.BS_MAINTANCE_DOWN.getCode());
            }
        }
        //如果是维护部修改，并且选择为修改，将其修改为维护部修改
        else if (weihu && Integer.parseInt(myJzMessage.getJzState()) > 16 && jzMessage.getSelect().equals(ProcessMapBpmn.BS_MODIFY_INFO.getCode())) {
            myJzMessage.setSelect(ProcessMapBpmn.BS_MAINTANCE_CHANGE.getCode());
        } else if (weihu && Integer.parseInt(myJzMessage.getJzState()) > 16 && jzMessage.getSelect().equals(ProcessMapBpmn.BS_STAND_DOWN.getCode())) {
            myJzMessage.setSelect(ProcessMapBpmn.BS_MAINTANCE_DOWN.getCode());
        } else {
            myJzMessage.setSelect(jzMessage.getSelect());//选择基站信息
        }
        //查询当前登录人角色是否为部门助理
        SUser sUser = sUserRepository.queryRoleByBusineeId(userBid);
        //向jzMessage表中填入启动流程变量
        myJzMessage.setTransition(jzMessage.getTransition());//点击信息
        myJzMessage.setMsgRemarks(jzMessage.getMsgRemarks());//备注信息
        //获取typeTemplate
        for (ProcessMapBpmn value : ProcessMapBpmn.values()) {
            if (value.getCode().equals(myJzMessage.getSelect())) {
                myJzMessage.setTypeTemplate(value.getTypeTemplate());
            }
        }
        if (!userBid.equals(myJzMessage.getJzCurUser()) && sUser == null) {
            //是否当前登录人启动自己的业务
            throw new CyServiceException(ResultServiceExceptionEnums.NOT_CUR_USER);
        }
        if (!CollectionUtils.isEmpty(processMidRepository.queryCurProExist(myJzMessage))) {
            //当前阶段 是否有未结束的流程
            throw new CyServiceException(ResultServiceExceptionEnums.START_PROCESS_ERROR);
        }
        //判断项目编号是否重复
        this.isRepeatProjectCode(jzMessage);
        //启动流程实例
        CyPIAndTaskModel taskModel = helper.BaseStationStart(myJzMessage);
        log.debug("完成任务");
        //插入表单数据信息
        //如果更新标识不为空，说明启动的为修改基站信息流程
        if (StringUtils.isNotEmpty(jzMessage.getIsUpdate())) {
            JzMessage jzMessage1 = jzMessageRepository.selectByPrimaryKey(jzMessage);
            jzMessage.setTaskId(taskModel.getTask().getId());
            jzMessage.setProcessId(taskModel.getProcessInstance().getId());
            jzMessage.setCreateDate(jzMessage1.getCreateDate());
            CyPersistModel cyPersistModel = messsageService.uploadJzMes(jzMessage);
            if (cyPersistModel.getInfluence()<1){
                return cyPersistModel;
            }
        } else {
            WorkflowTaskDateMes dateMes = new WorkflowTaskDateMes();
            dateMes.setTaskId(taskModel.getTask().getId());//获取任务id
            dateMes.setJsonStr(jzMessage.getJsonStrs());//动态json串
            dateMes.setRegionStr(jzMessage.getFlowJsonStr());//静态字符串
            dateMes.setRemarks(jzMessage.getMsgRemarks());//备注
            dateMes.setTransition(jzMessage.getTransition());//提交信息
            dateMes.setProcessId(taskModel.getProcessInstance().getId());
            CyPersistModel cyPersistModel = taskServiceImpl.insertDataMesByTaskId(dateMes);
            if (cyPersistModel.getInfluence()<1){
                return cyPersistModel;
            }
        }
        //插入中间表数据
        ProcessMid processMid = new ProcessMid();
        processMid.setBusinessId(CyIdGenUtil.uuid());//设置business_id
        processMid.setProcessid(taskModel.getProcessInstance().getId());//设置process_id
        processMid.setJzMessageId(myJzMessage.getBusinessId());//设置jz_message_id
        processMid.setTypeProcess(myJzMessage.getJzState());//设置type_process
        processMid.setTypeTemplate(myJzMessage.getTypeTemplate());
        //如果是修改基站信息，则从workflow_template表中查询最高版本所对应的id
        WorkflowTemplateHi workflowTemplateHi = new WorkflowTemplateHi();
        if (ProcessMapBpmn.BS_MODIFY_INFO.getCode().equals(myJzMessage.getSelect())
                || ProcessMapBpmn.BS_MAINTANCE_CHANGE.getCode().equals(myJzMessage.getSelect())) {
            workflowTemplateHi = workflowTemplateHiRepository.startProcess(processMid.getTypeTemplate());
            processMid.setTemplateid(workflowTemplateHi.getId());
        } else {
            //获取templateid
            processMid.setTemplateid(jzMessage.getTemplateId());
        }
        //设置version 版本为空设置为1，反之加1
        String version = processMidRepository.processMidByprocessMid(processMid);
        if (StringUtils.isEmpty(version)) {
            processMid.setVersion("1");
        } else {
            processMid.setVersion(String.valueOf(Integer.valueOf(version) + 1));
        }
        CyPersistModel save = processMidServiceImpl.save(processMid);
        if (save.getInfluence()<1){

            return save;
        }
        return new CyPersistModel(1);
    }

    /**
     * 根据项目编号查询基站是否存在
     *
     */
    public String selectBusinessIdByProjectCode(JzMessage jzMessage){
            List<String> businessId = jzMessageRepository.selectPorjectCodeByBusinessId(jzMessage);
            if (businessId.size()>1) {
                throw new CyServiceException(ResultServiceExceptionEnums.JZ_CODE_ERROR);
            }else if (businessId.size() == 0){
                throw new CyServiceException(ResultServiceExceptionEnums.JZMESSAGE_NULL);
            }else {
                return businessId.get(0);
            }

    };
    /**
     * 完成任务
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel completeTask(JzMessage jzMessage) {
        /*如果是金蝶跑流程*/
        if (StringUtils.isNotEmpty(jzMessage.getProjectCode())&&StringUtils.isEmpty(jzMessage.getBusinessId())) {
            String businessId = this.selectBusinessIdByProjectCode(jzMessage);
            jzMessage.setBusinessId(businessId);
        }
        //设置完成任务变量
        JzMessage myJzmessage = helper.setVariables(jzMessage);
        String taskId = jzMessage.getTaskId();
        //判断流程编号是否重复
        this.isRepeatProjectCode(jzMessage);
        //完成任务
        cyWfServiceImpl.completeTask(taskId, myJzmessage.getVariables(), myJzmessage.getVariablesLocal());
        //通过任务id查询任务 获取其流程实例id
        HistoricTaskInstance task = historyService.createHistoricTaskInstanceQuery().taskId(taskId).singleResult();
        String processInstanceId = null;
        if (task != null) {
            processInstanceId = task.getProcessInstanceId();
        }
        //通过流程id查询流程变量
        String choose = null;
        List<HistoricVariableInstance> historicVariableInstances = historyService.createHistoricVariableInstanceQuery().processInstanceId(processInstanceId).list();
        for (HistoricVariableInstance variableInstance : historicVariableInstances) {
            //流程变量取值 点击更换
            if (variableInstance.getVariableName().equals(StartProcessHelper.CHOOSE)) {
                if (variableInstance.getValue().toString() != null) {
                    choose = variableInstance.getValue().toString();
                }
            }
        }
        //查询历史流程
        HistoricProcessInstance hpi = historyService.createHistoricProcessInstanceQuery().processInstanceId(processInstanceId).singleResult();
        //修改jz_pro_state 流程状态,如果流程完成则修改为待提交 流程未完成 则修改为待审批，流程驳回 修改为驳回
        if (!StartProcessHelper.qdSpecialProcess().contains(choose)) {
            if (hpi.getEndTime() == null) {
                //如果流程结束时间为空，则说明任务未完成
                if (StartProcessHelper.FRONTREJECT.equals(jzMessage.getTransition())) {
                    //驳回时,设置其流程状态为 驳回
                    jzMessage.setJzProState(StartProcessHelper.OPPOSE);
                } else if (StartProcessHelper.FRORNTPASS.equals(jzMessage.getTransition()) || StartProcessHelper.COMMITTED.equals(jzMessage.getTransition())) {
                    //同意则修改其状态为待审批
                    jzMessage.setJzProState(StartProcessHelper.APPROVALPENDING);
                }
            } else {
                //流程结束时间不为空，说明流程结束,修改流程状态为 未提交
                jzMessage.setJzProState(StartProcessHelper.UNCOMMITTED);
            }
        }
        //更新流程状态
        jzMessage.setJzJdDate(new Date());
        jzMessageRepository.updateJzMessage(jzMessage);
        //3.插入表单数据
        if ((ProcessMapBpmn.BS_MODIFY_INFO.getCode().equals(choose) ||
                ProcessMapBpmn.BS_MAINTANCE_CHANGE.getCode().equals(choose))) {
            jzMessage.setProcessId(processInstanceId);
            JzMessage jzMessage1 = jzMessageRepository.selectByPrimaryKey(jzMessage);
            jzMessage.setCreateDate(jzMessage1.getCreateDate());
            messsageService.uploadJzMes(jzMessage);
        } else {
            WorkflowTaskDateMes dateMes = new WorkflowTaskDateMes();
            dateMes.setTaskId(taskId);//获取任务id
            dateMes.setJsonStr(myJzmessage.getJsonStrs());//静态json串
            dateMes.setRegionStr(myJzmessage.getFlowJsonStr());//动态json串
            dateMes.setRemarks(myJzmessage.getMsgRemarks());//备注
            dateMes.setTransition(myJzmessage.getTransition());//提交信息
            dateMes.setProcessId(processInstanceId);
            taskServiceImpl.insertDataMesByTaskId(dateMes);
        }
        return new CyPersistModel(1);
    }

    /**
     * 设置是否为自己的业务
     *
     * @param cyGridModel
     * @return
     */
    public CyCommonPageGridModel dealwith(CyGridModel cyGridModel) {
        CyCommonPageGridModel cyCommonPageGridModel = (CyCommonPageGridModel) cyGridModel;
        List<JzMessage> result = cyCommonPageGridModel.getRows();//读取row
        //boolean
        //判断是否为助理
        boolean flag = false;
        boolean managerFlag = false;
//        String loginRoles = CyUserUtil.getAuthenRoleStr();
        String[] loginRoles = CyUserUtil.getAuthenRoleStr().split("[\\,\\;]");
        log.info(CyUserUtil.getAuthenRoleStr());
        for (String value : SDictionaryServiceImpl.assistant.values()) {
            if (Arrays.asList(loginRoles).contains(value)) {
                flag = true;
                break;
            }
        }
        for (String value : SDictionaryServiceImpl.manager.values()) {
            if (Arrays.asList(loginRoles).contains(value)) {
                managerFlag = true;
                break;
            }
        }
        for (JzMessage jzMessage : result) {//判断是不是属于自己
            if (StringUtils.isEmpty(jzMessage.getJzCurUser())) {
                continue;
            }
            if (jzMessage.getJzCurUser().equals(CyUserUtil.getAuthenBusinessId())) {
                jzMessage.setIsMyBusiness("0");
            } else {
                jzMessage.setIsMyBusiness("1");
            }
            //if(boolean)
            //设置助理为1
            if (flag) {
                jzMessage.setIsAssistant("1");
            } else {
                jzMessage.setIsAssistant("0");
            }
            //设置是否为警告未处理
            if (("0".equals(jzMessage.getUwType())) && ("3".equals(jzMessage.getJzStatus())) && managerFlag) {
                jzMessage.setSelectWaringUntreated("0"); // 预警
            } else {
                jzMessage.setSelectWaringUntreated("1");
            }
        }
        return cyCommonPageGridModel;
    }

    /**
     * 导出基站信息excl文件
     *
     * @param response
     * @param jzMessage
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public HSSFWorkbook exportExcl(HttpServletResponse response, JzMessage jzMessage, List<SysDept> deptList) throws IOException {
        //查询需要导出的数据库信息
        JzMessage myJzMessage = relevance.helpPagination(jzMessage, deptList);
        myJzMessage.setExportSort("1");
        List<JzMessage> jzMessages = jzMessageRepository.queryJzMessages(myJzMessage);
        optimizeQuery.helpOptimizeQuery(jzMessages, "1");
        //excl
        HSSFWorkbook wb = new HSSFWorkbook();
        HSSFSheet sheet = wb.createSheet("基站信息");//创建工作表
        HSSFCellStyle centerStyle = wb.createCellStyle();//设置单元格居中样式
        centerStyle.setAlignment(HorizontalAlignment.CENTER);//水平居中
        centerStyle.setVerticalAlignment(VerticalAlignment.CENTER);//垂直居中
        HSSFCellStyle dateFormatStyle = wb.createCellStyle();
        HSSFDataFormat df = wb.createDataFormat();//设置数据格式
        dateFormatStyle.setDataFormat(df.getFormat("yyyy-MM-dd"));//设置单元格日期格式
        dateFormatStyle.setAlignment(HorizontalAlignment.CENTER);
        dateFormatStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        HSSFRow row = null; //创建行
        row = sheet.createRow(0);//创建第一行
        row.setHeight((short) (26.25 * 20));//设置第一行行高
        HSSFCell cell = row.createCell(0);//创建单元格
        cell.setCellValue("基站信息列表");//为第一行第一个单元格设置值
        cell.setCellStyle(centerStyle);//设置第一行单元格垂直居中
        CellRangeAddress rowRegion = new CellRangeAddress(0, 0, 0, 20);//合并单元格样式
        sheet.addMergedRegion(rowRegion);//合并单元格
        row = sheet.createRow(1);//创建第二行
        row.setHeight((short) (22.50 * 20));//设置第二行 行高
        int i, x = 0;
        //表头信息
        for (ExclEnum value : ExclEnum.values()) {
            sheet.setColumnWidth(x, value.getTranslate().getBytes().length * 240 * 2);
            sheet.setDefaultColumnStyle(x, centerStyle); //设置每列的默认属性  垂直水平居中
            row.createCell(x).setCellValue(value.getTranslate());//设置表头
            x++;
        }
        //设置excl数据
        exclUtil.setExclData(row, sheet, centerStyle, dateFormatStyle, jzMessages);
        //设置默认行高
        sheet.setDefaultRowHeight((short) (16.5 * 20));
        return wb;
    }

    /**
     * 批量插入
     */
    @Override
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public CyPersistModel batchSave(List<JzMessage> jzMessagesList) {
        List<String> businessIdList = new ArrayList<>();
        for (JzMessage item : jzMessagesList) {//设置初始状态
            if (StringUtils.isEmpty(item.getJzCurDept())) {
                item.setJzCurDept(CyUserUtil.getAuthenDept());
            }
            if ((!StringUtils.isEmpty(item.getJzType())) && item.getJzType().equals("0")) {
                item.setJzState("2");
            } else {
                item.setJzState("3");
                item.setJzProState("0");
            }
            item.setJzJdWaring("0");
            item.setJzJdDate(new Date());
            CyUserUtil.setCurrentPersistOperation(item);
            businessIdList.add(item.getBusinessId());
        }
        List<HiJzMessage> hiJzMessageList = new ArrayList<>();
        for (int i = 0; i < jzMessagesList.size(); i++) {
            this.setProjectId(jzMessagesList.get(i), i);
            HiJzMessage hiJzMessage = jzMessageToHistory(jzMessagesList.get(i));
            hiJzMessage.setJzVersion(1);
            hiJzMessageList.add(hiJzMessage);
        }
        jzMessageRepository.batchInsert(jzMessagesList);
        hiJzMessageRepository.batchInsert(hiJzMessageList);
        this.dbInfo(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                businessIdList.toString() + "的信息", "新增");
        return new CyPersistModel(1);
    }

    /**
     * 插入基站信息时设置项目Id
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public JzMessage setImportMessage(JzMessage jzMessage, int count) {
        JzMessage jzMessage1 = new JzMessage();
        jzMessage1.setNormal();
        jzMessage1.setProjectCode(jzMessage.getProjectCode());
        JzMessage jzMessages2 = jzMessageRepository.queryProjectCodeExcel(jzMessage1);
        //判断项目编号是否重复
        if (jzMessages2 != null) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZ_CODE_ERROR);
        }
        SDictionary sDictionary = new SDictionary();
        sDictionary.setNormal();
        List<String> typeList = new ArrayList();
        typeList.add(DictionaryMap.deptForShort);
        sDictionary.setTypeList(typeList);
        String deptId = sysDeptServiceImpl.findById(CyUserUtil.getAuthenDept()).getParentId();
        while (!StringUtils.isEmpty(sysDeptServiceImpl.findById(sysDeptServiceImpl.findById(deptId).getParentId()).getParentId())) {
            SysDept sysDept = sysDeptServiceImpl.findById(deptId);
            deptId = sysDept.getParentId();
        }
        sDictionary.setValue(sysDeptServiceImpl.findById(deptId).getCode());
        List<SDictionary> sDictionaries = sDictionaryRepository.queryByType(sDictionary);
        if (CollectionUtils.isEmpty(sDictionaries)) {
            throw new CyServiceException(ResultServiceExceptionEnums.SDictionary_NULL_ERROR);
        }
        jzMessage1.setJzProjectId(sDictionaries.get(0).getName());//获取部门简称
        List<JzMessage> jzMessages = jzMessageRepository.queryJzProjectId(jzMessage1);
        String str3;
        if (CollectionUtils.isEmpty(jzMessages)) {
            str3 = sDictionaries.get(0).getName() + String.format("%08d", count + 1);
        } else {
            String str = jzMessages.get(0).getJzProjectId();//获取最大项目编号
            str.trim();
            String str2 = new String();
            if (str != null && !"".equals(str)) {//提取编号中第一位非0及以后数字
                for (int i = 0; i < str.length(); i++) {
                    if (str.charAt(i) >= 48 && str.charAt(i) <= 57) {
                        str2 += str.charAt(i);
                    }
                }
            }
            str3 = sDictionaries.get(0).getName() + String.format("%08d", Integer.valueOf(str2) + count + 1);//最大项目编号加1
        }
        jzMessage.setJzProjectId(str3);
        return jzMessage;
    }

    /**
     * 三级经理直接更换业务员
     *
     * @param jzMessageId
     * @param userId
     * @return
     */
    @Override
    public CyPersistModel changeUser(String jzMessageId, String userId) {
        JzMessage jzMessage;
        HiJzMessage hiJzMessage;
        jzMessage = jzMessageRepository.jzmessageByBusinessId(jzMessageId);
        //更新基站信息表
        if (StringUtils.isNotEmpty(userId) || !("".equals(userId))) {
            //插入历史表(仅更换插入)
            hiJzMessage = ChangeUtil.jzMessageToHistory(jzMessage);
            hiJzMessage.setJzId(jzMessageId);//设置基站id
            hiJzMessage.setNormal();
            hiJzMessage.setJzCurUser(userId);
            Map maxVersion = hiJzMessageRepository.getMaxVersionByJzId(hiJzMessage);//获得最高版本
            if (maxVersion != null && maxVersion.containsKey("jzVersion")) {//插入新的版本
                hiJzMessage.setJzVersion(Integer.parseInt(maxVersion.get("jzVersion").toString()) + 1);
            } else {
                hiJzMessage.setJzVersion(1);
            }
            hiJzMessage.setJzWaitReason(RegionEnum.CHANGESALESMAN.getReason());//插入原因
            hiJzMessageServiceImpl.save(hiJzMessage);
            jzMessage.setJzCurUser(userId);
        }
        //设置插入金蝶标识为0可插入 当项目编号不为空时或者为移动会审铁塔立项时
        if (StringUtils.isNotEmpty(jzMessage.getProjectCode())
                || BaseStationStatus.MC_WAIT_TRIAGE.getCode().equals(jzMessage.getJzState())
                || BaseStationStatus.IT_WAIT_APPROVAL.getCode().equals(jzMessage.getJzState())) {
            jzMessage.setIsImport(0);
        }
        jzMessage.setJzJdWaring("0");
        jzMessage.setJzJdDate(new Date());
//        jzMessageRepository.updateJzMessage(jzMessage);
        jzMessageRepository.updateByPrimaryKey(jzMessage);
        //消除预警
        UserWarning userWarning = new UserWarning();
        userWarning.setJzId(jzMessageId);
        userWarning.setJzStatus(jzMessage.getJzState());
        userWarningServiceImpl.dealWarning(userWarning);
        return new CyPersistModel(1);
    }

    /**
     * 判断当前基站状态
     *
     * @param id
     * @return
     */
    @Override
    public String findJzMessage(String id) {
        //查询基站信息
        String states = null;//1,可以拆站 不可以需求取消 2，可以需求取消，不可以拆站 3 当前状态下不能需求取消,可以拆站  0 都不能拆站不能需求取消,5不是自己的业务,4在流程中
        JzMessage jzMessage = jzMessageRepository.selectByPrimaryKey(id);
        String curId = CyUserUtil.getAuthenBusinessId();
        if (!(jzMessage.getJzCurUser().equals(curId))) {
            return "5";
        }
        if (jzMessage.getJzState().equals("18")) {
            return "4";
        }
        if (jzMessage.getJzState().equals("0")) {
            return "6";
        }
        if (
//                jzMessage.getJzState().equals("0") ||
                jzMessage.getJzState().equals("1") ||
//                jzMessage.getJzState().equals("18") ||
                        jzMessage.getJzState().equals("19")) {
            //当前状态下都不能拆站，需求取消
            states = "0";
        } else {
            if (jzMessage.getJzType().equals(helper.PAYMENTSTATION)) {
                //代缴站
                if (Integer.parseInt(jzMessage.getJzState()) == 2) {
                    //当前状态可以拆站
                    states = "1";
                }
            } else if (jzMessage.getJzType().equals(helper.RAILCOM)) {
                //移动
                if (Integer.parseInt(jzMessage.getJzState()) < 13) {
                    //当前状态下可以需求取消，不可以拆站
                    states = "2";
                } else {
                    //当前状态下不能需求取消,可以拆站
                    states = "3";
                }
                //移动
//           if (Integer.parseInt(jzMessage.getJzState())>=13){
//               //当前状态下可以拆站
//                okchaizhang="1";
//           }else{
//               //当前状态下不可以拆站
//               return nochaizhang;
//           }
            } else if (jzMessage.getJzType().equals(helper.FILGHTNUMBER)) {
                //铁塔站
                if (Integer.parseInt(jzMessage.getJzState()) < 14) {
                    //当前状态下可以需求取消，不可以拆站
                    states = "2";
                } else {
                    //当前状态下不能需求取消,可以拆站
                    states = "3";
                }
            }
        }
        return states;
    }

    @Override
    public String loginSuccess(String originId, String key) {
        //获取redis key
        log.debug("------------cy------------" + originId + 771);
        log.debug("------------cy------------" + key + 772);
        String keyDest = RedisUserUtil.getKey(originId, key);
        log.debug("------------cy------------" + keyDest + 762);
        if (null == keyDest)
            return null;
        Object keyUser = cyRedisService.get(keyDest);
        log.debug("------------cy------------" + keyUser + 765);
        if (null == keyUser)
            return null;
        //解析
        String mid = "";
        try {
            JSONObject objUser = JSONObject.parseObject(keyUser.toString());
            mid = objUser.getString("user_id");
            log.debug("------------cy------------" + mid + 774);
        } catch (Exception e) {
            return null;
        }
        SysUser user = sysUserRepository.selectByPrimaryKey(mid);
        if (null == user)
            return null;
        UsernamePasswordAuthenticationToken upToken = new UsernamePasswordAuthenticationToken(user.getLoginName(), user.getLoginName());
        /*进入到 UserDetailsService(JwtUserDetailServiceImpl)  loadUserByUsername 方法*/
        final Authentication authentication = authenticationManager.authenticate(upToken);
        final UserDetails userDetails = (UserDetails) authentication.getPrincipal();
        final String token = CyJwtUtil.generateToken(userDetails);
        SecurityContextHolder.getContext().setAuthentication(authentication);
        return token;
    }

    /**
     * 判断项目编号是否重复
     */
    public void isRepeatProjectCode(JzMessage jzMessage) {
        jzMessage.setNormal();
        //判断projectId 是否有重复
        if (StringUtils.isNotEmpty(jzMessage.getSelect())) {
            if (ProcessMapBpmn.MC_JOINT_HEARING.getCode().equals(jzMessage.getSelect()) ||
                    ProcessMapBpmn.IT_PROJECT_APPROVAL.getCode().equals(jzMessage.getSelect())) {
                JzMessage jzMessage1 = CommonMethod.jsonToData(jzMessage);
                jzMessage1.setNormal();
                if (null != jzMessage1) {
                    if (StringUtils.isNotEmpty(jzMessage1.getProjectCode())) {
                        if ((jzMessageRepository.queryprojectCodeByBusinessId(jzMessage)).contains(jzMessage1.getProjectCode())) {
                            throw new CyServiceException(ResultServiceExceptionEnums.JZ_CODE_ERROR);
                        }
                    }
                }
            }
        } else {
            JzMessage jzMessage1 = CommonMethod.jsonToData(jzMessage);
            if (null != jzMessage1) {
                if (StringUtils.isNotEmpty(jzMessage1.getProjectCode()) && !StartProcessHelper.FRONTREJECT.equals(jzMessage.getTransition())) {
                    if ((jzMessageRepository.queryprojectCodeByBusinessId(jzMessage)).contains(jzMessage1.getProjectCode())) {
                        throw new CyServiceException(ResultServiceExceptionEnums.JZ_CODE_ERROR);
                    }
                }
            }
        }
    }

    /**
     * 金蝶判断项目编号为空
     */
    public boolean kingdeeIsRepeat(String projectCode) {
        boolean kingdee = false;
        if ((jzMessageRepository.queryprojectCode()).contains(projectCode)) {
            kingdee = true;

        }
        return kingdee;
    }

    /**
     * 导入基站信息时设置项目Id
     *
     * @param jzMessage
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public JzMessage setProjectId(JzMessage jzMessage, int count) {
        JzMessage jzMessage1 = new JzMessage();
        jzMessage1.setNormal();
        jzMessage1.setProjectCode(jzMessage.getProjectCode());
        JzMessage jzMessages2 = jzMessageRepository.queryProjectCodeExcel(jzMessage1);
        //判断项目编号是否重复
        if (jzMessages2 != null) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZ_CODE_ERROR);
        }
        //获取所有部门
        SysDept sysDept = new SysDept();
        sysDept.setNormal();
        List<SysDept> sysDepts = sysDeptServiceImpl.findAll(sysDept);
        //获取当前登陆人所属的分公司
        String deptCode = jzMessage.getJzCurDept();
        String companyId = FindSon.FindCompany(deptCode, deptCode, sysDepts);
        String gsCompany = SDictionaryServiceImpl.deptForShort.get(companyId);

        jzMessage1.setJzProjectId(gsCompany);
        List<JzMessage> jzMessages = jzMessageRepository.queryJzProjectId(jzMessage1);
        String str3;
        if (CollectionUtils.isEmpty(jzMessages)) {
            str3 = gsCompany + String.format("%08d", count + 1);
        } else {
            String str = jzMessages.get(0).getJzProjectId();//获取最大项目编号
            str.trim();
            String str2 = new String();
            if (str != null && !"".equals(str)) {//提取编号中第一位非0及以后数字
                for (int i = 0; i < str.length(); i++) {
                    if (str.charAt(i) >= 48 && str.charAt(i) <= 57) {
                        str2 += str.charAt(i);
                    }
                }
            }
            str3 = gsCompany + String.format("%08d", Integer.valueOf(str2) + count + 1);//最大项目编号加1
        }
        jzMessage.setJzProjectId(str3);
        return jzMessage;
    }

    //改变用户是否在流程中
    @Override
    public CyResult isChangeUserInProcess(JzMessage jzMessage) {

        for (ProcessMapBpmn value : ProcessMapBpmn.values()) {
            if (value.getCode().equals(jzMessage.getSelect())) {
                jzMessage.setTypeTemplate(value.getTypeTemplate());
            }
        }
        if (!CollectionUtils.isEmpty(processMidRepository.queryCurProExist(jzMessage))) {
            //当前阶段 是否有未结束的流程
            throw new CyServiceException(ResultServiceExceptionEnums.STAGE_LEADER_CHANGE_INPROCESS);
        }
        return null;
    }

    /**
     * 取消 需求取消
     *
     * @param jzMessage
     * @return
     */
    @Override
    @Transactional
    public CyResult cancelNeed(JzMessage jzMessage) {
        jzMessage.setNormal();
        JzMessage jzMessage1 = jzMessageRepository.selectByPrimaryKey(jzMessage);
        Task task = taskService.createTaskQuery().taskId(jzMessage.getTaskId()).singleResult();
        if ("0".equals(jzMessage1.getJzState())) {
            cyWfServiceImpl.deleteProcessInstance(task.getProcessInstanceId(), RegionEnum.CANCLENEED.getKey());
        }
        //还原基站流程状态和基站状态
        jzMessage.setJzProState(jzMessage1.getOriginalProState());
        jzMessage.setJzState(jzMessage1.getOriginalState());
        jzMessageRepository.updateJzMessage(jzMessage);
        return null;
    }



    /**
     * 金蝶添加
     */
    @Override
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public CyPersistModel KingDeeSave(JzMessage jzMessage) {
        String key = null;
        //代缴站运营商
        Set<String> set = SDictionaryServiceImpl.jzDjYys.keySet();
        //铁塔运营商
        Set<String> set1 = SDictionaryServiceImpl.jzTtYys.keySet();
        //移动运营商
        Set<String> set2 = SDictionaryServiceImpl.jzYdYys.keySet();
        //移动上游客户
        Set<String> set3 = SDictionaryServiceImpl.optimizeJzYdUpper.keySet();
        Collection<String> values = SDictionaryServiceImpl.optimizeJzYdUpper.values();
        //铁塔上游客户
        Set<String> set4 = SDictionaryServiceImpl.optimizeJzTtUpper.keySet();
        Collection<String> ttupdateValue = SDictionaryServiceImpl.optimizeJzTtUpper.values();
        //业务线
        Set<String> set5 = SDictionaryServiceImpl.optimizeJzYwx.keySet();
        Collection<String> YwxValues = SDictionaryServiceImpl.optimizeJzYwx.values();
        //区域
        Set<String> set6 = SDictionaryServiceImpl.jzQy.keySet();
        if (jzMessage.getJzType().contains("代缴")) {
            jzMessage.setJzType(TypeEnum.DJ.getkey());
            //基站状态
            String jzState = EnumUtil.EnumUtilDJ(jzMessage.getJzState(),KingAddJzDJ.values());
            if (StringUtils.isNotEmpty(jzState)) {
                jzMessage.setJzState(jzState);
            } else {
                log.error("项目编号为" + jzMessage.getProjectCode() + "的基站状态不存在" + jzMessage.getJzState());
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "的基站状态不存在" + jzMessage.getJzState());
                return new CyPersistModel(0);
            }
            if (set.contains(jzMessage.getJzYys())) {
                jzMessage.setJzYys(SDictionaryServiceImpl.jzDjYys.get(jzMessage.getJzYys()));
            } else if (StringUtils.isNotEmpty(jzMessage.getJzYys())) {
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "该代缴站的运营商不存在,运营商" + jzMessage.getJzYys());
                log.error("项目编号为" + jzMessage.getProjectCode() + "该代缴站的运营商不存在,运营商" + jzMessage.getJzYys());
                return new CyPersistModel(0);
            }
            if (StringUtils.isNotEmpty(jzMessage.getJzUpCustom())) {
                //代缴站不存在上游客户
                jzMessage.setJzUpCustom("");
            }
        } else if (jzMessage.getJzType().contains("移动")) {
            jzMessage.setJzType(TypeEnum.YD.getkey());
            //基站状态
            String jzState = EnumUtil.EnumUtilMM(jzMessage.getJzState(),KingAddJzMD.values());
            if (StringUtils.isNotEmpty(jzState)) {
                jzMessage.setJzState(jzState);
            } else {
                log.error("项目编号为" + jzMessage.getProjectCode() + "的基站状态不存在" + jzMessage.getJzState());
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "的基站状态不存在" + jzMessage.getJzState());
                return new CyPersistModel(0);
            }
            if (set2.contains(jzMessage.getJzYys())) {
                jzMessage.setJzYys(SDictionaryServiceImpl.jzYdYys.get(jzMessage.getJzYys()));
            } else if (StringUtils.isNotEmpty(jzMessage.getJzYys())) {
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "该移动的运营商不存在,运营商" + jzMessage.getJzYys());
                log.error("项目编号为" + jzMessage.getProjectCode() + "该移动的运营商不存在,运营商" + jzMessage.getJzYys());
                return new CyPersistModel(0);
            }
            if (values.contains(jzMessage.getJzUpCustom())) {
                for (String key1 : set3) {
                    if (SDictionaryServiceImpl.optimizeJzYdUpper.get(key1).equals(jzMessage.getJzUpCustom())) {
                        key = key1;
                        break;
                    }
                }
                jzMessage.setJzUpCustom(key);
            } else if (StringUtils.isNotEmpty(jzMessage.getJzUpCustom())) {
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "该移动的上游客户不存在,上游客户" + jzMessage.getJzUpCustom());
                log.error("项目编号为" + jzMessage.getProjectCode() + "该移动的上游客户不存在,上游客户" + jzMessage.getJzUpCustom());
                return new CyPersistModel(0);
            }
        } else if (jzMessage.getJzType().contains("铁塔")) {
            jzMessage.setJzType(TypeEnum.TT.getkey());
            //基站状态
            String jzState = EnumUtil.EnumUtilTT(jzMessage.getJzState(),KingAddJzTT.values());
            if (StringUtils.isNotEmpty(jzState)) {
                jzMessage.setJzState(jzState);
            } else {
                log.error("项目编号为" + jzMessage.getProjectCode() + "的基站状态不存在" + jzMessage.getJzState());
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "的基站状态不存在" + jzMessage.getJzState());
                return new CyPersistModel(0);
            }
            if (set1.contains(jzMessage.getJzYys())) {
                jzMessage.setJzYys(SDictionaryServiceImpl.jzTtYys.get(jzMessage.getJzYys()));
            } else if (StringUtils.isNotEmpty(jzMessage.getJzYys())) {
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "该铁塔的运营商不存在,运营商" + jzMessage.getJzYys());
                log.error("项目编号为" + jzMessage.getProjectCode() + "该铁塔的运营商不存在,运营商" + jzMessage.getJzYys());
                return new CyPersistModel(0);
            }
            if (ttupdateValue.contains(jzMessage.getJzUpCustom())) {
                for (String key1 : set4) {
                    if (SDictionaryServiceImpl.optimizeJzTtUpper.get(key1).equals(jzMessage.getJzUpCustom())) {
                        key = key1;
                    }
                }
                jzMessage.setJzUpCustom(key);
            } else if (StringUtils.isNotEmpty(jzMessage.getJzUpCustom())) {
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "该铁塔的上游客户不存在,上游客户" + jzMessage.getJzUpCustom());
                log.error("项目编号为" + jzMessage.getProjectCode() + "该铁塔的上游客户不存在,上游客户" + jzMessage.getJzUpCustom());
                return new CyPersistModel(0);
            }

        } else {
            log.error("项目编号为" + jzMessage.getProjectCode() + "的基站类型不存在" + jzMessage.getJzType());
            this.dbError("项目编号为" + jzMessage.getProjectCode() + "的基站类型不存在,基站类型" + jzMessage.getJzType());
            return new CyPersistModel(0);
        }
        //业务线
        if (YwxValues.contains(jzMessage.getBusinessLine())) {
            for (String businessLine : set5) {
                if (SDictionaryServiceImpl.optimizeJzYwx.get(businessLine).equals(jzMessage.getBusinessLine())) {
                    jzMessage.setBusinessLine(businessLine);
                    break;
                }
            }
        } else if (StringUtils.isNotEmpty(jzMessage.getBusinessLine())) {
            log.error("项目编号为" + jzMessage.getProjectCode() + "的基站业务线不存在" + jzMessage.getBusinessLine());
            this.dbError("项目编号为" + jzMessage.getProjectCode() + "的基站业务线不存在" + jzMessage.getBusinessLine());
            return new CyPersistModel(0);
        }
        //区域
        if (set6.contains(jzMessage.getJzQy())) {
            jzMessage.setJzQy(SDictionaryServiceImpl.jzQy.get(jzMessage.getJzQy()));
        } else if (StringUtils.isNotEmpty(jzMessage.getJzQy())) {
            log.error("项目编号为" + jzMessage.getProjectCode() + "的基站区域不存在" + jzMessage.getJzQy());
            this.dbError("项目编号为" + jzMessage.getProjectCode() + "的基站区域不存在" + jzMessage.getJzQy());
            return new CyPersistModel(0);
        }
        //经度
        if ("0".equals(jzMessage.getJzLongitude()) || (null == jzMessage.getJzLongitude()) || StringUtils.isEmpty(jzMessage.getJzLongitude().toString())) {
            jzMessage.setJzLongitude(new BigDecimal(0.000000));
        }
        //纬度
        if ("0".equals(jzMessage.getJzLatitude()) || (null == jzMessage.getJzLatitude()) || StringUtils.isEmpty(jzMessage.getJzLatitude().toString())) {
            jzMessage.setJzLatitude(new BigDecimal(0.000000));
        }
        //部门
        boolean isSysDept = true;
        SysDept sysDept = new SysDept();
        sysDept.setNormal();
        List<SysDept> SysDeptall = sysDeptServiceImpl.findAll(sysDept);
        for (SysDept sysDept1 : SysDeptall) {
            if (jzMessage.getJzCurDept().equals(sysDept1.getName())) {
                jzMessage.setJzCurDept(sysDept1.getCode());
                isSysDept = false;
                break;
            }
        }
        if (isSysDept && StringUtils.isNotEmpty(jzMessage.getJzCurDept())) {
            log.error("项目编号为" + jzMessage.getProjectCode() + "的部门不存在" + jzMessage.getJzCurDept());
            this.dbError("项目编号为" + jzMessage.getProjectCode() + "的部门不存在" + jzMessage.getJzCurDept());
            return new CyPersistModel(0);
        }
        //用户
        List<SUser> sUsers = sUserRepository.queryAllUserInfoByDept(jzMessage.getJzCurDept());
        if (!CollectionUtils.isEmpty(sUsers)) {
            boolean isSysUser = true;
            boolean isOwnern = true;
            for (SUser suser : sUsers) {
                if (jzMessage.getJzCurUser().equals(suser.getName())) {
                    jzMessage.setJzCurUser(suser.getBusinessId());
                    isSysUser = false;
                    break;
                }
            }
            if (isSysUser && StringUtils.isNotEmpty(jzMessage.getJzCurUser())) {
                log.error("项目编号为" + jzMessage.getProjectCode() + "的业务员不存在" + jzMessage.getJzCurUser());
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "的业务员不存在" + jzMessage.getJzCurUser());
                return new CyPersistModel(0);
            }
            for (SUser suser : sUsers) {
                if (jzMessage.getJzProjectOwner().equals(suser.getName())) {
                    jzMessage.setJzProjectOwner(suser.getBusinessId());
                    isOwnern = false;
                    break;
                }
            }
            if (isOwnern && StringUtils.isNotEmpty(jzMessage.getProjectOwner())) {
                log.error("项目编号为" + jzMessage.getProjectCode() + "的项目负责人不存在" + jzMessage.getJzProjectOwner());
                this.dbError("项目编号为" + jzMessage.getProjectCode() + "的项目负责人不存在" + jzMessage.getJzProjectOwner());
                return new CyPersistModel(0);
            }
        }

        if (StringUtils.isNotEmpty(jzMessage.getProjectCode())) {
          if (kingdeeIsRepeat(jzMessage.getProjectCode())){
              log.error("项目编号为" + jzMessage.getProjectCode()+"重复");
              this.dbError("项目编号为" + jzMessage.getProjectCode()+"重复");
              return new CyPersistModel(0);
          }
        }
        jzMessage.setJzProState("0");
        jzMessage.setJzJdWaring("0");
        jzMessage.setIsImport(0);
        jzMessage.setProjectCodeImport(0);
        jzMessage.setJzJdDate(new Date());
        this.setProjectId(jzMessage, 0);
        CyUserUtil.setCurrentPersistOperation(jzMessage);
        HiJzMessage hiJzMessage = jzMessageToHistory(jzMessage);
        hiJzMessage.setJzVersion(1);
        jzMessageRepository.insertSelective(jzMessage);
        hiJzMessageRepository.insertSelective(hiJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                jzMessage.toString() + "的信息", "新增");
        return new CyPersistModel(1);
    }

    /**
     * 判断当前流程是否结束
     * @param templateType
     * @param projectCode
     * @return
     */
    @Override
    public Boolean processIsEnd(String templateType, String projectCode) {
        boolean i = true;
        List<JzMessage> jzMessages = jzMessageRepository.processIsEnd(templateType, projectCode);
        if (jzMessages.size()>0){
            i =false;
        }
        return i;
    }

    @Override
    public CyPersistModel changeStatus(String projectCode) {
        if (StringUtils.isNotEmpty(projectCode)){
            int i = jzMessageRepository.updateByprojecetCode(projectCode,"3");
           return new CyPersistModel(i);
        }
        return new CyPersistModel(0);
    }
}