package org.rcisoft.business.jzmessage.util;

import com.alibaba.druid.sql.visitor.functions.If;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.rcisoft.business.jzmessage.common.DictionaryMap;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.sdictionary.dao.SDictionaryRepository;
import org.rcisoft.business.sdictionary.entity.SDictionary;
import org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl;
import org.rcisoft.common.BaseStationStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

@Slf4j
@Component
public class ExclUtil {
    @Autowired
    SDictionaryRepository sDictionaryRepository;

    private static final String ZERONUMBER = "0";

    private static final String ONENUMBER = "1";

    private static final String TWONUMBER = "2";

    private static final String THREENUMBER = "3";

    //类型
    private static final String PAYMENTSTATION = "代缴站";

    private static final String RAILCOM = "移动";

    private static final String RAILTOWER = "铁塔";

    public void setExclData(HSSFRow row, HSSFSheet sheet, HSSFCellStyle centerStyle, HSSFCellStyle dataFormatStyle, List<JzMessage> jzMessages) {
        //设置表格数据
        for (int j = 0; j < jzMessages.size(); j++) {
            row = sheet.createRow(j + 2);
            //获取每一列的数据
            JzMessage exclData = jzMessages.get(j);
            if (exclData.getJzCode() != null && exclData.getJzCode() != "") {
                row.createCell(0).setCellValue(exclData.getJzCode());//基站号
            }
            row.createCell(1).setCellValue(exclData.getJzName());//基站名
            row.createCell(2).setCellValue(exclData.getProjectCode());//项目编号
           /* if (exclData.getBusinessLine() != null) {
                row.createCell(3).setCellValue(tranField(exclData.getBusinessLine(), ZERONUMBER));//业务线
            }*/
            if (exclData.getBusinessLine() != null) {
                row.createCell(3).setCellValue(exclData.getYwxName());//业务线
            }
           /* if (exclData.getYysDjName() != null || exclData.getYysYdName() != null || exclData.getYysTtName() != null) {
                if("0".equals(exclData.getJzType())){
                    row.createCell(4).setCellValue(exclData.getYysDjName());//运营商
                } else if("1".equals(exclData.getJzType())){
                    row.createCell(4).setCellValue(exclData.getYysYdName());//运营商
                } else if("2".equals(exclData.getJzType())){
                    row.createCell(4).setCellValue(exclData.getYysTtName());//运营商
                }
            }*/
           if (StringUtils.isNotEmpty(exclData.getJzYys())){
               row.createCell(4).setCellValue(exclData.getYysName());//运营商
           }
            if (StringUtils.isNotEmpty(exclData.getJzRequire())) {
                row.createCell(5).setCellValue(exclData.getJzRequire());//需求号
            }
            row.createCell(6).setCellValue(exclData.getJzLocationName());//区域
            if (exclData.getProjectAddress() != null) {
                row.createCell(7).setCellValue(exclData.getProjectAddress());//项目地址
            }
            row.createCell(8).setCellValue(tranJzType(exclData.getJzType()));//类型
            row.createCell(9).setCellValue(tranJzState(exclData.getJzType(), exclData.getJzState()));//基站状态
            row.createCell(10).setCellValue(exclData.getCurUserName());//阶段负责人
            if (exclData.getProjectOwner() != null) {
                row.createCell(11).setCellValue(exclData.getProjectOwner());//项目负责人
            }
            row.createCell(12).setCellValue(exclData.getCurDeptName());//部门
            /*if (exclData.getJzUpCustom() != null) {
                row.createCell(13).setCellValue(tranField(exclData.getJzUpCustom(), TWONUMBER));//上游客户
            }*/
            if (exclData.getJzUpCustom() != null) {
                row.createCell(13).setCellValue(exclData.getUpperName());//上游客户
            }
            /*if (StringUtils.isNotEmpty(exclData.getJzConstruct())) {
                row.createCell(14).setCellValue(tranField(exclData.getJzConstruct(), ONENUMBER));//建设方式 0 飞箱 , 1 微站
            }*/
            if (StringUtils.isNotEmpty(exclData.getJzConstruct())) {
                row.createCell(14).setCellValue(exclData.getJzBuildName());//建设方式 0 飞箱 , 1 微站
            }
            if (exclData.getJzMobileRelation() != null) {
                row.createCell(15).setCellValue(exclData.getJzMobileRelation());//移动关系
            }
            if (exclData.getJzMobilePhone() != null) {
                row.createCell(16).setCellValue(exclData.getJzMobilePhone());//移动联系方式
            }
            if (exclData.getJzLongitude() != null) {
                row.createCell(17).setCellValue(exclData.getJzLongitude().doubleValue());//经度
            }
            if (exclData.getJzLatitude() != null) {
                row.createCell(18).setCellValue(exclData.getJzLatitude().doubleValue());//纬度
            }
            if(exclData.getJzEwm() != null){
                row.createCell(19).setCellValue(exclData.getJzEwm());
            }
            /*if (exclData.getCreateDate() != null) {
                row.createCell(19).setCellValue(exclData.getCreateDate());//纬度
            }*/
            log.debug("状态：" + exclData.getCreateDate());
            HSSFCell dateCell = row.createCell(20);
            if (exclData.getCreateDate() != null) {
                dateCell.setCellValue(exclData.getCreateDate());//基站创建日dateCell.setCellStyle(dataFormatStyle);
            }
            dateCell.setCellStyle(dataFormatStyle);//设置日期格式
        }
    }

    //基站类型数字转换
    public String tranJzType(String jzType) {
        if (ZERONUMBER.equals(jzType)) {
            return PAYMENTSTATION;
        } else if (ONENUMBER.equals(jzType)) {
            return RAILCOM;
        } else if (TWONUMBER.equals(jzType)) {
            return RAILTOWER;
        }
        return null;
    }

    //基站状态转换
    public String tranJzState(String jzType, String jzState) {
        //代缴站
        if (ZERONUMBER.equals(jzType)) {
            if (BaseStationStatus.DJ_HAVE_OPEN.getCode().equals(jzState)) {
                //已开通
                return BaseStationStatus.DJ_HAVE_OPEN.getStatus();
            }else if (BaseStationStatus.BS_HAVE_STANDOWN.getCode().equals(jzState)) {
                //已拆站
                return BaseStationStatus.BS_HAVE_STANDOWN.getStatus();
            }
        }//铁通(移动)
        else if (ONENUMBER.equals(jzType)) {
            if (BaseStationStatus.BS_CANALE_REQUIREMENT.getCode().equals(jzState)) {
                //基站状态为 0 返回 需求取消
                return BaseStationStatus.BS_CANALE_REQUIREMENT.getStatus();
            } else if (BaseStationStatus.BS_HAVE_CANCLE.getCode().equals(jzState)) {
                //基站状态为1 返回 已取消
                return BaseStationStatus.BS_HAVE_CANCLE.getStatus();
            } else if (BaseStationStatus.MC_WAIT_LOCATION.getCode().equals(jzState)) {
                //基站状态为3 返回 选址
                return BaseStationStatus.MC_WAIT_LOCATION.getStatus();
            } else if (BaseStationStatus.MC_WAIT_PROSPECT.getCode().equals(jzState)) {
                //基站状态为4 返回 勘察
                return BaseStationStatus.MC_WAIT_PROSPECT.getStatus();
            } else if (BaseStationStatus.MC_WAIT_TRIAGE.getCode().equals(jzState)) {
                //基站状态为5 返回会审
                return BaseStationStatus.MC_WAIT_TRIAGE.getStatus();
            } else if (BaseStationStatus.MC_WAIT_DISCLOSURE.getCode().equals(jzState)) {
                //基站状态为6 返回交底
                return BaseStationStatus.MC_WAIT_DISCLOSURE.getStatus();
            } else if (BaseStationStatus.MC_WAIT_PACKING.getCode().equals(jzState)) {
                //基站状态为8 返回 领料
                return BaseStationStatus.MC_WAIT_PACKING.getStatus();
            } else if (BaseStationStatus.MC_WAIT_EXECUTION.getCode().equals(jzState)) {
                //基站状态为9 返回施工
                return BaseStationStatus.MC_WAIT_EXECUTION.getStatus();
            } else if (BaseStationStatus.MC_WAIT_OPEN.getCode().equals(jzState)) {
                //开通
                return BaseStationStatus.MC_WAIT_OPEN.getStatus();
            } else if (BaseStationStatus.MC_WAIT_CAPITAL.getCode().equals(jzState)) {
                //交资
                return BaseStationStatus.MC_WAIT_CAPITAL.getStatus();
            } else if (BaseStationStatus.MC_WAIT_MAINTAIN.getCode().equals(jzState)) {
                //交维
                return BaseStationStatus.MC_WAIT_MAINTAIN.getStatus();
            } else if (BaseStationStatus.BS_HAVE_MAINTAIN.getCode().equals(jzState)) {
                //已交维
                return BaseStationStatus.BS_HAVE_MAINTAIN.getStatus();
            } else if (BaseStationStatus.BS_WAIT_STANDOWN.getCode().equals(jzState)) {
                //拆站
                return BaseStationStatus.BS_WAIT_STANDOWN.getStatus();
            } else if (BaseStationStatus.BS_HAVE_STANDOWN.getCode().equals(jzState)) {
                //已拆站
                return BaseStationStatus.BS_HAVE_STANDOWN.getStatus();
            }

        }
        //航数(铁塔)
        else if (TWONUMBER.equals(jzType)) {
            if (BaseStationStatus.BS_CANALE_REQUIREMENT.getCode().equals(jzState)) {
                //基站状态为 0 返回 需求取消
                return BaseStationStatus.BS_CANALE_REQUIREMENT.getStatus();
            } else if (BaseStationStatus.BS_HAVE_CANCLE.getCode().equals(jzState)) {
                //基站状态为1 返回 已取消
                return BaseStationStatus.BS_HAVE_CANCLE.getStatus();
            } else if (BaseStationStatus.IT_WAIT_LOCATION.getCode().equals(jzState)) {
                //基站状态为3 返回 选址
                return BaseStationStatus.IT_WAIT_LOCATION.getStatus();
            } else if (BaseStationStatus.IT_WAIT_PROSPECT.getCode().equals(jzState)) {
                //基站状态为4 返回 勘察
                return BaseStationStatus.IT_WAIT_PROSPECT.getStatus();
            } else if (BaseStationStatus.IT_WAIT_TRIAGE.getCode().equals(jzState)) {
                //基站状态为5 返回会审
                return BaseStationStatus.IT_WAIT_TRIAGE.getStatus();
            } else if (BaseStationStatus.IT_WAIT_APPROVAL.getCode().equals(jzState)) {
                //基站状态为6 返回交底
                return BaseStationStatus.IT_WAIT_APPROVAL.getStatus();
            } else if (BaseStationStatus.IT_WAIT_PACKING.getCode().equals(jzState)) {
                //基站状态为8 返回 领料
                return BaseStationStatus.IT_WAIT_PACKING.getStatus();
            } else if (BaseStationStatus.IT_WAIT_EXECUTION.getCode().equals(jzState)) {
                //基站状态为9 返回施工
                return BaseStationStatus.IT_WAIT_EXECUTION.getStatus();
            } else if (BaseStationStatus.IT_WAIT_COMPLETION.getCode().equals(jzState)) {
                //完工
                return BaseStationStatus.IT_WAIT_COMPLETION.getStatus();
            } else if (BaseStationStatus.IT_WAIT_DELIVERY.getCode().equals(jzState)) {
                //交付
                return BaseStationStatus.IT_WAIT_DELIVERY.getStatus();
            } else if (BaseStationStatus.IT_WAIT_ONHIRE.getCode().equals(jzState)) {
                //起租
                return BaseStationStatus.IT_WAIT_ONHIRE.getStatus();
            } else if (BaseStationStatus.IT_WAIT_MAINTAIN.getCode().equals(jzState)) {
                //交维
                return BaseStationStatus.IT_WAIT_MAINTAIN.getStatus();
            } else if (BaseStationStatus.BS_HAVE_MAINTAIN.getCode().equals(jzState)) {
                //已交维
                return BaseStationStatus.BS_HAVE_MAINTAIN.getStatus();
            } else if (BaseStationStatus.BS_WAIT_STANDOWN.getCode().equals(jzState)) {
                //拆站
                return BaseStationStatus.BS_WAIT_STANDOWN.getStatus();
            } else if (BaseStationStatus.BS_HAVE_STANDOWN.getCode().equals(jzState)) {
                //已拆站
                return BaseStationStatus.BS_HAVE_STANDOWN.getStatus();
            }
        }
        return null;
    }

    /*    //上游客户
        public  String tranUpCustom(String jzUpCustom){
            SDictionary sDictionary = new SDictionary();
            sDictionary.setNormal();
            sDictionary.setValue(jzUpCustom);
            List<String> list = new ArrayList<>();
            list.add(DictionaryMap.jzTtUpper);
            list.add(DictionaryMap.jzYdUpper);
            sDictionary.setTypeList(list);
            String name = null;
            List<SDictionary> dictionaries = sDictionaryRepository.queryByType(sDictionary);
            if (CollectionUtils.isNotEmpty(dictionaries)){
                for (SDictionary dictionary : dictionaries) {
                    if (jzUpCustom.equals(dictionary.getValue())){
                        name = dictionary.getName();
                    }
                }
            }
            return name;
        }*/
   /* //建设方式 上游客户  业务线
    public String tranField(String value, String identifier) {
        SDictionary sDictionary = new SDictionary();
        sDictionary.setNormal();
        sDictionary.setValue(value);
        List<String> list = new ArrayList<>();
        if (ZERONUMBER.equals(identifier)) {
            list.add(DictionaryMap.jzYwx);
        } else if (ONENUMBER.equals(identifier)) {
            list.add(DictionaryMap.jzBuild); //建设方式
        } else if (TWONUMBER.equals(identifier)) {
            list.add(DictionaryMap.jzYdUpper);
            list.add(DictionaryMap.jzTtUpper);
        }
        sDictionary.setTypeList(list);
        String name = null;
        List<SDictionary> dictionaries = sDictionaryRepository.queryByType(sDictionary);
        if (CollectionUtils.isNotEmpty(dictionaries)) {
            for (SDictionary dictionary : dictionaries) {
                if (value.equals(dictionary.getValue())) {
                    name = dictionary.getName();
                }
            }
        }
        return name;
    }*/


}
