package org.rcisoft.business.processDesign.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import lombok.extern.slf4j.Slf4j;
import org.activiti.engine.HistoryService;
import org.activiti.engine.TaskService;
import org.activiti.engine.history.HistoricTaskInstance;
import org.activiti.engine.task.Task;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.rcisoft.business.hijzmessage.dao.HiJzMessageRepository;
import org.rcisoft.business.hijzmessage.entity.HiJzMessage;
import org.rcisoft.business.jzmessage.common.DictionaryMap;
import org.rcisoft.business.jzmessage.common.OptimizeQuery;
import org.rcisoft.business.jzmessage.common.TypeEnum;
import org.rcisoft.business.jzmessage.dao.JzMessageRepository;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.jzmessage.service.impl.JzMessageServiceImpl;
import org.rcisoft.business.jzmessage.util.ChangeUtil;
import org.rcisoft.business.jzmessage.util.CommonMethod;
import org.rcisoft.business.processDesign.dao.*;
import org.rcisoft.business.processDesign.dto.*;
import org.rcisoft.business.processDesign.entity.*;
import org.rcisoft.business.processDesign.service.AllMesssageService;
import org.rcisoft.business.suser.service.SUserService;
import org.rcisoft.business.userwarning.dao.UserWarningRepository;
import org.rcisoft.business.userwarning.entity.UserWarning;
import org.rcisoft.business.userwarning.service.UserWarningService;
import org.rcisoft.business.xgjzmessage.dao.XgJzMessageRepository;
import org.rcisoft.business.xgjzmessage.entity.XgJzMessage;
import org.rcisoft.common.BaseStationStatus;
import org.rcisoft.common.RegionEnum;
import org.rcisoft.common.ResultServiceExceptionEnums;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.beans.Transient;
import java.util.*;

/**
 * @Author: jiangpengpeng
 * @Description:
 * @Date: Created in 20:24  2019/8/5
 * @Modified By:
 */
@Service
@Slf4j
public class AllMesssageServiceImpl implements AllMesssageService {
    private static final String JZVERSION = "jzVersion";

    @Autowired
    private JzMessageRepository jzMessageRepository;
    @Autowired
    private HiJzMessageRepository hiJzMessageRepository;
    @Autowired
    private ProcessMidRepository processMidRepository;
    @Autowired
    private WorkflowTaskDataRepository workflowTaskDataRepository;
    @Autowired
    private WorkflowTaskDateMesRepository workflowTaskDateMesRepository;
    @Autowired
    private SUserService sUserService;
    @Autowired
    private WorkflowTaskDataHiRepository workflowTaskDataHiRepository;
    @Autowired
    private XgJzMessageRepository xgJzMessageRepository;
    @Autowired
    private WorkflowTemplateFormFieldHiRepository workflowTemplateFormFieldHiRepository;
    @Autowired
    private ActHiVarInstRepository actHiVarInstRepository;
    @Autowired
    private TaskService taskService;
    @Autowired
    private HistoryService historyService;
    @Autowired
    private JzMessageServiceImpl jzMessageService;
    @Autowired
    private UserWarningService userWarningService;
    @Autowired
    private OptimizeQuery optimizeQuery;

    //判断流程是否已经启动修改
    public boolean isInProcess(String jzMessageId) {
        boolean isInProcess = false;
        if (CollectionUtils.isNotEmpty(processMidRepository.selectByJzMessageId(jzMessageId))) {
            isInProcess = true;
        }
        return isInProcess;
    }

    ;

    //返回当前的基站信息和流程信息
    @Override
    public NowMessageDTO getMessageJZTem(String jzMessageId) {
        //判断是不是管理员
        Boolean admin = sUserService.isAdmin();
        NowMessageDTO nowMessageDTO = new NowMessageDTO();
        //根据jzMessageId查询当前基站信息表；
        JzMessage jzMessage = new JzMessage();
        jzMessage.setBusinessIds(jzMessageId.split(","));
        jzMessage.setNormal();
        /* jzMessage.setJzLocation(DictionaryMap.jzLocation);*/
        List<String> yysList = new ArrayList();
        yysList.add(DictionaryMap.jzDjYys);
        yysList.add(DictionaryMap.jzTtYys);
        yysList.add(DictionaryMap.jzYdYys);
        jzMessage.setJzListYys(yysList);
        List<JzMessage> jzMessages = jzMessageRepository.queryJzMessages(jzMessage);
        if (CollectionUtils.isEmpty(jzMessages)) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZMESSAGE_NULL);
        }
        if (jzMessages.get(0).getJzCurUser().equals(CyUserUtil.getAuthenBusinessId())) {
            jzMessages.get(0).setIsMyBusiness("0");
        } else {
            jzMessages.get(0).setIsMyBusiness("1");
        }
        optimizeQuery.helpOptimizeQuery(jzMessages,"0");
        /*if (jzMessages.get(0).getJzType().equals("0")) {
            jzMessages.get(0).setTypeName(TypeEnum.DJ.getname());
        }
        if (jzMessages.get(0).getJzType().equals("1")) {
            jzMessages.get(0).setTypeName(TypeEnum.YD.getname());
        }
        if (jzMessages.get(0).getJzType().equals("2")) {
            jzMessages.get(0).setTypeName(TypeEnum.TT.getname());
        }*/
        nowMessageDTO.setJzMessage(jzMessages.get(0));
        List<WorkflowTaskData> taskDateBytemplateId = workflowTaskDataRepository.getTaskDateBytemplateId(jzMessageId);
        if (taskDateBytemplateId == null) {
            return nowMessageDTO;
        }
        List<ProcessMidDTO> processMidList = new ArrayList<>();
        for (WorkflowTaskData workflowTaskData : taskDateBytemplateId) {
            ProcessMidDTO processMidDTO = this.nowProcessMid(workflowTaskData.getProcessId(), processMidList);
            if (processMidDTO == null) {
                processMidDTO = this.generateNowProMidDto(workflowTaskData);
                processMidList.add(processMidDTO);
                continue;
            }
            WorkflowTaskData workflowTaskData1 = this.getNowWorkflowTaskDataById(workflowTaskData.getId(), processMidDTO);
            if (null == workflowTaskData1) {
                workflowTaskData1 = this.generateNowWorkflowTaskData(workflowTaskData);
                if (CollectionUtils.isEmpty(processMidDTO.getWorkflowTaskData())) {
                    List<WorkflowTaskData> workflowTaskData2 = new ArrayList<>();
                    workflowTaskData2.add(workflowTaskData1);
                    processMidDTO.setWorkflowTaskData(workflowTaskData2);
                } else {
                    processMidDTO.getWorkflowTaskData().add(workflowTaskData1);
                }
                continue;
            }
        }
        nowMessageDTO.setProcessMidDTOs(processMidList);
        nowMessageDTO.setAdmin(admin);
        nowMessageDTO.setInPorcess(isInProcess(jzMessageId));
        return nowMessageDTO;
    }

    //返回当前的基站信息和流程信息
    @Override
    public NowMessageDTO getMessageJZTemByProjectCode(String projectCode) {
        //判断是不是管理员
        Boolean admin = sUserService.isAdmin();
        NowMessageDTO nowMessageDTO = new NowMessageDTO();
        //根据jzMessageId查询当前基站信息表；
        JzMessage jzMessage = new JzMessage();
        jzMessage.setProjectCode(projectCode);
        jzMessage.setNormal();
        /* jzMessage.setJzLocation(DictionaryMap.jzLocation);*/
        List<String> yysList = new ArrayList();
        yysList.add(DictionaryMap.jzDjYys);
        yysList.add(DictionaryMap.jzTtYys);
        yysList.add(DictionaryMap.jzYdYys);
        jzMessage.setJzListYys(yysList);
        List<JzMessage> jzMessages = jzMessageRepository.queryJzMessages(jzMessage);
        if (CollectionUtils.isEmpty(jzMessages)) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZMESSAGE_NULL);
        }
        if (jzMessages.get(0).getJzCurUser().equals(CyUserUtil.getAuthenBusinessId())) {
            jzMessages.get(0).setIsMyBusiness("0");
        } else {
            jzMessages.get(0).setIsMyBusiness("1");
        }
        optimizeQuery.helpOptimizeQuery(jzMessages,"0");
        /*if (jzMessages.get(0).getJzType().equals("0")) {
            jzMessages.get(0).setTypeName(TypeEnum.DJ.getname());
        }
        if (jzMessages.get(0).getJzType().equals("1")) {
            jzMessages.get(0).setTypeName(TypeEnum.YD.getname());
        }
        if (jzMessages.get(0).getJzType().equals("2")) {
            jzMessages.get(0).setTypeName(TypeEnum.TT.getname());
        }*/
        nowMessageDTO.setJzMessage(jzMessages.get(0));
        List<WorkflowTaskData> taskDateBytemplateId = workflowTaskDataRepository.getTaskDateBytemplateId(jzMessages.get(0).getBusinessId());
        if (taskDateBytemplateId == null) {
            return nowMessageDTO;
        }
        List<ProcessMidDTO> processMidList = new ArrayList<>();
        for (WorkflowTaskData workflowTaskData : taskDateBytemplateId) {
            ProcessMidDTO processMidDTO = this.nowProcessMid(workflowTaskData.getProcessId(), processMidList);
            if (processMidDTO == null) {
                processMidDTO = this.generateNowProMidDto(workflowTaskData);
                processMidList.add(processMidDTO);
                continue;
            }
            WorkflowTaskData workflowTaskData1 = this.getNowWorkflowTaskDataById(workflowTaskData.getId(), processMidDTO);
            if (null == workflowTaskData1) {
                workflowTaskData1 = this.generateNowWorkflowTaskData(workflowTaskData);
                if (CollectionUtils.isEmpty(processMidDTO.getWorkflowTaskData())) {
                    List<WorkflowTaskData> workflowTaskData2 = new ArrayList<>();
                    workflowTaskData2.add(workflowTaskData1);
                    processMidDTO.setWorkflowTaskData(workflowTaskData2);
                } else {
                    processMidDTO.getWorkflowTaskData().add(workflowTaskData1);
                }
                continue;
            }
        }
        nowMessageDTO.setProcessMidDTOs(processMidList);
        nowMessageDTO.setAdmin(admin);
        nowMessageDTO.setInPorcess(isInProcess(jzMessages.get(0).getBusinessId()));
        return nowMessageDTO;
    }

    /*查询当前第三及是否有数据*/
    private WorkflowTaskData getNowWorkflowTaskDataById(String id, ProcessMidDTO processMidList) {
        if (CollectionUtils.isEmpty(processMidList.getWorkflowTaskData()))
            return null;
        WorkflowTaskData workflowTaskData = null;
        for (WorkflowTaskData workflowTaskData1 : processMidList.getWorkflowTaskData()) {
            if (id.equals(workflowTaskData1.getId())) {
                workflowTaskData = workflowTaskData1;
                break;
            }

        }
        return workflowTaskData;
    }

    /*查询当前第二级是否有数据*/
    private ProcessMidDTO nowProcessMid(String processId, List<ProcessMidDTO> processMidList) {
        if (CollectionUtils.isEmpty(processMidList))
            return null;
        ProcessMidDTO processMidDTO = null;
        for (ProcessMidDTO processMidDTO1 : processMidList) {
            if (processId.equals(processMidDTO1.getProcessId())) {
                processMidDTO = processMidDTO1;
                break;
            }
        }
        return processMidDTO;
    }

    /**
     * 创建二级
     *
     * @param wf
     * @return
     */
    private ProcessMidDTO generateNowProMidDto(WorkflowTaskData wf) {
        ProcessMidDTO dto = new ProcessMidDTO();
        //赋值
        dto.setTypeTemplate(wf.getTypeTemplate());
        dto.setTypeProcess(wf.getTypeProcess());
        dto.setProcessId(wf.getProcessId());
        dto.setVersion(wf.getVersion());
        dto.setRegionStr(wf.getRegionStr());
        //-------------------3---------------------------
        List<WorkflowTaskData> workflowTaskDataList = new ArrayList<>();
        WorkflowTaskData workflowTaskData = this.generateNowWorkflowTaskData(wf);
        workflowTaskDataList.add(workflowTaskData);
        dto.setWorkflowTaskData(workflowTaskDataList);
        return dto;
    }

    /**
     * 创建当前第三级
     *
     * @param wf
     * @return
     */
    private WorkflowTaskData generateNowWorkflowTaskData(WorkflowTaskData wf) {
        //-------------------4---------------------------
        WorkflowTaskData workflowTaskData = new WorkflowTaskData();
        workflowTaskData.setId(wf.getId());
        workflowTaskData.setFieldId(wf.getFieldId());
        workflowTaskData.setRequired(wf.getRequired());
        workflowTaskData.setFieldValue(wf.getFieldValue());
        workflowTaskData.setRequired(wf.getRequired());
        workflowTaskData.setFieldTp(wf.getFieldTp());
        workflowTaskData.setFieldNm(wf.getFieldNm());
        workflowTaskData.setFieldOrder(wf.getFieldOrder());
        workflowTaskData.setFieldExpand(wf.getFieldExpand());
        return workflowTaskData;
    }

    /*=================================================================*/
    //查询修改信息任务修改信息
    public AlterMesDTO getAlterMes(String xgId, String taskId) {
        //判断是不是管理员
        Boolean admin = sUserService.isAdmin();
        AlterMesDTO alterMesDTO = new AlterMesDTO();
        //xgId；
        List<XgJzMessage> xgJzMessages = xgJzMessageRepository.XgJzMessages(xgId);
        alterMesDTO.setXgJzMessage(xgJzMessages.get(0));
        XgJzMessage xgJzMessage2 = new XgJzMessage();
        xgJzMessage2.setBusinessId(xgId);
        XgJzMessage xgJzMessage1 = xgJzMessageRepository.selectByPrimaryKey(xgJzMessage2);
        List<WorkflowTaskDateMes> messDataHiByJZMesId = workflowTaskDateMesRepository.getMessDataHiByJZMesId(xgJzMessage1.getJzId());
        //-------------------1---------------------------
        if (messDataHiByJZMesId.size() == 0) {
            alterMesDTO.setWorkflowTemplateFormFieldHis(null);
            return alterMesDTO;
        }
        //通过任务id查看当前表单信息
        HistoricTaskInstance historicTaskInstance = historyService.createHistoricTaskInstanceQuery().taskId(taskId).singleResult();
        List<String> processIdsByTaskId = workflowTemplateFormFieldHiRepository.getProcessIdsByTaskId(taskId);
        WorkflowTaskDateMes messDataHiByProcessId = workflowTaskDateMesRepository.getMessDataHiByProcessId(processIdsByTaskId.get(0));
        List<WorkflowTemplateFormFieldHi> mesByTaskId = workflowTemplateFormFieldHiRepository.getMesByTaskId(messDataHiByProcessId.getTaskId());
        alterMesDTO.setWorkflowTemplateFormFieldHis(mesByTaskId);
        alterMesDTO.setAdmin(admin);
        alterMesDTO.setProcessId(historicTaskInstance.getProcessInstanceId());
        return alterMesDTO;
    }

    //返回历史基站信息和流程信息
    @Override
    public AllMessageHiDTO getMessageHi(String jzMessageId) {
        //通过基站id查询基站历史数据
        log.info(jzMessageId);
        List<HiJzMessage> hijzMessageByjzMessageId = hiJzMessageRepository.getHijzMessageByjzMessageId(jzMessageId);
        log.info(hijzMessageByjzMessageId.toString());

        int j = 1;
        for (int i = hijzMessageByjzMessageId.size(); i > 0; i--) {
            hijzMessageByjzMessageId.get(i - 1).setNumber(j);
            j++;
        }

        //通过基站jzMessageId查询历史数据；
        List<WorkflowTaskDateMes> messDataHiByJZMesId = workflowTaskDateMesRepository.getMessDataHiByJZMesId(jzMessageId);
        //-------------------1---------------------------
        AllMessageHiDTO allMessageHiDTO = new AllMessageHiDTO();
        allMessageHiDTO.setHiJzMessageList(hijzMessageByjzMessageId);


        List<ProcessMidDTO> midDTOList = new ArrayList<>();
        if (messDataHiByJZMesId.size() == 0) {
            allMessageHiDTO.setProcessMidDTOS(midDTOList);
            return allMessageHiDTO;
        }
        //历史流程
        //-------------------2---------------------------
        for (WorkflowTaskDateMes wf : messDataHiByJZMesId) {
            //找第二级
            ProcessMidDTO dto = this.getProcessMidDTOByProcessId(wf.getTaskId(), wf.getProcessId(), midDTOList);
            if (null == dto) {
                dto = this.generateProMidDto(wf);
                midDTOList.add(dto);
                continue;
            }
            //找第三级
            TaskMessageDTO taskMessage = this.getTaskMessageDTOById(wf.getId(), dto);
            if (null == taskMessage) {
                taskMessage = this.generateTaskMessage(wf);
                if (CollectionUtils.isEmpty(dto.getTaskMessageDTOList())) {
                    List<TaskMessageDTO> taskMessageDTOList = new ArrayList<>();
                    taskMessageDTOList.add(taskMessage);
                    dto.setTaskMessageDTOList(taskMessageDTOList);
                } else {
                    dto.getTaskMessageDTOList().add(taskMessage);
                }
                continue;
            }
            //找第四级
            WorkflowTaskDataHi workflowTaskDataHi = this.getWorkflowTaskDataHiById(wf.getDid(), taskMessage);
            if (null == workflowTaskDataHi) {
                workflowTaskDataHi = this.generateWorkflowTaskDataHi(wf);
                if (CollectionUtils.isEmpty(taskMessage.getWorkflowTaskDataHiList())) {
                    List<WorkflowTaskDataHi> taskMessageDTOList = new ArrayList<>();
                    taskMessageDTOList.add(workflowTaskDataHi);
                    taskMessage.setWorkflowTaskDataHiList(taskMessageDTOList);
                } else {
                    taskMessage.getWorkflowTaskDataHiList().add(workflowTaskDataHi);
                }
                continue;
            }

        }
        allMessageHiDTO.setProcessMidDTOS(midDTOList);

        return allMessageHiDTO;
    }


    /**
     * 根据 processId  查询匹配的  processMidDto   找 二级
     *
     * @param processId
     * @param processMidDTOList
     * @return
     */
    private ProcessMidDTO getProcessMidDTOByProcessId(String taskId, String processId, List<ProcessMidDTO> processMidDTOList) {
        if (CollectionUtils.isEmpty(processMidDTOList))
            return null;
        ProcessMidDTO dto = null;
        for (ProcessMidDTO o : processMidDTOList) {
            //管理员修改----------------
            if (null == taskId && null == o.getTypeProcess()) {
                dto = o;
                break;
            }
            //非管理员修改
            else if (null != taskId && null != o.getTypeProcess() && processId.equals(o.getProcessId())) {
                dto = o;
                break;
            }
        }
        return dto;
    }

    /**
     * 根据 messId 查看 taskmessage     找 三级
     *
     * @param id
     * @param mDto
     * @return
     */
    private TaskMessageDTO getTaskMessageDTOById(String id, ProcessMidDTO mDto) {
        if (CollectionUtils.isEmpty(mDto.getTaskMessageDTOList()))
            return null;
        TaskMessageDTO dto = null;
        for (TaskMessageDTO o : mDto.getTaskMessageDTOList()) {
            if (id.equals(o.getMid())) {
                dto = o;
                break;
            }
        }
        return dto;
    }

    /*
        根据  did 查找 第四级
     */
    private WorkflowTaskDataHi getWorkflowTaskDataHiById(String did, TaskMessageDTO tdto) {
        if (CollectionUtils.isEmpty(tdto.getWorkflowTaskDataHiList()))
            return null;
        WorkflowTaskDataHi dto = null;
        for (WorkflowTaskDataHi o : tdto.getWorkflowTaskDataHiList()) {
            if (did.equals(o.getId())) {
                dto = o;
                break;
            }
        }
        return dto;
    }


    /**
     * create dtp
     *
     * @param wf
     * @return
     */
    private ProcessMidDTO generateProMidDto(WorkflowTaskDateMes wf) {
        ProcessMidDTO dto = new ProcessMidDTO();
        //赋值
        //管理员修改---------------------
        if (null == wf.getTaskId())
            dto.setTypeProcess(null);
            //非管理员修改
        else
            dto.setTypeProcess(wf.getPmTypeProcess());
        dto.setProcessId(wf.getProcessId());
        dto.setVersion(wf.getPmVersion());
        dto.setTypeTemplate(wf.getTypeTemplate());

        //-------------------3---------------------------
        List<TaskMessageDTO> taskMessageDTOList = new ArrayList<>();
        TaskMessageDTO taskMessageDTO = this.generateTaskMessage(wf);
        taskMessageDTOList.add(taskMessageDTO);
        dto.setTaskMessageDTOList(taskMessageDTOList);
        return dto;
    }

    /**
     * 创建三级
     *
     * @param wf
     * @return
     */
    private TaskMessageDTO generateTaskMessage(WorkflowTaskDateMes wf) {
        //-------------------3---------------------------
        TaskMessageDTO taskMessageDTO = new TaskMessageDTO();
        taskMessageDTO.setName(wf.getName());
        taskMessageDTO.setCreatetime(wf.getCreateTime());
        taskMessageDTO.setTransition(wf.getTransition());
        taskMessageDTO.setRemarks(wf.getRemarks());
        taskMessageDTO.setRegionStr(wf.getRegionStr());
        taskMessageDTO.setMid(wf.getId());
        //-------------------4---------------------------
        List<WorkflowTaskDataHi> workflowTaskDataHiList = new ArrayList<>();
        WorkflowTaskDataHi workflowTaskDataHi = this.generateWorkflowTaskDataHi(wf);
        workflowTaskDataHiList.add(workflowTaskDataHi);
        taskMessageDTO.setWorkflowTaskDataHiList(workflowTaskDataHiList);
        return taskMessageDTO;
    }

    /**
     * 创建第四级
     *
     * @param wf
     * @return
     */
    private WorkflowTaskDataHi generateWorkflowTaskDataHi(WorkflowTaskDateMes wf) {
        //-------------------4---------------------------
        WorkflowTaskDataHi workflowTaskDataHi = new WorkflowTaskDataHi();
        workflowTaskDataHi.setFieldId(wf.getFhiFieldId());
        workflowTaskDataHi.setFieldValue(wf.getHifieldValue());
        workflowTaskDataHi.setFieldTp(wf.getFhiFieldTp());
        workflowTaskDataHi.setFieldNm(wf.getFhiFieldNm());
        workflowTaskDataHi.setFieldOrder(wf.getFhiFieldOrder());
        workflowTaskDataHi.setFieldExpand(wf.getFhiExpand());
        return workflowTaskDataHi;
    }

    /**
     * 修改当前表单信息
     *
     * @param workflowTaskDateMes
     * @return
     */
    @Override
    @Transactional
    public CyPersistModel updateMes(WorkflowTaskDateMes workflowTaskDateMes) {
        //判断权限是否充足
        if (!sUserService.isAdmin()) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZ_UNAUTHORIZED);
        }
        log.debug(workflowTaskDateMes.getJzMessage());
        //存入HijzMessage
        JzMessage jzMessage = JSON.parseObject(workflowTaskDateMes.getJzMessage(), new TypeReference<JzMessage>() {
        });
        if (jzMessage != null) {
            updateJZMes(jzMessage);
        }

        //-----------------1-------date_mes-----------------------------
        workflowTaskDateMes.setId(CyIdGenUtil.uuid());
        //生成创建日期
        workflowTaskDateMes.setCreateTime(new Date());
        //设置创建人为当前登录人id
        workflowTaskDateMes.setTransition("管理员修改基站信息");
        workflowTaskDateMes.setCreatePerson(CyUserUtil.getAuthenBusinessId());
        //插入到data_mes
        workflowTaskDateMesRepository.insertSelective(workflowTaskDateMes);
        //-----------------2-------date_hi-----------------------------
        List<WorkflowTaskDataHi> datahi = new ArrayList<>();
        //{"1":"23232","2":"32323232"}
        String jsonStr = workflowTaskDateMes.getJsonStr();
        if (StringUtils.isNotEmpty(jsonStr)) {
            try {

                JSONObject jsonObject = JSONObject.parseObject(jsonStr);
                for (Map.Entry<String, Object> entry : jsonObject.entrySet()) {
                    WorkflowTaskDataHi workflowTaskDataHi = new WorkflowTaskDataHi();
                    workflowTaskDataHi.setId(CyIdGenUtil.uuid());
                    workflowTaskDataHi.setFieldId(entry.getKey());
                    workflowTaskDataHi.setFieldValue(entry.getValue().toString());
                    workflowTaskDataHi.setTaskDataMesId(workflowTaskDateMes.getId());
                    datahi.add(workflowTaskDataHi);
                }
            } catch (Exception e) {

            }
        }
        if (!CollectionUtils.isEmpty(datahi))
            workflowTaskDataHiRepository.insertList(datahi);
        //-----------------3-------data-----------------------------
        for (WorkflowTaskDataHi work : datahi) {
            work.setProcessId(workflowTaskDateMes.getProcessId());
            WorkflowTaskData workflowTaskData = workflowTaskDataRepository.queryWorkTaskDataByProcessIdAndFieldId(work);
            //修改
            workflowTaskData.setFieldValue(work.getFieldValue());
            workflowTaskData.setIsFirst("1");
            workflowTaskDataRepository.updateByPrimaryKeySelective(workflowTaskData);
        }

        return new CyPersistModel(1);
    }

    /*
     * 管理员修改基站信息
     * */
    @Override
    @Transactional
    public CyPersistModel updateJZMes(JzMessage jzMessage) {
        if (!sUserService.isAdmin()) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZ_UNAUTHORIZED);
        }
        //判断当前项目编号是否重复
        if (StringUtils.isNotEmpty(jzMessage.getProjectCode())){
            jzMessage.setNormal();
            List<String> list = jzMessageRepository.queryprojectCodeByBusinessId(jzMessage);
            if (list.contains(jzMessage.getProjectCode())) {
                throw new CyServiceException(ResultServiceExceptionEnums.JZ_CODE_ERROR);
            }
        }
       /*
        if (!CollectionUtils.isEmpty(list))
            return new CyPersistModel(0);*/

        //设置插入金蝶标识为0可插入 当项目编号不为空时或者为移动会审铁塔立项时
        if (org.apache.commons.lang3.StringUtils.isNotEmpty(jzMessage.getProjectCode())
                || BaseStationStatus.MC_WAIT_TRIAGE.getCode().equals(jzMessage.getJzState())
                || BaseStationStatus.IT_WAIT_APPROVAL.getCode().equals(jzMessage.getJzState())) {
            jzMessage.setIsImport(0);
            jzMessage.setProjectCodeImport(0);
        }
        jzMessage.setUpdateBy(CyUserUtil.getAuthenBusinessId());
        jzMessage.setUpdateDate(new Date());
        jzMessage.setJzWaitReason(RegionEnum.MANAGERUPDATE.getKey());
        JzMessage jzMessage2 = jzMessageRepository.selectByPrimaryKey(jzMessage);
        if (StringUtils.isEmpty(jzMessage.getJzRequire())) {
            jzMessageRepository.updateJzRequire(jzMessage2);
        }
        //修改当前阶段负责人，则更新预警时间和状态，清除预警，删除当前基站流程
        if (StringUtils.isNotEmpty(jzMessage.getJzCurUser()) && !"".equals(jzMessage.getJzCurUser()) && !jzMessage2.getJzCurUser().equals(jzMessage.getJzCurUser())) {
            jzMessage.setJzJdDate(new Date());
            jzMessage.setJzJdWaring("0");
            UserWarning userWarning = new UserWarning();
            userWarning.setJzId(jzMessage.getBusinessId());
            userWarning.setWarningStatus("1");
            userWarning.setJzStatus(jzMessage2.getJzState());
            userWarning.setNormal();
            userWarningService.dealWarning(userWarning);
        }
        jzMessage.setJzProState(jzMessage2.getJzProState());
        int i = jzMessageRepository.updateByPrimaryKeySelective(jzMessage);
        JzMessage jzMessage1 = jzMessageRepository.selectByPrimaryKey(jzMessage);
        jzMessage1.setJzWaitReason(RegionEnum.MANAGERUPDATE.getKey());
        //转变当前基站信息转为历史基站信息.
        HiJzMessage hiJzMessage1 = ChangeUtil.jzMessageToHistory(jzMessage1);
        Map hiJzMessage = hiJzMessageRepository.getMaxVersionByJzId(hiJzMessage1);//查询历史表数据
        log.debug("ss");
        if (hiJzMessage != null && hiJzMessage.containsKey(JZVERSION)) {
            hiJzMessage1.setJzVersion(Integer.parseInt(hiJzMessage.get(JZVERSION).toString()) + 1);
        } else {
            hiJzMessage1.setJzVersion(1);
        }
        //插入历史表
        hiJzMessageRepository.insertSelective(hiJzMessage1);

        return new CyPersistModel(1);
    }

    /**
     * 保存修改基站信息 xg_jz_message
     *
     * @param jzMessage
     * @return
     */
    @Override
    @Transactional
    public CyPersistModel uploadJzMes(JzMessage jzMessage) {
        //解析静态资源,映射到javabean上
        jzMessage.setNormal();
        JzMessage rgJZmes = jzMessageRepository.selectByPrimaryKey(jzMessage);
        rgJZmes = JSON.parseObject(jzMessage.getFlowJsonStr(), new TypeReference<JzMessage>() {
        });
        rgJZmes.setCreateDate(jzMessage.getCreateDate());
        rgJZmes.setCreateBy(CyUserUtil.getAuthenBusinessId());
        rgJZmes.setUpdateDate(new Date());
        rgJZmes.setUpdateBy(CyUserUtil.getAuthenBusinessId());
        rgJZmes.setNormal();
        //判断项目编号是否重复
        jzMessageService.isRepeatProjectCode(rgJZmes);
        //将jzMessage转成XgJzMessage
        XgJzMessage xgJzMessage = ChangeUtil.jzMessageToXgJzMessage(rgJZmes);
        /* if (jzMessage.getJzYys().equals())*/
        //将基站信息存入xg_jz_mes表
        int i = xgJzMessageRepository.insertSelective(xgJzMessage);
        if (i == 0) {
            return new CyPersistModel(0);
        }
        /**
         * 存入WorkflowTaskDateMes表中
         */
        String xid = xgJzMessage.getBusinessId();
        xid = "xid=" + xid;
        xid = xid.replace("=", "\":\"");
        String regionStr = null;
        if (StringUtils.isEmpty(rgJZmes.getMaintainer()) || StringUtils.isEmpty(rgJZmes.getMaintainerName())) {
            regionStr = "{\"" + xid + "\"}";
        } else {
            String jzjwOwner = "jzjwOwner\" : { \"maintainer =" + rgJZmes.getMaintainer() + "\",\"maintainerName=" + rgJZmes.getMaintainerName() + "\"}";
            jzjwOwner = jzjwOwner.replace("=", "\":\"");
            regionStr = "{\"" + xid + "\",\"" + jzjwOwner + "}";
        }
        WorkflowTaskDateMes workflowTaskDateMes = new WorkflowTaskDateMes();
        workflowTaskDateMes.setId(CyIdGenUtil.uuid());
        workflowTaskDateMes.setCreatePerson(CyUserUtil.getAuthenBusinessId());
        workflowTaskDateMes.setTaskId(jzMessage.getTaskId());
        workflowTaskDateMes.setJsonStr(jzMessage.getJsonStrs());
        workflowTaskDateMes.setRegionStr(regionStr);
        workflowTaskDateMes.setTransition(jzMessage.getTransition());
        workflowTaskDateMes.setRemarks(jzMessage.getMsgRemarks());
        workflowTaskDateMes.setCreateTime(new Date());//设置当前时间
        workflowTaskDateMes.setProcessId(jzMessage.getProcessId());
        //存入workflow_data_mes 表中
        int i1 = workflowTaskDateMesRepository.insertSelective(workflowTaskDateMes);
        if (i1 == 0) {
            return new CyPersistModel(0);
        }
        //存入data_hi表
        List<WorkflowTaskDataHi> workflowTaskDataHiList = new ArrayList<>();
        if (!org.apache.commons.lang.StringUtils.isEmpty(jzMessage.getJsonStrs())) {
            try {
                JSONArray jsonArray = JSONArray.parseArray(jzMessage.getJsonStrs());
                for (int g = 0; g < jsonArray.size(); g++) {
                    for (Map.Entry<String, Object> entry : jsonArray.getJSONObject(g).entrySet()) {
                        Object value = entry.getValue();
                        JSONArray jsonArray1 = (JSONArray) JSON.toJSON(value);
                        for (int j = 0; j < jsonArray1.size(); j++) {
                            for (Map.Entry<String, Object> entry1 : jsonArray1.getJSONObject(j).entrySet()) {
                                WorkflowTaskDataHi workflowTaskDatahi = new WorkflowTaskDataHi();
                                workflowTaskDatahi.setTaskDataMesId(workflowTaskDateMes.getId());
                                workflowTaskDatahi.setId(String.valueOf(UUID.randomUUID()));
                                workflowTaskDatahi.setFieldId(entry1.getKey());
                                workflowTaskDatahi.setFieldValue(entry1.getValue().toString());
                                workflowTaskDataHiList.add(workflowTaskDatahi);
                            }
                        }
                    }
                }

            } catch (Exception e) {
                log.error("解析json error" + e.getMessage());
            }
        }
        if (CollectionUtils.isNotEmpty(workflowTaskDataHiList)) {
            workflowTaskDataHiRepository.insertList(workflowTaskDataHiList);
        }
        return new CyPersistModel(1);
    }


    //修改信息待审批页面返回信息
    @Override
    public AlterWaitMesDTO alterMesByXgId(String xgId, String taskId) {
        AlterWaitMesDTO alterWaitMesDTO = new AlterWaitMesDTO();
        XgJzMessage xgJzMessage = new XgJzMessage();
        xgJzMessage.setBusinessId(xgId);
        XgJzMessage xgJzMessage1 = xgJzMessageRepository.selectByPrimaryKey(xgJzMessage);
        //返回原信息
        alterWaitMesDTO.setNowMessageDTO(this.getMessageJZTem(xgJzMessage1.getJzId()));
        //返回待修改信息
        alterWaitMesDTO.setAlterMesDTO(this.getAlterMes(xgId, taskId));
        return alterWaitMesDTO;
    }

    //返回基站信息和流程信息
    public NowMessageDTO getNowMessageJZTem(String jzMessageId) {
//         List<ProcessMid> listProcessId = jzMessageService.updateProcessId;
        //判断是不是管理员
        Boolean admin = sUserService.isAdmin();
        NowMessageDTO nowMessageDTO = new NowMessageDTO();
        //根据jzMessageId查询当前基站信息表；
        JzMessage jzMessage = new JzMessage();
        jzMessage.setBusinessIds(jzMessageId.split(","));
        jzMessage.setNormal();
        jzMessage.setJzLocation(DictionaryMap.jzLocation);
        List<String> yysList = new ArrayList();
        yysList.add(DictionaryMap.jzDjYys);
        yysList.add(DictionaryMap.jzTtYys);
        yysList.add(DictionaryMap.jzYdYys);
        jzMessage.setJzListYys(yysList);
        List<JzMessage> jzMessages = jzMessageRepository.queryJzMessages(jzMessage);
        if (CollectionUtils.isEmpty(jzMessages)) {
            throw new CyServiceException(ResultServiceExceptionEnums.JZMESSAGE_NULL);
        }
        if (jzMessages.get(0).getJzCurUser().equals(CyUserUtil.getAuthenBusinessId())) {
            jzMessages.get(0).setIsMyBusiness("0");
        } else {
            jzMessages.get(0).setIsMyBusiness("1");
        }

        if (jzMessages.get(0).getJzType().equals("0")) {
            jzMessages.get(0).setTypeName(TypeEnum.DJ.getname());
        }
        if (jzMessages.get(0).getJzType().equals("1")) {
            jzMessages.get(0).setTypeName(TypeEnum.YD.getname());
        }
        if (jzMessages.get(0).getJzType().equals("2")) {
            jzMessages.get(0).setTypeName(TypeEnum.TT.getname());
        }
        nowMessageDTO.setJzMessage(jzMessages.get(0));
        List<WorkflowTaskData> taskDateBytemplateId = workflowTaskDataRepository.getTaskDateBytemplateId(jzMessageId);
        if (taskDateBytemplateId == null) {
            return nowMessageDTO;
        }
        List<ProcessMidDTO> processMidList = new ArrayList<>();
        for (WorkflowTaskData workflowTaskData : taskDateBytemplateId) {
            ProcessMidDTO processMidDTO = this.nowProcessMid(workflowTaskData.getProcessId(), processMidList);
            if (processMidDTO == null) {
                processMidDTO = this.generateNowProMidDto(workflowTaskData);
                processMidList.add(processMidDTO);
                continue;
            }
            WorkflowTaskData workflowTaskData1 = this.getNowWorkflowTaskDataById(workflowTaskData.getId(), processMidDTO);
            if (null == workflowTaskData1) {
                workflowTaskData1 = this.generateNowWorkflowTaskData(workflowTaskData);
                if (CollectionUtils.isEmpty(processMidDTO.getWorkflowTaskData())) {
                    List<WorkflowTaskData> workflowTaskData2 = new ArrayList<>();
                    workflowTaskData2.add(workflowTaskData1);
                    processMidDTO.setWorkflowTaskData(workflowTaskData2);
                } else {
                    processMidDTO.getWorkflowTaskData().add(workflowTaskData1);
                }
                continue;
            }
        }
        nowMessageDTO.setProcessMidDTOs(processMidList);
        nowMessageDTO.setAdmin(admin);
        nowMessageDTO.setInPorcess(isInProcess(jzMessageId));
        return nowMessageDTO;
    }

   /* //修改信息已审批页面返回信息
    @Override
    public AlterMesDTO alterMesBytaskId(String xgId, String taskId) {
        AlterMesDTO alterMes = this.getAlterMes(xgId, taskId);
        return alterMes;
    }*/


}
