package org.rcisoft.business.processDesign.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.rcisoft.business.processDesign.dao.*;
import org.rcisoft.business.processDesign.dto.ComplateTaskResDto;
import org.rcisoft.business.processDesign.entity.*;
import org.rcisoft.business.processDesign.service.TaskService;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Author: jiangpengpeng
 * @Description:
 * @Date: Created in 17:49  2019/7/28
 * @Modified By:
 */
@Service
@Transactional
@Slf4j
public class TaskServiceImpl implements TaskService {
    @Autowired
    private ProcessMidRepository processMidRepository;
    @Autowired
    private ActHiVarInstRepository actHiVarInstRepository;
    @Autowired
    private WorkflowTemplateFormFieldHiRepository workflowTemplateFormFieldHiRepository;
    @Autowired
    private WorkflowTaskDataHiRepository workflowTaskDataHiRepository;
    @Autowired
    private WorkflowTemplateFormFieldRepository workflowTemplateFormFieldRepository;
    @Autowired
    private WorkflowTaskDataRepository workflowTaskDataRepository;
    @Autowired
    private WorkflowTaskDateMesRepository workflowTaskDateMesRepository;
    @Autowired
    private WorkflowTemplateProcessFileRepository workflowTemplateProcessFileRepository;

    //完成任务查询表单数据
    @Override
    public ComplateTaskResDto taskedByTaskId(String taskId) {
        ComplateTaskResDto complateTaskResDto = new ComplateTaskResDto();
        List<WorkflowTemplateFormFieldHi> workflowTemplateFormFieldHis = new ArrayList<>();
        List<WorkflowTaskDateMes> workflowTaskDateMes = workflowTaskDateMesRepository.workflowTaskDateMess(taskId);
        WorkflowTemplateFormFieldHi workflowTemplateFormFieldHi = null;
        if (CollectionUtils.isEmpty(workflowTaskDateMes)) {
            return complateTaskResDto;
        }
        for (WorkflowTaskDateMes workflowTaskDateMes1 : workflowTaskDateMes) {
            workflowTemplateFormFieldHi = new WorkflowTemplateFormFieldHi();
            workflowTemplateFormFieldHi.setId(workflowTaskDateMes1.getFhiFieldId());
            workflowTemplateFormFieldHi.setFieldNm(workflowTaskDateMes1.getFhiFieldNm());
            workflowTemplateFormFieldHi.setFieldValue(workflowTaskDateMes1.getHifieldValue());
            workflowTemplateFormFieldHi.setFieldTp(workflowTaskDateMes1.getFhiFieldTp());
            workflowTemplateFormFieldHi.setExpand(workflowTaskDateMes1.getFhiExpand());
            workflowTemplateFormFieldHis.add(workflowTemplateFormFieldHi);
        }
        complateTaskResDto.setWorkflowTemplateFormFieldHis(workflowTemplateFormFieldHis);
        complateTaskResDto.setTransition(workflowTaskDateMes.get(0).getTransition());
        complateTaskResDto.setRemarks(workflowTaskDateMes.get(0).getRemarks());
        complateTaskResDto.setRegionStr(workflowTaskDateMes.get(0).getRegionStr());
        complateTaskResDto.setJsonStr(workflowTaskDateMes.get(0).getJsonStr());
        complateTaskResDto.setTaskId(workflowTaskDateMes.get(0).getTaskId());
        return complateTaskResDto;
    }

    ;

    //根据任务id获取表单及权限
    @Override
    public ComplateTaskResDto complateByTaskId(String taskId) {
        String ifRewrite = "0";
        List<WorkflowTemplateProcessFile> workflowTemplateProcessFiles = workflowTemplateProcessFileRepository.WorkflowTemplateProcessFiles(taskId);
        if (workflowTemplateProcessFiles.size() > 0) {
            ifRewrite = "1";
        }
        ComplateTaskResDto complateTaskResDto = new ComplateTaskResDto();
        List<WorkflowTemplateFormFieldHi> fieldMesByTaskId = workflowTemplateFormFieldHiRepository.getFieldMesByTaskId(taskId);
        List<WorkflowTaskDateMes> regionStrBytaskId = workflowTaskDateMesRepository.getRegionStrBytaskId(taskId);
        if (regionStrBytaskId.size()<0 && fieldMesByTaskId.size()<0) {
            return complateTaskResDto;
        }
        complateTaskResDto.setWorkflowTemplateFormFieldHis(fieldMesByTaskId);
        complateTaskResDto.setRegionStr(regionStrBytaskId.get(0).getRegionStr());
        complateTaskResDto.setRemarks(regionStrBytaskId.get(0).getRemarks());
        complateTaskResDto.setTransition(regionStrBytaskId.get(0).getTransition());
        complateTaskResDto.setJsonStr(regionStrBytaskId.get(0).getJsonStr());
        complateTaskResDto.setIfReWrite(ifRewrite);
        complateTaskResDto.setWorkflowTaskDateMesList(regionStrBytaskId);
        return complateTaskResDto;
    }

    @Override
    public CyPersistModel insertDataMesByTaskId(WorkflowTaskDateMes workflowTaskDateMes) {
        //插入data_mes表
        //-----------------1-------date_mes-----------------------------
        //生成随机ID
        workflowTaskDateMes.setId(CyIdGenUtil.uuid());
        //生成创建日期
        workflowTaskDateMes.setCreateTime(new Date());
        //设置创建人为当前登录人id
        workflowTaskDateMes.setCreatePerson(CyUserUtil.getAuthenBusinessId());
        //通过任务id获取流程id
        String regionStr = workflowTaskDateMes.getRegionStr();
        String jsonStrV = workflowTaskDateMes.getJsonStr();
        //regionStr validate
        log.error(regionStr+"++++++++++++++++++++++");
        if (StringUtils.isNotBlank(regionStr)&&regionStr!= "\"\""&&!"\"\"".equals(regionStr)) {
            try {
                log.error(regionStr+"===================="+regionStr.length());
                JSONObject.parseObject(regionStr);
            } catch (Exception e) {
                try {
                    log.error(regionStr+"-----------------");
                    JSONArray.parseArray(regionStr);
                } catch (Exception e1) {
                    log.error("解析报错啦++++++++++++++++++++++"+regionStr);
                    return new CyPersistModel(0);
                }

            }
        }
        //jsonStr validate
        if (StringUtils.isNotBlank(jsonStrV)&&jsonStrV!="\"\""&&!"\"\"".equals(jsonStrV)) {
            try {
                JSONObject.parseObject(jsonStrV);
            } catch (Exception e) {
                try {
                    JSONArray.parseArray(jsonStrV);
                } catch (Exception e1) {
                    log.error("解析报错啦++++++++++++++++++++++222222222");
                    return new CyPersistModel(0);
                }

            }
        }
        int insert = workflowTaskDateMesRepository.insert(workflowTaskDateMes);
        if (insert==0){
            return new CyPersistModel(-1);
        }

        //-----------------2-------date_hi-----------------------------
        List<WorkflowTaskDataHi> datahi = new ArrayList<>();
        //{"1":"23232","2":"32323232"}
        String jsonStr = workflowTaskDateMes.getJsonStr();
        if (!StringUtils.isEmpty(jsonStr)) {
            try {

                JSONObject jsonObject = JSONObject.parseObject(jsonStr);
                for (Map.Entry<String, Object> entry : jsonObject.entrySet()) {
                    WorkflowTaskDataHi workflowTaskDataHi = new WorkflowTaskDataHi();
                    workflowTaskDataHi.setId(CyIdGenUtil.uuid());
                    workflowTaskDataHi.setFieldId(entry.getKey());
                    workflowTaskDataHi.setFieldValue(entry.getValue().toString());
                    workflowTaskDataHi.setTaskDataMesId(workflowTaskDateMes.getId());
                    datahi.add(workflowTaskDataHi);
                }


            } catch (Exception e) {

            }
        }
        if (!CollectionUtils.isEmpty(datahi)) {
            int i = workflowTaskDataHiRepository.insertList(datahi);
            if (i==0){
                return new CyPersistModel(-1);
            }
        }
        //-----------------3-------data-----------------------------
        for (WorkflowTaskDataHi work : datahi) {
            work.setProcessId(workflowTaskDateMes.getProcessId());
            WorkflowTaskData workflowTaskData = workflowTaskDataRepository.queryWorkTaskDataByProcessIdAndFieldId(work);
            if (null == workflowTaskData) {
                //没有
                workflowTaskData = new WorkflowTaskData();
                workflowTaskData.setId(CyIdGenUtil.uuid());
                workflowTaskData.setFieldId(work.getFieldId());
                workflowTaskData.setFieldValue(work.getFieldValue());
                workflowTaskData.setIsFirst("0");
                workflowTaskData.setProcessId(workflowTaskDateMes.getProcessId());
                int insert1 = workflowTaskDataRepository.insert(workflowTaskData);
                if (insert1==0){
                    return new CyPersistModel(-1);
                }
            } else {
                //修改
                workflowTaskData.setFieldValue(work.getFieldValue());
                workflowTaskData.setIsFirst("1");
                int i = workflowTaskDataRepository.updateByPrimaryKeySelective(workflowTaskData);
                if (i==0){
                    return new CyPersistModel(-1);
                }
            }
        }
        return new CyPersistModel(1);
    }
    //根据任务id插入数据到Data ,Data_hi Data_mes表

}
