package org.rcisoft.business.quartz.dao;

import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.jzmessage.dao.JzMessageRepository;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.quartz.entity.TimeInfo;
import org.rcisoft.business.quartz.util.GetTimeDifference;
import org.rcisoft.business.sdictionary.service.SDictionaryService;
import org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl;
import org.rcisoft.business.suser.entity.SUser;
import org.rcisoft.business.suser.service.SUserService;
import org.rcisoft.business.userwarning.dao.UserWarningRepository;
import org.rcisoft.business.userwarning.entity.UserWarning;
import org.rcisoft.business.userwarning.service.UserWarningService;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;

import static org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl.specialRole;

@Slf4j
@Component
public class TimeTask {
    @Autowired
    private UserWarningRepository userWarningRepository;

    @Autowired
    private JzMessageRepository jzMessageRepository;

    @Autowired
    private SDictionaryService sDictionaryServiceImpl;

    @Autowired
    private SUserService sUserServiceImpl;

    /**
     * 更新数据字典
     */
    public void updateDictionary() {
        sDictionaryServiceImpl.whiteList();
        log.debug(specialRole.toString());
    }

    /**
     * 查询未准时完成业务的业务员
     * 批量添加到业务员警告表中
     */
    public void userWarning(int deadline, String jzStatus, String jzType) {
        JzMessage jzMessage = new JzMessage();
        //设置未被删除的
        jzMessage.setNormal();
        //设置基站状态和基站类型
        jzMessage.setJzType(jzType);
        jzMessage.setJzState(jzStatus);
        //设置用户警告的类型为业务员
        jzMessage.setType("0");
        List<JzMessage> jzMessageList = jzMessageRepository.selectUndoUserNotInTable(jzMessage);
        log.debug("两表关联后的数据数目: " + jzMessageList.size() + " -----------------------------------");
        //需要添加的业务员
        List<UserWarning> addWarningUsers = new ArrayList<>();
        //需要改变预警状态的基站
        List<JzMessage> changeJzMessage = new ArrayList<>();
        //获取当前时间
        Date nowTime = new Date();
        for (JzMessage jzMessage1 : jzMessageList) {
            //如果基站进度时间为空则跳过
            if (jzMessage1.getJzJdDate() == null)
                continue;
            //判断权限，不是经理且基站不是待处理状态，继续下一个循环
            List<SUser> roles = sUserServiceImpl.queryRoleById(jzMessage1.getJzCurUser());
            List<String> role = new ArrayList<>();
            for(SUser sUser: roles){
                role.add(sUser.getRoleCode());
            }
            if (!role.contains(SDictionaryServiceImpl.manager.get("三级经理")) && !"0".equals(jzMessage1.getJzProState())) {
                continue;
            }else if(role.contains(SDictionaryServiceImpl.manager.get("三级经理")) && !"0".equals(jzMessage1.getJzProState())){
                continue;
            }
            /*if(!"0".equals(jzMessage1.getJzProState())) continue;*/
            //判断
            //获取基站进度时间
            Date preTime = jzMessage1.getJzJdDate();
            //获取时间差 getDay：相差天数 getMonth 相差月数 getYear 相差年数
            TimeInfo timeInfo = GetTimeDifference.DayCompare(preTime, nowTime);
            if (timeInfo.getDay() >= deadline) {
                log.debug("相差天数: " + timeInfo.getDay() + " 当前的deadline: " + deadline);
                if (jzMessage1.getWarningStatus() == null && jzMessage1.getType() == null) {
                    //type 0： 业务员 warningStatus 0：未处理 1：已处理
                    UserWarning userWarning = new UserWarning();

                    // 设置字段
                    userWarning.setJzId(jzMessage1.getBusinessId());
                    userWarning.setUserId(jzMessage1.getJzCurUser());
                    userWarning.setType("0");
                    userWarning.setMessage("");
                    userWarning.setWarningStatus("0");
                    userWarning.setJzStatus(jzStatus);
                    userWarning.setNormal();
                    userWarning.setBusinessId(CyIdGenUtil.uuid());
                    userWarning.setCreateDate(new Date());
                    userWarning.setCreateBy("System");
                    //添加到业务员警告表
                    addWarningUsers.add(userWarning);
                }
                //需要更新的基站------考虑存在基站预警为0，业务员预警有预警信息的状态 的错误情况，更新所有超过指定时间基站预警状态
                changeJzMessage.add(jzMessage1);
            }
        }
        //告警中添加业务员
        if (addWarningUsers.size() > 0) {
            log.debug("业务员预警添加数目 : " + userWarningRepository.addMoreWarningUser(addWarningUsers));
        }
        //更新基站预警为预警状态
        if (changeJzMessage.size() > 0) {
            log.debug("基站预警更新数目 : " + String.valueOf(jzMessageRepository.updateJzJdWaring(changeJzMessage)));
        }
    }

    /**
     * 加入预警到达指定时间，仍未处理的”经理“的预警
     */
    public void managerWarning(int deadline, String jzStatus, String jzType) {

        //获取当前负责人的角色
        /*HashMap<String ,String> userRole = new HashMap<>();
        List<SUser> sUserList = sUserServiceImpl.queryAllUsers();
        for(SUser sUser:sUserList){
            userRole.put(sUser.getBusinessId(),sUser.getRoleCode());
        }*/

        //获得数据字典name为三级经理的值
        String code = SDictionaryServiceImpl.manager.get("三级经理");
        JzMessage jzMessage = new JzMessage();
        //设置未被删除的
        jzMessage.setNormal();
        //设置基站状态和基站类型
        jzMessage.setJzType(jzType);
        jzMessage.setJzState(jzStatus);
        //设置用户警告的类型为经理
        jzMessage.setType("1");
        List<JzMessage> jzMessageList = jzMessageRepository.selectUndoManagerNotInTable(jzMessage);
        log.debug("两表关联后的数据数目: " + jzMessageList.size() + " -----------------------------------");
        //需要添加的经理
        List<UserWarning> addmanagerWarning = new ArrayList<>();
        //需要更新预警状态的基站信息
        List<JzMessage> changeJzMessage = new ArrayList<>();
        //获取当前时间
        Date nowTime = new Date();
        for (JzMessage jzMessage1 : jzMessageList) {
            //如果基站进度时间为空则跳过
            if (jzMessage1.getJzJdDate() == null)
                continue;
            List<SUser> roles = sUserServiceImpl.queryRoleById(jzMessage1.getJzCurUser());
            List<String> role = new ArrayList<>();
            for(SUser sUser: roles){
                role.add(sUser.getRoleCode());
            }
            if ("0".equals(jzMessage1.getJzProState()) && role.contains(SDictionaryServiceImpl.manager.get("三级经理"))) {
                continue;
            }
   /*         List<String> managerList = new ArrayList<>();
            for (String value : SDictionaryServiceImpl.manager.values()) {
                managerList.add(value);
            }
            if ("0".equals(jzMessage1.getJzProState()) && role.retainAll(managerList)){
                continue;
            }*/

            //获取基站进度时间
            Date preTime = jzMessage1.getJzJdDate();
            //获取时间差 getDay：相差天数 getMonth 相差月数 getYear 相差年数
            TimeInfo timeInfo = GetTimeDifference.DayCompare(preTime, nowTime);
            if (timeInfo.getDay() >= deadline) {
                //判断
                if (jzMessage1.getWarningStatus() == null && jzMessage1.getType() == null) {
                    log.debug("相差天数: " + String.valueOf(timeInfo.getDay()));
                    //获取经理id
                    List<String> managerIds = userWarningRepository.queryManagerByUserId(jzMessage1.getJzCurUser(), code);
                    //type 0： 业务员 warningStatus 0：未处理 1：已处理
                    for (String managerId : managerIds) {
                        UserWarning managerWarning = new UserWarning();

                        //设置字段
                        managerWarning.setJzId(jzMessage1.getBusinessId());
                        managerWarning.setUserId(managerId);
                        managerWarning.setType("1");
                        managerWarning.setMessage("");
                        managerWarning.setWarningStatus("0");
                        managerWarning.setJzStatus(jzStatus);
                        managerWarning.setNormal();
                        managerWarning.setBusinessId(CyIdGenUtil.uuid());
                        managerWarning.setCreateDate(new Date());
                        managerWarning.setCreateBy("System");
                        //添加到业务员警告表
                        addmanagerWarning.add(managerWarning);
                    }
                    //需要更新的基站------考虑存在基站预警为0，业务员预警有预警信息的状态 的错误情况，更新所有超过指定时间基站预警状态
                    changeJzMessage.add(jzMessage1);
                }
            }
        }
        if (addmanagerWarning.size() > 0) {
            log.debug("经理预警添加数目 : " + userWarningRepository.addMoreWarningUser(addmanagerWarning));
        }
        //更新基站预警为预警状态
        if (changeJzMessage.size() > 0) {
            log.debug("基站预警更新数目 : " + String.valueOf(jzMessageRepository.updateJzJdWaring(changeJzMessage)));
        }
    }
}
