package org.rcisoft.business.quartz.service.impl;

import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.jzmessage.common.DictionaryMap;
import org.rcisoft.business.jzmessage.common.StartProcessHelper;
import org.rcisoft.business.quartz.dao.TimeTask;
import org.rcisoft.business.userwarning.dao.UserWarningRepository;
import org.rcisoft.common.BaseStationStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Profile;
import org.springframework.context.annotation.PropertySource;
import org.springframework.context.annotation.PropertySources;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

@PropertySource("classpath:application-cron.yml")
//@PropertySource("classpath:application-prod.yml")
@Component
@Slf4j
public class TaskStart {
    @Autowired
    private TimeTask timeTask;
    @Autowired
    private UserWarningRepository userWarningRepository;

    /**
     * 每隔一小时，更新数据字典
     * 测试：每隔30s更新数据字典
     * 秒 分 小时 月份中的日期 月份 星期中的日期 年份
     */
    /* @Scheduled(cron = "0 0 0/1 * * ?")*/  //一个小时
    /*  @Scheduled(cron = "0 0/10 * * * ?")*/  //十分钟
    /* @Scheduled(cron = "0 0/5 * * * ?")    //五分钟*/
//    @Scheduled(cron = "0/5 * * * * ?")  //五秒
    @Scheduled(cron = "${cron}")
    public void updateDataDictionary() {
        timeTask.updateDictionary();
    }

    //*********************选址状态的预警-----移动铁塔都有
    //业务员预警
    /*@Scheduled(cron = "0 0 0/1 * * ?")*/
//    @Scheduled(cron = "0 0/5 * * * ?")
    /*  @Scheduled(cron = "0/5 * * * * ?")*/
//    @Scheduled(cron = "0 0/10 * * * ?")
/*    @Scheduled(cron="${cron}")
    public void chooseStatusForUser() {
        //选址状态  3
        String jzStatus = BaseStationStatus.IT_WAIT_LOCATION.getCode();
        //铁塔或移动
        *//*String jzType = "1";*//*
        //时长限制


    }*/
    //经理预警
    /*@Scheduled(cron = "0 0 0/1 * * ?")*/
//   @Scheduled(cron = "0 0/5 * * * ?")
   /*@Scheduled(cron = "0/5 * * * * ?")*/
//    @Scheduled(cron = "0 0/10 * * * ?")
    @Scheduled(cron = "${cron}")
    public void chooseStatusForManager() {
        //选址状态  3
        String jzStatus = BaseStationStatus.IT_WAIT_LOCATION.getCode();
        //铁塔或移动
        /*       String jzType = "1";*/
        //时长限制
        //业务员预警
        String deadlineUserStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.IT_WAIT_LOCATION.getStatus(), DictionaryMap.jzDeadline);
        if (deadlineUserStr != null) {
            int deadline = Integer.parseInt(deadlineUserStr);
            timeTask.userWarning(deadline, jzStatus, null);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.IT_WAIT_LOCATION.getStatus() + " " + DictionaryMap.jzDeadline);
        }

        //经理预警
        String deadlineManStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.IT_WAIT_LOCATION.getStatus(), DictionaryMap.jzDeadline);

        if (deadlineManStr != null) {
            int deadline = Integer.parseInt(deadlineManStr);
            timeTask.managerWarning(deadline, jzStatus, null);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.IT_WAIT_LOCATION.getStatus() + " " + DictionaryMap.jzDeadline);
        }

    }

    //****************************************************
    //*********************会审状态的预警-----移动铁塔都有
    //业务员预警
    /* @Scheduled(cron = "0 0 0/1 * * ?")*/
//   @Scheduled(cron = "0 0/5 * * * ?")
//    @Scheduled(cron = "0/5 * * * * ?")
    /*    @Scheduled(cron = "0 0/10 * * * ?")*/
    @Scheduled(cron = "${cron}")
    public void checkStatusForUser() {
        //会审状态   5
        String jzStatus = BaseStationStatus.IT_WAIT_TRIAGE.getCode();
        //铁塔或移动
        /*String jzType = "1";*/
        //时长限制
        String deadlineStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.IT_WAIT_TRIAGE.getStatus(), DictionaryMap.jzDeadline);
        if (deadlineStr != null) {
            int deadline = Integer.parseInt(deadlineStr);
            timeTask.userWarning(deadline, jzStatus, null);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.IT_WAIT_TRIAGE.getStatus() + " " + DictionaryMap.jzDeadline);
        }
    }
    //******************************************************
    //*********************交底状态的预警-----只有移动有

    /*@Scheduled(cron = "0 0 0/1 * * ?")*/
//   @Scheduled(cron = "0 0/5 * * * ?")
//    @Scheduled(cron = "0/5 * * * * ?")
    /*    @Scheduled(cron = "0 0/10 * * * ?")*/
    @Scheduled(cron = "${cron}")
    public void disclosureStatusForUser() {
        //交底状态   6
        String jzStatus = BaseStationStatus.MC_WAIT_DISCLOSURE.getCode();
        //移动
        String jzType = StartProcessHelper.RAILCOM;
        //时长限制
        String deadlineStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.MC_WAIT_DISCLOSURE.getStatus(), DictionaryMap.jzDeadline);
        if (deadlineStr != null) {
            int deadline = Integer.parseInt(deadlineStr);
            timeTask.userWarning(deadline, jzStatus, jzType);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.MC_WAIT_DISCLOSURE.getStatus() + " " + DictionaryMap.jzDeadline);
        }
    }

    //**********************************************************
    //*********************领料状态的预警-----移动铁塔都有
    //业务员预警
    /* @Scheduled(cron = "0 0 0/1 * * ?")*/
//     @Scheduled(cron = "0 0/5 * * * ?")
//    @Scheduled(cron = "0/5 * * * * ?")
    /* @Scheduled(cron = "0 0/10 * * * ?")*/
    @Scheduled(cron = "${cron}")
    public void pickingStatusForUser() {
        //领料状态   8
        String jzStatus = BaseStationStatus.MC_WAIT_PACKING.getCode();
        //铁塔或移动 注释则为都有
        /*String jzType = "1";*/
        //时长限制
        String deadlineStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.MC_WAIT_PACKING.getStatus(), DictionaryMap.jzDeadline);
        if (deadlineStr != null) {
            int deadline = Integer.parseInt(deadlineStr);
            timeTask.userWarning(deadline, jzStatus, null);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.MC_WAIT_PACKING.getStatus() + " " + DictionaryMap.jzDeadline);
        }
    }

    //**********************************************************
    //*********************交资状态的预警-----只有移动有
    /*@Scheduled(cron = "0 0 0/1 * * ?")*/
//    @Scheduled(cron = "0 0/5 * * * ?")
//    @Scheduled(cron = "0/5 * * * * ?")
    //  @Scheduled(cron = "0 0/10 * * * ?")
    @Scheduled(cron = "${cron}")
    public void payCapitalStatusForUser() {
        //交资状态  13
        String jzStatus = BaseStationStatus.MC_WAIT_CAPITAL.getCode();
        //移动
        String jzType = StartProcessHelper.RAILCOM;
        ;
        String deadlineStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.MC_WAIT_CAPITAL.getStatus(), DictionaryMap.jzDeadline);
        if (deadlineStr != null) {
            int deadline = Integer.parseInt(deadlineStr);
            timeTask.userWarning(deadline, jzStatus, jzType);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.MC_WAIT_CAPITAL.getStatus() + " " + DictionaryMap.jzDeadline);
        }
    }

    //**********************************************************
    //********************交维状态的预警-----移动铁塔都有
    //业务员预警
    /*@Scheduled(cron = "0 0 0/1 * * ?")*/
//    @Scheduled(cron = "0 0/5 * * * ?")
//    @Scheduled(cron = "0/5 * * * * ?")
    // @Scheduled(cron = "0 0/10 * * * ?")
    @Scheduled(cron = "${cron}")
    public void intersectionDimensionStatusForUser() {
        //交维状态   16
        String jzStatus = BaseStationStatus.IT_WAIT_MAINTAIN.getCode();
        //铁塔或移动 注释则为都有
        /*String jzType = "1";*/
        //时长限制
        String deadlineStr = userWarningRepository.queryDeadlineFromsDictionary(BaseStationStatus.IT_WAIT_MAINTAIN.getStatus(), DictionaryMap.jzDeadline);
        if (deadlineStr != null) {
            int deadline = Integer.parseInt(deadlineStr);
            timeTask.userWarning(deadline, jzStatus, null);
        } else {
            log.info("数据字典中无法查到： " + BaseStationStatus.IT_WAIT_MAINTAIN.getStatus() + " " + DictionaryMap.jzDeadline);
        }
    }
}
