package org.rcisoft.business.querytask.entity;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;

import org.rcisoft.core.entity.CyIdNotDataEntity;
import javax.persistence.*;
import java.util.Date;
import java.util.List;

/**
* Created with Ryan on 2019-7-26 10:53:11.
*/
@ApiModel(value = "ToDoTask",description = "待办任务表")
@Entity
@Data
@NoArgsConstructor
@AllArgsConstructor
@Table(name = "v_todotasklist")
public class ToDoTask extends CyIdNotDataEntity<ToDoTask> {


     /**
     * @desc 基站号
     * @column jz_code
     * @default 
     */
     @ApiModelProperty(value = "基站号",dataType = "String")
     private String jzCode;
     /**
     * @desc 基站名
     * @column jz_name
     * @default 
     */
     @ApiModelProperty(value = "基站名",dataType = "String")
     private String jzName;
     /**
     * @desc 业务线     飞箱选址 0  铁塔选址 1 小站选址 2 电费代缴 3
     * @column jz_line
     * @default 
     */
     @ApiModelProperty(value = "业务线",dataType = "String",allowableValues = "0(飞箱选址),1(铁塔选址),2(小站选址),3(电费代缴)")
     private String jzLine;
     /**
     * @desc 运营商     移动 0
            运营商     移动 0
     * @column jz_yys
     * @default 
     */
     @ApiModelProperty(value = "运营商",dataType = "String",allowableValues = "0(移动)")
     private String jzYys;
     /**
     * @desc 区域
     * @column jz_qy
     * @default 
     */
     @ApiModelProperty(value = "区域",dataType = "String")
     private String jzQy;
     /**
     * @desc 基站类型 0 代缴站 1 铁通(移动)  2 航数(铁塔)
     * @column jz_type
     * @default 
     */
     @ApiModelProperty(value = "基站类型",dataType = "String",allowableValues = "0(代缴站),1(铁通(移动)), 2(航数(铁塔))")
     private String jzType;
     /**
     * @desc 部门名称
     * @column jz_dept
     * @default 
     */
     @ApiModelProperty(value = "部门名称",dataType = "jz_dept")
     private String jzDept;
     /**
     * @desc 基站状态 (移动) 0 需求取消 1 已开通 2 待选址 3 待勘察 4 待会审 5 待交底 
            6 待领料 7 待施工和验收 8 待开通 9 待签单 10 待交资 11 待交维 12 xxx 13 以拆站
            (铁塔)0 需求取消 1 已开通 2 待选址 3 待勘察 4 待会审 5 待立项 6 待领料
            7 待施工 8 待完工 9 待交付 10 待起租 11待签署 12待交维 13 xxx 
            14 已拆站
     * @column jz_state
     * @default 
     */
     @ApiModelProperty(value = "基站状态 0需求取消 ...",dataType = "String")
     private String jzState;
     /**
      * @desc 流程状态 0 待审批  1 通过  2 驳回
      * @column jz_pro_state
      * @default
      */
     @ApiModelProperty(value = "流程状态(0 待审批 1 通过 2驳回)",dataType = "String")
     private String jzProState;
     /**
     * @desc 基站创建时间  日期框
     * @column jz_creat_date
     * @default 
     */
     @ApiModelProperty(value = "基站创建时间",dataType = "date")
     private Date jzCreateDate;
     /**
     * @desc 
     * @column task_id
     * @default 
     */
     @ApiModelProperty(value = "任务id",dataType = "String")
     private String taskId;
     /**
     * @desc 项目编号（唯一键）
     * @column jz_business_key
     * @default 
     */
     @ApiModelProperty(value = "不是项目编号",dataType = "String")
     private String jzBusinessKey;
     /**
     * @desc 
     * @column assignee
     * @default 
     */
     @ApiModelProperty(value = "办理人",dataType = "String")
     private String assignee;
     /**
      * @desc
      * @column candidate
      * @default
      */
     @ApiModelProperty(value = "候选人",dataType = "String")
     private String candidate;
     /**
      * @desc
      * @column roleList
      * @default
      */
     @Transient
     private List<String> roleList;
     /**
      * @desc
      * @column deptIdList
      * @default
      */
     @Transient
     private List<String> deptIdList;

     /**
      * @desc
      * @column project_code
      * @default
      */
     @ApiModelProperty(value = "项目编号",dataType = "String")
     private  String projectCode;

     /**
      * @desc
      * @column jz_up_custom
      * @default
      */
     @ApiModelProperty(value = "上游客户",dataType = "String")
     private String jzUpCustom;

     /**
      * @desc
      * @column business_line
      * @default
      */
     @ApiModelProperty(value = "业务线",dataType = "String")
     private String businessLine;
     /**
      * @desc
      * @column task_name
      * @default
      */
     @ApiModelProperty(value = "任务名称",dataType = "String")
     private String taskName;
     /**
      * @desc
      * @column type_template
      * @default
      */
     @ApiModelProperty(value = "流程类型",dataType = "String")
     private String typeTemplate;

     @Transient
     private String sDicYysType;
     @Transient
     private String sDicUpperType;

     @Transient
     private String upperTtName;

     @Transient
     private String upperYdName;

     @Transient
     @ApiModelProperty(value = "上游客户名字",dataType = "String",allowableValues = "0铁通 , 1铁塔")
     private String upperName;

     @Transient
     private String yysDjName;

     @Transient
     private String yysYdName;

     @Transient
     private String yysTtName;
     @Transient
     private String ywxName;

     /**
      * 基站类型名称
      */
     @Transient
     private String typeName;
     /**
      * 运营商名称，对应s_dictionary表中name字段
      */
     @ApiModelProperty(value = "运营商名称",dataType = "String")
     @Transient
     private String yysName;

     @Transient
     private String projectId;
}

