package org.rcisoft.business.querytask.service.impl;

import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.jzmessage.common.TypeEnum;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.querytask.dao.QueryCompletedTaskRepository;
import org.rcisoft.business.querytask.dao.QueryTasksRepository;
import org.rcisoft.business.querytask.entity.CompletedTask;
import org.rcisoft.business.querytask.entity.ToDoTask;
import org.rcisoft.business.querytask.service.QueryTasksService;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.sys.dept.dao.SysDeptRepository;
import org.rcisoft.sys.dept.entity.SysDept;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

@Service
public class QueryTasksServiceImpl implements QueryTasksService {

    @Autowired
    QueryTasksRepository queryTasksRepository;

    @Autowired
    QueryCompletedTaskRepository queryCompletedTaskRepository;

    @Autowired
    SysDeptRepository sysDeptRepository;

    @Override
    public List<ToDoTask> findTodoTasksByPagination(CyPageUtil<ToDoTask> paginationUtility,
            ToDoTask toDoTask, List<String> deptIdList) {
        toDoTask.setAssignee(CyUserUtil.getAuthenBusinessId());//获取登录人的businessId
        List<String> candidate = Arrays.asList(CyUserUtil.getAuthenRoleStr().split(","));//获取登录人的角色列表
        //前台有个搜索框比较特殊（基站状态），这段代码用于该搜索框，它向后台传 jzType和jzState 例如jzType = 0 jzState = 1
        //它会传 jzState = 01，这段代码用于分割jzType和jzState 取第一位为jzType 后面为jzState
        //已办和基站信息查询里面有相同的代码
        //解析当前选择运营商 运行商格式  JZ_DJ_YYS,1
        String[] jzYys = new String[3];
        String[] jzUpCustom = new String[3];
        String[] jzState = new String[3];
        if (StringUtils.isNotEmpty(toDoTask.getJzYys())) {
            jzYys = toDoTask.getJzYys().split(",");
            toDoTask.setSDicYysType(jzYys[1]); //数据字典类型
            toDoTask.setJzYys(jzYys[2]);//数据字典属性
        }
        //解析当前选择上游客户 JZ_YD_UPPER,1
        if (StringUtils.isNotEmpty(toDoTask.getJzUpCustom())) {
            jzUpCustom = toDoTask.getJzUpCustom().split(",");
            toDoTask.setSDicUpperType(jzUpCustom[1]); //数据字典类型
            toDoTask.setJzUpCustom(jzUpCustom[2]);//数据字典属性
        }
        //解析基站状态 1,3 (1代表基站类型jz_type 3代表基站状态 jz_state)
        if (StringUtils.isNotEmpty(toDoTask.getJzState())) {
            jzState = toDoTask.getJzState().split(",");
            toDoTask.setJzState(jzState[1]);
        }
        if (StringUtils.isNotEmpty(toDoTask.getJzState()) && StringUtils.isEmpty(toDoTask.getJzType())) {
            toDoTask.setJzType(jzState[0]);
        } else if (StringUtils.isNotEmpty(toDoTask.getJzUpCustom()) && StringUtils.isEmpty(toDoTask.getJzType())) {
            toDoTask.setJzType(jzUpCustom[0]);//基站类型
        } else if (StringUtils.isNotEmpty(toDoTask.getJzYys()) && StringUtils.isEmpty(toDoTask.getJzType())) {
            toDoTask.setJzType(jzYys[0]);//基站类型
        }
        toDoTask.setRoleList(candidate);
        toDoTask.setDeptIdList(deptIdList);
        List<ToDoTask> toDoTasks = queryTasksRepository.queryToDoTaskLists(toDoTask);
        for (ToDoTask item : toDoTasks) {
            if (StringUtils.isEmpty(item.getJzType())) {
                continue;
            }
            if (item.getJzType().equals("0")) {
                item.setTypeName(TypeEnum.DJ.getname()); //设置基站类型名称
                item.setYysName(item.getYysDjName());//设置运营商名字
            }
            if (item.getJzType().equals("1")) {
                item.setTypeName(TypeEnum.YD.getname());
                item.setYysName(item.getYysYdName());
                item.setUpperName(item.getUpperYdName()); //设置上游客户名字
            }
            if (item.getJzType().equals("2")) {
                item.setTypeName(TypeEnum.TT.getname());
                item.setYysName(item.getYysTtName());
                item.setUpperName(item.getUpperTtName());
            }

        }
        return toDoTasks;

    }

    @Override
    public List<CompletedTask> findCompletedTasksByPagination(CyPageUtil<CompletedTask> paginationUtility,
            CompletedTask completedTask) {
        String[] jzYys = new String[3];
        String[] jzUpCustom = new String[3];
        String[] jzState = new String[3];
        //解析当前选择运营商 运行商格式  JZ_DJ_YYS,1
        if (StringUtils.isNotEmpty(completedTask.getJzYys())) {
            jzYys = completedTask.getJzYys().split(",");
            completedTask.setSDicYysType(jzYys[1]); //数据字典类型
            completedTask.setJzYys(jzYys[2]);//数据字典属性
        }
        //解析当前选择上游客户 JZ_YD_UPPER,1
        if (StringUtils.isNotEmpty(completedTask.getJzUpCustom())) {
            jzUpCustom = completedTask.getJzUpCustom().split(",");
            completedTask.setSDicUpperType(jzUpCustom[1]); //数据字典类型
            completedTask.setJzUpCustom(jzUpCustom[2]);//数据字典属性
        }
        //解析基站状态 1,3 (1代表基站类型jz_type 3代表基站状态 jz_state)
        if (StringUtils.isNotEmpty(completedTask.getJzState()) && StringUtils.isEmpty(completedTask.getJzType())) {
            jzState = completedTask.getJzState().split(",");
            completedTask.setJzType(jzState[0]);
            completedTask.setJzState(jzState[1]);
        }
        if (StringUtils.isNotEmpty(completedTask.getJzState()) && StringUtils.isEmpty(completedTask.getJzType())) {
            completedTask.setJzType(jzState[0]);
        } else if (StringUtils.isNotEmpty(completedTask.getJzUpCustom()) && StringUtils.isEmpty(completedTask.getJzType())) {
            completedTask.setJzType(jzUpCustom[0]);//基站类型
        } else if (StringUtils.isNotEmpty(completedTask.getJzYys()) && StringUtils.isEmpty(completedTask.getJzType())) {
            completedTask.setJzType(jzYys[0]);//基站类型
        }
        completedTask.setAssignee(CyUserUtil.getAuthenBusinessId());//获取登录人的businessId
        List<CompletedTask> completedTasks = queryCompletedTaskRepository.queryCompletedTaskLists(completedTask);
        for (CompletedTask item : completedTasks) {
            if (StringUtils.isEmpty(item.getJzType())) {
                continue;
            }
            if (item.getJzType().equals("0")) {
                item.setTypeName(TypeEnum.DJ.getname()); //设置基站类型名称
                item.setYysName(item.getYysDjName());//设置运营商名字
            }
            if (item.getJzType().equals("1")) {
                item.setTypeName(TypeEnum.YD.getname());
                item.setYysName(item.getYysYdName());
                item.setUpperName(item.getUpperYdName()); //设置上游客户名字
            }
            if (item.getJzType().equals("2")) {
                item.setTypeName(TypeEnum.TT.getname());
                item.setYysName(item.getYysTtName());
                item.setUpperName(item.getUpperTtName());
            }

        }

        return completedTasks;
    }
}
