package org.rcisoft.business.sdictionary.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.sys.dictionary.service.impl.DictionaryServiceImpl;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.sdictionary.entity.SDictionary;
import org.rcisoft.business.sdictionary.service.SDictionaryService;

import java.util.List;

/**
* Created by lpy on 2019-7-30 12:51:26.
*/
@RestController
@RequestMapping("/sdictionary")
public class SDictionaryController extends CyPaginationController<SDictionary> {

    @Autowired
    private SDictionaryService sDictionaryServiceImpl;
    @Autowired
    private DictionaryServiceImpl dictionaryServiceImpl;

    @ApiOperation(value="添加数据字典", notes="添加数据字典")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid SDictionary sDictionary, BindingResult bindingResult) {
        CyPersistModel data = sDictionaryServiceImpl.save(sDictionary);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sDictionary);
    }
    @ApiOperation(value="逻辑删除数据字典", notes="逻辑删除数据字典")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,SDictionary sDictionary) {
        sDictionary.setBusinessId(businessId);
        CyPersistModel data = sDictionaryServiceImpl.removeLogical(sDictionary);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="删除数据字典", notes="删除数据字典")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,SDictionary sDictionary) {
        sDictionary.setBusinessId(businessId);
        CyPersistModel data = sDictionaryServiceImpl.remove(sDictionary);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="修改数据字典", notes="修改数据字典")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid SDictionary sDictionary, BindingResult bindingResult) {
        sDictionary.setBusinessId(businessId);
        CyPersistModel data = sDictionaryServiceImpl.merge(sDictionary);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sDictionary);
    }

    @ApiOperation(value="查询单一数据字典", notes="查询单一数据字典")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sDictionaryServiceImpl.findById(businessId));
    }

    @ApiOperation(value="查询数据字典集合", notes="查询数据字典集合")
    @GetMapping(value = "/querySDictionarys")
    public CyResult querySDictionarys(SDictionary sDictionary) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sDictionaryServiceImpl.findAll(sDictionary));
    }

    @ApiOperation(value="分页查询数据字典集合", notes="分页查询数据字典集合")
    @GetMapping(value = "/querySDictionaryByPagination")
    public CyGridModel listByPagination(SDictionary sDictionary) {
        sDictionaryServiceImpl.findAllByPagination(getPaginationUtility(), sDictionary);
        return getGridModelResponse();
    }
}
