package org.rcisoft.business.suser.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.suser.entity.SUser;
import org.rcisoft.business.suser.service.SUserService;

import java.util.List;

/**
* Created by cy on 2019-8-5 15:25:04.
*/
@RestController
@RequestMapping("/suser")
public class SUserController extends CyPaginationController<SUser> {

    @Autowired
    private SUserService sUserServiceImpl;


    @ApiOperation(value = "添加用户表", notes = "添加用户表")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid SUser sUser, BindingResult bindingResult) {
        CyPersistModel data = sUserServiceImpl.save(sUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUser);
    }

    @ApiOperation(value = "逻辑删除用户表", notes = "逻辑删除用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, SUser sUser) {
        sUser.setBusinessId(businessId);
        CyPersistModel data = sUserServiceImpl.removeLogical(sUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "删除用户表", notes = "删除用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, SUser sUser) {
        sUser.setBusinessId(businessId);
        CyPersistModel data = sUserServiceImpl.remove(sUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "修改用户表", notes = "修改用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid SUser sUser, BindingResult bindingResult) {
        sUser.setBusinessId(businessId);
        CyPersistModel data = sUserServiceImpl.merge(sUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUser);
    }

    @ApiOperation(value = "查询单一用户表", notes = "查询单一用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.findById(businessId));
    }


    @ApiOperation(value = "查询用户表集合", notes = "查询用户表集合")
    @GetMapping(value = "/querySUsers")
    public CyResult querySUsers(SUser sUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.findAll(sUser));
    }

    @ApiOperation(value = "分页查询用户表集合", notes = "分页查询用户表集合")
    @GetMapping(value = "/querySUserByPagination")
    public CyGridModel listByPagination(SUser sUser) {
        sUserServiceImpl.findAllByPagination(getPaginationUtility(), sUser);
        return getGridModelResponse();
    }

    @ApiOperation(value = "查询用户表集合", notes = "查询用户表集合")
    @GetMapping(value = "/queryAllUsers")
    public CyResult querySUsersInfo(String deptId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.findAllUser(deptId));

    }

    @ApiOperation(value = "返回维护部人员", notes = "返回维护部人员")
    @GetMapping(value = "/getMaintainPerson")
    public CyResult getMaintainPerson() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.getMaintainPersonList());
    }

/*    @ApiOperation(value = "返回维护部人员", notes = "返回维护部人员")
    @GetMapping(value = "/getMyMaintainPerson")
    public CyResult getMyMaintainPerson() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.getMyMaintainPersonList());
    }*/

    @ApiOperation(value = "查询单一用户姓名", notes = "查询单一用户姓名")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/userName/{businessId:\\w+}")
    public CyResult userName(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.findUserNameById(businessId));
    }

    @ApiOperation(value = "查询是否为导入导出管理员", notes = "查询是否为导入导出管理员")
    @GetMapping(value = "/getSpecialIdentity")
    public CyResult getSpecialIdentity() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.isSpecialIdentity());
    }

    /**
     * 金蝶走流程
     *
     * @param projectCode
     * @return
     */

    @ApiOperation(value = "根据项目编号获取阶段负责人", notes = "根据项目编号获取阶段负责人")
    @GetMapping(value = "/selectUserByProjectCode")
    public CyResult selectUserByProjectCode(@RequestParam("projectCode") String projectCode) {
        if(sUserServiceImpl.selectUserByProjectCode(projectCode)==null){
        return CyResultGenUtil.builder(new CyPersistModel(-1),
                    CyMessCons.MESSAGE_ALERT_SUCCESS,
                    CyMessCons.MESSAGE_ALERT_ERROR,
                    sUserServiceImpl.selectUserByProjectCode(projectCode));

        }
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.selectUserByProjectCode(projectCode));
    }

    /**
     * 根据项目编号和类型获取审批人和当前任务id
     */
    @ApiOperation(value = "根据项目编号和类型获取当前审批人", notes = "根据项目编号和类型获取当前审批人")
    @GetMapping(value = "/toDOTaskUser")
    public CyResult toDOTaskUser(@RequestParam("projectCode")String projectCode,@RequestParam("templateType") String templateType){
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sUserServiceImpl.toDOTaskUser(projectCode,templateType));
    }
}