package org.rcisoft.business.suser.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpEntity;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.http.util.EntityUtils;
import org.rcisoft.business.suser.dao.SDeptSYNRepo;
import org.rcisoft.business.suser.dao.SRoleSYNRepo;
import org.rcisoft.business.suser.dao.SUserRepository;
import org.rcisoft.business.suser.dao.SUserRoleSYNRepo;
import org.rcisoft.business.suser.entity.*;
import org.rcisoft.business.suser.service.SUserSYNService;
import org.rcisoft.business.suser.service.SUserService;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.CyResultSystemExceptionEnums;
import org.rcisoft.core.service.CyBaseService;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.util.*;

@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class SUserSYNServiceImpl extends CyBaseService implements SUserSYNService {

    @Autowired
    private SRoleSYNRepo sRoleSYNRepo;

    @Autowired
    private SDeptSYNRepo sDeptSYNRepo;

    @Autowired
    private SUserRepository sUserRepository;

    @Autowired
    private SUserRoleSYNRepo sUserRoleSYNRepo;

    @Autowired
    private SUserService sUserService;

    @Autowired
    private PasswordEncoder passwordEncoder;

    @Value("${global.path.user_synchronized}")
    private String USER_SYNCHRONIZED;

    @Value("${global.path.app_id}")
    private String APP_ID;

    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public CyPersistModel synUser(String timestamp, String sign){
        String token = "";

        //判断当前登陆用户是否为管理员
        if(!sUserService.isAdmin()){
            return new CyPersistModel(-1);
        }

        // 获得Http客户端(可以理解为:你得先有一个浏览器;注意:实际上HttpClient与浏览器是不一样的)
        CloseableHttpClient httpClient = HttpClientBuilder.create().build();

        //创建get请求
        HttpGet httpGet = new HttpGet(USER_SYNCHRONIZED + "/token?app_id=" + APP_ID + "&timestamp=" + timestamp + "&sign=" + sign);

        // 响应模型
        CloseableHttpResponse response = null;

        try {
            // 配置信息
            RequestConfig requestConfig = RequestConfig.custom()
                    // 设置连接超时时间(单位毫秒)
                    .setConnectTimeout(5000)
                    // 设置请求超时时间(单位毫秒)
                    .setConnectionRequestTimeout(5000)
                    // socket读写超时时间(单位毫秒)
                    .setSocketTimeout(5000)
                    // 设置是否允许重定向(默认为true)
                    .setRedirectsEnabled(true).build();

            // 将上面的配置信息 运用到这个Get请求里
            httpGet.setConfig(requestConfig);

            // 由客户端执行(发送)Get请求
            response = httpClient.execute(httpGet);

            // 从响应模型中获取响应实体
            HttpEntity responseEntity = response.getEntity();
            if (response.getStatusLine().getStatusCode() == 200 && responseEntity != null) {
                //取出实体中的数据
                String str = EntityUtils.toString(responseEntity);
                //将数据转换成json数据
                //JSONObject jsonObject = JSONObject.parseObject(str);
                String str1 = JSONObject.parseObject(str).get("data").toString();
                Map mapTypes = JSON.parseObject(str1);
                for (Object obj : mapTypes.keySet()){
                    log.debug("-----------------" + "key为："+obj+"值为："+mapTypes.get(obj));
                }

                token = mapTypes.get("token").toString();
                log.debug("-------------------------" + token);
            } else {
                return new CyPersistModel(-2);
            }
        } catch (Exception e) {
            throw new CyServiceException(CyResultSystemExceptionEnums.FAIL);
        } finally {
            try {
                // 释放资源
                if (httpClient != null) {
                    httpClient.close();
                }
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return synUsers(token);
        //return new CyPersistModel(200);
    }

    /**
     * 同步用户
     *
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public CyPersistModel synUsers(String token) {

        List<SDept> sDepts = this.saveDept(token);
        List<SRole> sRoles = this.saveRole(token);
        List<SUserSYN> sUserSYNS = this.saveUser(token);

        List<SUser> sUserList = new ArrayList<>();
        List<SUserRole> sUserRoles = new ArrayList<>();

        for(SUserSYN sUserSYN: sUserSYNS){
            SUser sUser = new SUser();
            sUser.setDeptId(sUserSYN.getDeptId());
            sUser.setName(sUserSYN.getName());
            sUser.setLoginName(sUserSYN.getBusinessId());
            sUser.setPassword(passwordEncoder.encode(sUserSYN.getBusinessId()));
            CyUserUtil.setCurrentPersistOperation(sUser);
            sUser.setBusinessId(sUserSYN.getBusinessId());
            sUserList.add(sUser);

            if (sUserSYN.getRoleId() != null &&
                    !"".equals(sUserSYN.getRoleId())) {
                String[] strs = String.valueOf(sUserSYN.getRoleId()).split(",");
                List<String> list = new ArrayList<>();
                Collections.addAll(list, strs);
                for(String role:list){
                    SUserRole sUserRole = new SUserRole();
                    CyUserUtil.setCurrentPersistOperation(sUserRole);
                    sUserRole.setUserId(sUserSYN.getBusinessId());
                    sUserRole.setRoleId(role);
                    sUserRoles.add(sUserRole);
                }
            }
        }

        sUserRoleSYNRepo.removeAll();
        sUserRepository.removeAll();
        sRoleSYNRepo.removeAll();
        sDeptSYNRepo.removeAll();

        int deptRes = sDeptSYNRepo.saveDeptSYN(sDepts);
        int roleRes = sRoleSYNRepo.saveRoleSYN(sRoles);
        int userRes = sUserRepository.saveUserSYN(sUserList);
        if (userRes > 0) {
            userRes = sUserRoleSYNRepo.saveUserRoleSYN(sUserRoles);
        }

        if (deptRes <= 0 ||
                roleRes <= 0 ||
                userRes <= 0) {
            throw new CyServiceException(CyResultSystemExceptionEnums.FAIL);
        }
        return new CyPersistModel(200);
    }

    /**
     * 保存部门表
     *
     * @param token
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public List<SDept> saveDept(String token) {

        List<SDept> sDepts = new ArrayList<>();
        // 获得Http客户端(可以理解为:你得先有一个浏览器;注意:实际上HttpClient与浏览器是不一样的)
        CloseableHttpClient httpClient = HttpClientBuilder.create().build();

        //创建get请求
        HttpGet httpGet = new HttpGet(USER_SYNCHRONIZED + "/dept?token=" + token);

        // 响应模型
        CloseableHttpResponse response = null;

        try {
            // 配置信息
            RequestConfig requestConfig = RequestConfig.custom()
                    // 设置连接超时时间(单位毫秒)
                    .setConnectTimeout(5000)
                    // 设置请求超时时间(单位毫秒)
                    .setConnectionRequestTimeout(5000)
                    // socket读写超时时间(单位毫秒)
                    .setSocketTimeout(5000)
                    // 设置是否允许重定向(默认为true)
                    .setRedirectsEnabled(true).build();

            // 将上面的配置信息 运用到这个Get请求里
            httpGet.setConfig(requestConfig);

            // 由客户端执行(发送)Get请求
            response = httpClient.execute(httpGet);

            // 从响应模型中获取响应实体
            HttpEntity responseEntity = response.getEntity();
            if (response.getStatusLine().getStatusCode() == 200 && responseEntity != null) {
                //取出实体中的数据
                String str = EntityUtils.toString(responseEntity);
                //将数据转换成json数据
                JSONObject jsonObject = JSONObject.parseObject(str);
                JSONArray jsonArray = JSONObject.parseArray(jsonObject.get("data").toString());
                //将json数组转换成list数组
                SDept dept0 = new SDept();
                CyUserUtil.setCurrentPersistOperation(dept0);
                dept0.setName("北京广厦");
                dept0.setCode("0");
                dept0.setBusinessId("0");
                sDepts.add(dept0);
                for (int i = 0; i < jsonArray.size(); i++) {
                    SDept dept = new SDept();
                    CyUserUtil.setCurrentPersistOperation(dept);
                    //判断部门id是否为空，不为空继续，为空跳过进行下一个循环
                    if (jsonArray.getJSONObject(i).get("id") != null) {
                        dept.setName(String.valueOf(jsonArray.getJSONObject(i).get("name")));
                        dept.setParentId(String.valueOf(jsonArray.getJSONObject(i).get("pid")));
                        dept.setSort(Integer.parseInt(String.valueOf(jsonArray.getJSONObject(i).get("sort"))));
                        dept.setBusinessId(String.valueOf(jsonArray.getJSONObject(i).get("id")));
                        dept.setCode(dept.getBusinessId());
                        sDepts.add(dept);
                    } else {
                        continue;
                    }
                }
            }
        } catch (Exception e) {

        } finally {
            try {
                // 释放资源
                if (httpClient != null) {
                    httpClient.close();
                }
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return sDepts;
    }

    /**
     * 保存角色表
     *
     * @param token
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public List<SRole> saveRole(String token) {
        List<SRole> sRoles = new ArrayList<>();
        // 获得Http客户端(可以理解为:你得先有一个浏览器;注意:实际上HttpClient与浏览器是不一样的)
        CloseableHttpClient httpClient = HttpClientBuilder.create().build();

        //创建get请求
        HttpGet httpGet = new HttpGet(USER_SYNCHRONIZED + "/roles?token=" + token);

        // 响应模型
        CloseableHttpResponse response = null;

        try {
            // 配置信息
            RequestConfig requestConfig = RequestConfig.custom()
                    // 设置连接超时时间(单位毫秒)
                    .setConnectTimeout(5000)
                    // 设置请求超时时间(单位毫秒)
                    .setConnectionRequestTimeout(5000)
                    // socket读写超时时间(单位毫秒)
                    .setSocketTimeout(5000)
                    // 设置是否允许重定向(默认为true)
                    .setRedirectsEnabled(true).build();

            // 将上面的配置信息 运用到这个Get请求里
            httpGet.setConfig(requestConfig);

            // 由客户端执行(发送)Get请求
            response = httpClient.execute(httpGet);

            // 从响应模型中获取响应实体
            HttpEntity responseEntity = response.getEntity();
            if (response.getStatusLine().getStatusCode() == 200 && responseEntity != null) {
                //取出实体中的数据
                String str = EntityUtils.toString(responseEntity);
                //将数据转换成json数据
                JSONObject jsonObject = JSONObject.parseObject(str);
                JSONArray jsonArray = JSONObject.parseArray(jsonObject.get("data").toString());
                //将json数组转换成list数组
                for (int i = 0; i < jsonArray.size(); i++) {
                    SRole sRole = new SRole();
                    CyUserUtil.setCurrentPersistOperation(sRole);
                    //判断角色id是否为空，不为空继续，为空跳过进行下一个循环
                    if (jsonArray.getJSONObject(i).get("id") != null &&
                            jsonArray.getJSONObject(i).get("title") != null) {
                        CyUserUtil.setCurrentPersistOperation(sRole);
                        sRole.setBusinessId(String.valueOf(jsonArray.getJSONObject(i).get("id")));
                        sRole.setRoleName(String.valueOf(jsonArray.getJSONObject(i).get("title")));
                        sRole.setCode(sRole.getBusinessId());
                        sRoles.add(sRole);
                    } else {
                        continue;
                    }
                }
            }
        } catch (Exception e) {

        } finally {
            try {
                // 释放资源
                if (httpClient != null) {
                    httpClient.close();
                }
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return sRoles;
    }

    /**
     * 保存用户表
     *
     * @param token
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public List<SUserSYN> saveUser(String token) {
        List<SUserSYN> sUserSYNS = new ArrayList<>();

        // 获得Http客户端(可以理解为:你得先有一个浏览器;注意:实际上HttpClient与浏览器是不一样的)
        CloseableHttpClient httpClient = HttpClientBuilder.create().build();

        //创建get请求
        HttpGet httpGet = new HttpGet(USER_SYNCHRONIZED + "/staffs?token=" + token);

        // 响应模型
        CloseableHttpResponse response = null;

        try {
            // 配置信息
            RequestConfig requestConfig = RequestConfig.custom()
                    // 设置连接超时时间(单位毫秒)
                    .setConnectTimeout(5000)
                    // 设置请求超时时间(单位毫秒)
                    .setConnectionRequestTimeout(5000)
                    // socket读写超时时间(单位毫秒)
                    .setSocketTimeout(5000)
                    // 设置是否允许重定向(默认为true)
                    .setRedirectsEnabled(true).build();

            // 将上面的配置信息 运用到这个Get请求里
            httpGet.setConfig(requestConfig);

            // 由客户端执行(发送)Get请求
            response = httpClient.execute(httpGet);

            // 从响应模型中获取响应实体
            HttpEntity responseEntity = response.getEntity();
            if (responseEntity != null) {
                String str = EntityUtils.toString(responseEntity);
                JSONObject jsonObject = JSONObject.parseObject(str);
                JSONArray jsonArray = JSONObject.parseArray(jsonObject.get("data").toString());
                //将json数组转换成list数组
                for (int i = 0; i < jsonArray.size(); i++) {
                    SUserSYN sUserSYN = new SUserSYN();
                    //判断用户id是否为空，不为空继续，为空跳过进行下一个循环
                    if (jsonArray.getJSONObject(i).get("id") != null) {
                        sUserSYN.setBusinessId(String.valueOf(jsonArray.getJSONObject(i).get("id")));
                        sUserSYN.setDeptId(String.valueOf(jsonArray.getJSONObject(i).get("d_id")));
                        sUserSYN.setName(String.valueOf(jsonArray.getJSONObject(i).get("name")));
                        sUserSYN.setRoleId(String.valueOf(jsonArray.getJSONObject(i).get("roles")));
                        sUserSYNS.add(sUserSYN);
                    } else {
                        continue;
                    }
                }
            }
        } catch (Exception e) {

        } finally {
            try {
                // 释放资源
                if (httpClient != null) {
                    httpClient.close();
                }
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return sUserSYNS;
    }

}
