package org.rcisoft.business.userwarning.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.userwarning.entity.UserWarning;
import org.rcisoft.business.userwarning.service.UserWarningService;

import java.util.List;

/**
* Created by cy on 2019-7-30 14:54:13.
*/
@RestController
@RequestMapping("/userwarning")
public class UserWarningController extends CyPaginationController<UserWarning> {

    @Autowired
    private UserWarningService userWarningServiceImpl;


    @ApiOperation(value="添加", notes="添加")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid UserWarning userWarning, BindingResult bindingResult) {
        CyPersistModel data = userWarningServiceImpl.save(userWarning);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        userWarning);
    }
    @ApiOperation(value="逻辑删除", notes="逻辑删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,UserWarning userWarning) {
        userWarning.setBusinessId(businessId);
        CyPersistModel data = userWarningServiceImpl.removeLogical(userWarning);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="删除", notes="删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,UserWarning userWarning) {
        userWarning.setBusinessId(businessId);
        CyPersistModel data = userWarningServiceImpl.remove(userWarning);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="修改", notes="修改")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid UserWarning userWarning, BindingResult bindingResult) {
        userWarning.setBusinessId(businessId);
        CyPersistModel data = userWarningServiceImpl.merge(userWarning);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        userWarning);
    }

    @ApiOperation(value="查询单一", notes="查询单一")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        userWarningServiceImpl.findById(businessId));
    }

    @ApiOperation(value="查询集合", notes="查询集合")
    @GetMapping(value = "/queryUserWarnings")
    public CyResult queryUserWarnings(UserWarning userWarning) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            userWarningServiceImpl.findAll(userWarning));
    }

    @ApiOperation(value="分页查询集合", notes="分页查询集合")
    @GetMapping(value = "/queryUserWarningByPagination")
    public CyGridModel listByPagination(UserWarning userWarning) {
        userWarningServiceImpl.findAllByPagination(getPaginationUtility(), userWarning);
        return getGridModelResponse();
    }

    @ApiOperation(value="查询未处理的业务员的数量", notes="查询未处理的业务员的数量")
    @GetMapping(value = "/queryNumbersOfWarningUsers")
    public CyResult queryNumbersOfWarningUsers(UserWarning userWarning) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                userWarningServiceImpl.queryUserWarningNumbers(userWarning));

    }

    @ApiOperation(value="查询警告中的未处理的业务员", notes="查询警告中的未处理的业务员")
    @GetMapping(value = "/queryUserWarningsMoreThanDate")
    public List<UserWarning> queryUserWarningsMoreThanDate (UserWarning userWarning) {
        userWarning.setNormal();
        return userWarningServiceImpl.queryUserWarningsMoreThanDate(userWarning);
    }
}
