package org.rcisoft.business.userwarning.service.impl;

import org.rcisoft.business.jzmessage.common.TypeEnum;
import org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.userwarning.dao.UserWarningRepository;
import org.rcisoft.business.userwarning.entity.UserWarning;
import org.rcisoft.business.userwarning.service.UserWarningService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2019-7-30 14:54:13.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class UserWarningServiceImpl extends CyBaseService  implements UserWarningService {

    @Autowired
    private UserWarningRepository userWarningRepository;


    /**
    * 保存
    * @param userWarning
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(UserWarning userWarning){
        //增加操作
        CyUserUtil.setCurrentPersistOperation(userWarning);
        int line = userWarningRepository.insertSelective(userWarning);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"新增了ID为"+
userWarning.getBusinessId()+"的信息","新增");
        log.info(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            userWarning.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除
    * @param userWarning
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(UserWarning userWarning){
        int line = userWarningRepository.deleteByPrimaryKey(userWarning.getBusinessId());
        this.dbInfo(CyUserUtil.getAuthenUsername()+"删除了ID为"+
userWarning.getBusinessId()+"的信息","删除");
        log.info(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            userWarning.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }
    /**
    * 逻辑删除
    * @param userWarning
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(UserWarning userWarning){
        CyUserUtil.setCurrentMergeOperation(userWarning);
        userWarning.setDeleted();
        int line = userWarningRepository.logicalDelete(userWarning);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
userWarning.getBusinessId()+"的信息","逻辑删除");
        log.info(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
            userWarning.getBusinessId()+"的信息");

        return new CyPersistModel(line);
    }
    /**
    * 修改
    * @param userWarning
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(UserWarning userWarning){
        CyUserUtil.setCurrentMergeOperation(userWarning);
        int line = userWarningRepository.updateByPrimaryKeySelective(userWarning);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"修改了ID为"+
userWarning.getBusinessId()+"的信息","修改");
        log.info(CyUserUtil.getAuthenUsername()+"修改了ID为"+
            userWarning.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询
    * @param id
    * @return
    */
    @Override
    public UserWarning findById(String id){
        return userWarningRepository.selectByPrimaryKey(id);
    }

    /**
    * 分页查询
    * @param userWarning
    * @return
    */
    @Override
    public List<UserWarning> findAllByPagination(CyPageUtil<UserWarning> paginationUtility,
        UserWarning userWarning){
        userWarning.setNormal();
        userWarning.setUserId(CyUserUtil.getAuthenBusinessId());
        List<UserWarning> userWarningList = userWarningRepository.queryUserWarnings(userWarning);
        //解析业务线名称
        for (UserWarning warning : userWarningList) {
            for (String ywx : SDictionaryServiceImpl.optimizeJzYwx.keySet()) {
                if (ywx.equals(warning.getBusinessLine())){
                    warning.setYwxName(SDictionaryServiceImpl.optimizeJzYwx.get(ywx));
                }
            }
        }
        for(int i = 0; i < userWarningList.size(); i++){
            if("0".equals(userWarningList.get(i).getJzType())){
                //代缴，解析代缴yys
                userWarningList.get(i).setTypeName(TypeEnum.DJ.getname());
                for (Map.Entry<String, String> m :SDictionaryServiceImpl.jzDjYys.entrySet())  {
                    if (m.getValue().equals(userWarningList.get(i).getJzYys())) {
                        userWarningList.get(i).setJzYys(m.getKey());
                    }
                }
            } else if ("1".equals(userWarningList.get(i).getJzType())) {
                userWarningList.get(i).setTypeName(TypeEnum.YD.getname());
                for (Map.Entry<String, String> m :SDictionaryServiceImpl.jzYdYys.entrySet())  {
                    if (m.getValue().equals(userWarningList.get(i).getJzYys())) {
                        userWarningList.get(i).setJzYys(m.getKey());
                    }
                }
            } else if ("2".equals(userWarningList.get(i).getJzType())) {
                userWarningList.get(i).setTypeName(TypeEnum.TT.getname());
                for (Map.Entry<String, String> m :SDictionaryServiceImpl.jzTtYys.entrySet())  {
                    if (m.getValue().equals(userWarningList.get(i).getJzYys())) {
                        userWarningList.get(i).setJzYys(m.getKey());
                    }
                }
            }
            for (Map.Entry<String, String> m :SDictionaryServiceImpl.jzQy.entrySet())  {
                log.debug(m.toString());
                if (m.getValue().equals(userWarningList.get(i).getJzQy())) {
                    userWarningList.get(i).setJzQy(m.getKey());
                }
            }
            for (Map.Entry<String, String> m :SDictionaryServiceImpl.salesman.entrySet())  {
                if (m.getValue().equals(userWarningList.get(i).getJzQy())) {
                    userWarningList.get(i).setJzQy(m.getKey());
                }
            }
        }
        return userWarningList;
    }
    /**
    * 查询list
    * @param userWarning
    * @return
    */
    @Override
    public List<UserWarning> findAll(UserWarning userWarning){
        userWarning.setNormal();
        return userWarningRepository.queryUserWarnings(userWarning);
    }
    /**
     * 查询未处理的业务员的数量
     * @param userWarning
     * @return
     */
    @Override
    public int queryUserWarningNumbers(UserWarning userWarning) {
        userWarning.setNormal();
        userWarning.setUserId(CyUserUtil.getAuthenBusinessId());
        return userWarningRepository.queryUserWarningNumbers(userWarning);
    }

    /**
     * 查询警告中的未处理的业务员
     * @param userWarning
     * @return
     */
    @Override
    public List<UserWarning> queryUserWarningsMoreThanDate (UserWarning userWarning) {
        userWarning.setNormal();
        return userWarningRepository.queryUserWarningsMoreThanDate(userWarning);
    }

    /**
     * 处理预警
     * @param userWarning
     * @return
     */
    @Override
    public int dealWarning(UserWarning userWarning) {
        userWarning.setNormal();
        return userWarningRepository.updateWarning(userWarning);
    }

    /**
     * 处理预警
     * @param userWarning
     * @return
     */
    @Override
    public int dealAllWarning(UserWarning userWarning) {
        userWarning.setNormal();
        return userWarningRepository.updateAllWarning(userWarning);
    }
}

