package org.rcisoft.business.xgjzmessage.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.xgjzmessage.entity.XgJzMessage;
import org.rcisoft.business.xgjzmessage.service.XgJzMessageService;

import java.util.List;

/**
* Created by lpy on 2019-7-26 15:45:51.
*/
@RestController
@RequestMapping("/xgjzmessage")
public class XgJzMessageController extends CyPaginationController<XgJzMessage> {

    @Autowired
    private XgJzMessageService xgJzMessageServiceImpl;


    @ApiOperation(value="添加基站信息修改表", notes="添加基站信息修改表")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid XgJzMessage xgJzMessage, BindingResult bindingResult) {
        CyPersistModel data = xgJzMessageServiceImpl.save(xgJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        xgJzMessage);
    }
    @ApiOperation(value="逻辑删除基站信息修改表", notes="逻辑删除基站信息修改表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,XgJzMessage xgJzMessage) {
        xgJzMessage.setBusinessId(businessId);
        CyPersistModel data = xgJzMessageServiceImpl.removeLogical(xgJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="删除基站信息修改表", notes="删除基站信息修改表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,XgJzMessage xgJzMessage) {
        xgJzMessage.setBusinessId(businessId);
        CyPersistModel data = xgJzMessageServiceImpl.remove(xgJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="修改基站信息修改表", notes="修改基站信息修改表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid XgJzMessage xgJzMessage, BindingResult bindingResult) {
        xgJzMessage.setBusinessId(businessId);
        CyPersistModel data = xgJzMessageServiceImpl.merge(xgJzMessage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        xgJzMessage);
    }

    @ApiOperation(value="查询单一基站信息修改表", notes="查询单一基站信息修改表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        xgJzMessageServiceImpl.findById(businessId));
    }

    @ApiOperation(value="查询基站信息修改表集合", notes="查询基站信息修改表集合")
    @GetMapping(value = "/queryXgJzMessages")
    public CyResult queryXgJzMessages(XgJzMessage xgJzMessage) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            xgJzMessageServiceImpl.findAll(xgJzMessage));
    }

    @ApiOperation(value="分页查询基站信息修改表集合", notes="分页查询基站信息修改表集合")
    @GetMapping(value = "/queryXgJzMessageByPagination")
    public CyGridModel listByPagination(XgJzMessage xgJzMessage) {
        xgJzMessageServiceImpl.findAllByPagination(getPaginationUtility(), xgJzMessage);
        return getGridModelResponse();
    }
}
