package org.rcisoft.business.xgjzmessage.service.impl;

import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.xgjzmessage.dao.XgJzMessageRepository;
import org.rcisoft.business.xgjzmessage.entity.XgJzMessage;
import org.rcisoft.business.xgjzmessage.service.XgJzMessageService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by lpy on 2019-7-26 15:45:51.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class XgJzMessageServiceImpl extends CyBaseService  implements XgJzMessageService {

    @Autowired
    private XgJzMessageRepository xgJzMessageRepository;


    /**
    * 保存 基站信息修改表
    * @param xgJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(XgJzMessage xgJzMessage){
        //增加操作
        CyUserUtil.setCurrentPersistOperation(xgJzMessage);
        int line = xgJzMessageRepository.insertSelective(xgJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"新增了ID为"+
xgJzMessage.getBusinessId()+"的基站信息修改表信息","新增基站信息修改表");
        log.info(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            xgJzMessage.getBusinessId()+"的基站信息修改表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 基站信息修改表
    * @param xgJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(XgJzMessage xgJzMessage){
        int line = xgJzMessageRepository.deleteByPrimaryKey(xgJzMessage.getBusinessId());
        this.dbInfo(CyUserUtil.getAuthenUsername()+"删除了ID为"+
xgJzMessage.getBusinessId()+"的基站信息修改表信息","删除基站信息修改表");
        log.info(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            xgJzMessage.getBusinessId()+"的基站信息修改表信息");
        return new CyPersistModel(line);
    }
    /**
    * 逻辑删除 基站信息修改表
    * @param xgJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(XgJzMessage xgJzMessage){
        CyUserUtil.setCurrentMergeOperation(xgJzMessage);
        xgJzMessage.setDeleted();
        int line = xgJzMessageRepository.logicalDelete(xgJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
xgJzMessage.getBusinessId()+"的基站信息修改表信息","逻辑删除基站信息修改表");
        log.info(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
            xgJzMessage.getBusinessId()+"的基站信息修改表信息");

        return new CyPersistModel(line);
    }
    /**
    * 修改 基站信息修改表
    * @param xgJzMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(XgJzMessage xgJzMessage){
        CyUserUtil.setCurrentMergeOperation(xgJzMessage);
        int line = xgJzMessageRepository.updateByPrimaryKeySelective(xgJzMessage);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"修改了ID为"+
xgJzMessage.getBusinessId()+"的基站信息修改表信息","修改基站信息修改表");
        log.info(CyUserUtil.getAuthenUsername()+"修改了ID为"+
            xgJzMessage.getBusinessId()+"的基站信息修改表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 基站信息修改表
    * @param id
    * @return
    */
    @Override
    public XgJzMessage findById(String id){
        return xgJzMessageRepository.selectByPrimaryKey(id);
    }

    /*
    * 分页查询 基站信息修改表
    * @param xgJzMessage
    * @return
    */
    @Override
    public List<XgJzMessage> findAllByPagination(CyPageUtil<XgJzMessage> paginationUtility,
        XgJzMessage xgJzMessage){
        xgJzMessage.setNormal();
        return xgJzMessageRepository.queryXgJzMessages(xgJzMessage);
    }
    /**
    * 查询list 基站信息修改表
    * @param xgJzMessage
    * @return
    */
    @Override
    public List<XgJzMessage> findAll(XgJzMessage xgJzMessage){
        xgJzMessage.setNormal();
        return xgJzMessageRepository.queryXgJzMessages(xgJzMessage);
    }

}
