package org.rcisoft.common;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import lombok.extern.slf4j.Slf4j;
import org.activiti.constants.CyWfConstants;
import org.activiti.engine.HistoryService;
import org.activiti.engine.RuntimeService;
import org.activiti.engine.TaskService;
import org.activiti.engine.delegate.DelegateExecution;
import org.activiti.engine.delegate.ExecutionListener;
import org.activiti.engine.history.HistoricVariableInstance;
import org.activiti.service.CyWfService;
import org.activiti.service.impl.CyWfServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.hijzmessage.dao.HiJzMessageRepository;
import org.rcisoft.business.hijzmessage.entity.HiJzMessage;
import org.rcisoft.business.hijzmessage.service.HiJzMessageService;
import org.rcisoft.business.jzmessage.common.StartProcessHelper;
import org.rcisoft.business.jzmessage.dao.JzMessageRepository;
import org.rcisoft.business.jzmessage.entity.JzMessage;
import org.rcisoft.business.jzmessage.util.ChangeUtil;
import org.rcisoft.business.jzmessage.util.CommonMethod;
import org.rcisoft.business.processDesign.dao.ProcessMidRepository;
import org.rcisoft.business.processDesign.dao.WorkflowTaskDataRepository;
import org.rcisoft.business.processDesign.dao.WorkflowTaskDateMesRepository;
import org.rcisoft.business.processDesign.entity.ProcessMid;
import org.rcisoft.business.processDesign.entity.WorkflowTaskData;
import org.rcisoft.business.processDesign.entity.WorkflowTaskDateMes;
import org.rcisoft.business.sdictionary.service.impl.SDictionaryServiceImpl;
import org.rcisoft.business.suser.dao.SUserRepository;
import org.rcisoft.business.suser.entity.SUser;
import org.rcisoft.business.suser.service.SUserService;
import org.rcisoft.business.userwarning.entity.UserWarning;
import org.rcisoft.business.userwarning.service.UserWarningService;
import org.rcisoft.business.xgjzmessage.dao.XgJzMessageRepository;
import org.rcisoft.business.xgjzmessage.entity.XgJzMessage;
import org.rcisoft.core.component.CyApplicationContextHolder;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import static org.rcisoft.business.jzmessage.util.CommonMethod.jsonToData;

@Slf4j
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
public class ProcessStatusListener implements ExecutionListener {
    private static final String YES = "0";
    private static final String NO = "1";
    private static final String JZVERSION = "jzVersion";
    JzMessageRepository jzMessageRepository;//基站信息
    WorkflowTaskDateMesRepository workflowTaskDateMesRepository;
    HiJzMessageService hiJzMessageServiceImpl; //历史
    HiJzMessageRepository hiJzMessageRepository;
    HistoryService historyService;//activiti历史服务
    RuntimeService runtimeService;//运行时服务
    TaskService taskService;//任务时服务
    SUserService sUserServiceImpl;
    CyWfService cyWfServiceImpl;
    ProcessMidRepository processMidRepository;
    UserWarningService userWarningServiceImpl;
    ProcessMidRepository midRepository;
    XgJzMessageRepository xgJzMessageRepository;
    WorkflowTaskDataRepository workflowTaskDataRepository;
    StartProcessHelper helper;
    SDictionaryServiceImpl sDictionaryServiceImpl;
    SUserRepository sUserRepository;

    @Override
    @Transactional(propagation = Propagation.SUPPORTS, isolation = Isolation.DEFAULT)
    public void notify(DelegateExecution delegateExecution) throws Exception {
        //注入类
        workflowTaskDateMesRepository = CyApplicationContextHolder.getBean(WorkflowTaskDateMesRepository.class);
        jzMessageRepository = CyApplicationContextHolder.getBean(JzMessageRepository.class);
        hiJzMessageRepository = CyApplicationContextHolder.getBean(HiJzMessageRepository.class);
        hiJzMessageServiceImpl = CyApplicationContextHolder.getBean(HiJzMessageService.class);
        historyService = CyApplicationContextHolder.getBean(HistoryService.class);
        runtimeService = CyApplicationContextHolder.getBean(RuntimeService.class);
        taskService = CyApplicationContextHolder.getBean(TaskService.class);
        processMidRepository = CyApplicationContextHolder.getBean(ProcessMidRepository.class);
        sUserServiceImpl = CyApplicationContextHolder.getBean(SUserService.class);
        userWarningServiceImpl = CyApplicationContextHolder.getBean(UserWarningService.class);
        cyWfServiceImpl = CyApplicationContextHolder.getBean(CyWfServiceImpl.class);
        midRepository = CyApplicationContextHolder.getBean(ProcessMidRepository.class);
        xgJzMessageRepository = CyApplicationContextHolder.getBean(XgJzMessageRepository.class);
        workflowTaskDataRepository = CyApplicationContextHolder.getBean(WorkflowTaskDataRepository.class);
        helper = CyApplicationContextHolder.getBean(StartProcessHelper.class);
        sDictionaryServiceImpl = CyApplicationContextHolder.getBean(SDictionaryServiceImpl.class);
        sUserRepository = CyApplicationContextHolder.getBean(SUserRepository.class);
        String processId = delegateExecution.getProcessInstanceId();//获取流程id
        String uid = CyUserUtil.getAuthenBusinessId();
        List<SUser> sUsers = sUserServiceImpl.getMaintainPersonList();
        List<String> businessIds = new ArrayList<>();
        for (SUser sUser : sUsers) {
            businessIds.add(sUser.getBusinessId());
        }
        log.debug("流程id：" + processId);
        //根据流程id查询流程信息数据
        WorkflowTaskDateMes taskDateMes = workflowTaskDateMesRepository.getMessDataHiByProcessId(processId);
        log.debug("静态资源：" + taskDateMes.getRegionStr());
        String bussinessId = delegateExecution.getProcessBusinessKey();//业务主键
        log.info("业务主键：" + bussinessId);
        JzMessage jzMessage = jzMessageRepository.selectByPrimaryKey(bussinessId);//通过业务主键查询当前基站信息
        //查询流程变量，然后取值
        String select = null;
        String curUser = jzMessage.getJzCurUser();//获取阶段负责人
        List<HistoricVariableInstance> historicVariableInstances = historyService.createHistoricVariableInstanceQuery().processInstanceId(processId).list();
        for (HistoricVariableInstance variableInstance : historicVariableInstances) {
            //流程变量取值 点击更换
            if (variableInstance.getVariableName().equals(StartProcessHelper.CHOOSE)) {
                if (variableInstance.getValue().toString() != null) {
                    select = variableInstance.getValue().toString();
                }
            }
            //获取点击信息
            if (variableInstance.getVariableName().equals(CyWfConstants.PROCESS_TASK_TRANSITION)) {
                jzMessage.setTransition(variableInstance.getValue().toString());
            }
        }
        //设置typeTemplate
        for (ProcessMapBpmn value : ProcessMapBpmn.values()) {
            if (value.getCode().equals(select)) {
                jzMessage.setTypeTemplate(value.getTypeTemplate());
            }
        }
        log.debug("点击信息：" + jzMessage.getTransition());
        //静态资源赋值
        if (org.apache.commons.lang3.StringUtils.isNotEmpty(taskDateMes.getRegionStr())) {
            jzMessage.setFlowJsonStr(taskDateMes.getRegionStr());
        }
        //动态资源赋值
        if (org.apache.commons.lang3.StringUtils.isNotEmpty(taskDateMes.getJsonStr())) {
            jzMessage.setJsonStrs(taskDateMes.getJsonStr());
        }
        jzMessage.setSelect(select);//选择基站信息
        //如果项目编号不为空，就设置isImport为0 可导入
        if (StringUtils.isNotEmpty(jzMessage.getProjectCode())){
            jzMessage.setIsImport(0);
            jzMessage.setProjectCodeImport(0);
        }
        log.debug("当前静态资源：" + jzMessage.getFlowJsonStr());
        jzMessage.setProcessId(processId);//设置流程id
        //根据全局流程变量，设置流程状态
        for (ProcessMapBpmn mapBpmn : ProcessMapBpmn.values()) {
            //如果流程变量等于流程code则做相应的状态改变
            if (mapBpmn.getCode().equals(select)) {
                //修改基站信息
                if (select.equals(ProcessMapBpmn.BS_MODIFY_INFO.getCode())) {
                    //更新workflow_task_data数据
                    updateWorkflowData(jzMessage);
                    //调用修改基站信息方法
                    jzMessage = updateJzmessage(jzMessage);
                    if (!jzMessage.getJzCurUser().equals(curUser)) {
                        helper.clearWaring(jzMessage);//更新预警时间和状态
                        helper.clearUserWaring(jzMessage);
                    }
                    jzMessage.setJzWaitReason(RegionEnum.UPDATEBSINFO.getKey());//设置修改基站信息原因
                }
                //更换业务员
                else if (select.equals(ProcessMapBpmn.BS_CHANGE_SALEMANS.getCode())) {
                    //更换业务员
                    jzMessage.setFlowJsonStr(taskDateMes.getRegionStr());
                    jzMessage = jsonToData(jzMessage);
                    //修改预警状态
                    helper.clearWaring(jzMessage);//更新预警时间和状态
                    UserWarning userWarning = new UserWarning();
                    userWarning.setJzId(bussinessId);
                    userWarning.setJzStatus(jzMessage.getJzState());
                    userWarningServiceImpl.dealWarning(userWarning);
                }
                //需求取消
                else if (select.equals(ProcessMapBpmn.BS_NEED_CANCLE.getCode())) {
                    helper.clearWaring(jzMessage);//更新预警时间和状态
                    UserWarning userWarning = new UserWarning();
                    userWarning.setJzId(bussinessId);
                    userWarningServiceImpl.dealAllWarning(userWarning);
                    //需求取消流程
                    deletProcess(jzMessage, processId);
                    jzMessage.setJzState(BaseStationStatus.BS_HAVE_CANCLE.getCode());
                }
                //当前流程状态为维护部拆站
                else if (select.equals(ProcessMapBpmn.BS_MAINTANCE_DOWN.getCode())) {
                    //维护部拆站
                    deletProcess(jzMessage, processId);
                    jzMessage.setJzState(BaseStationStatus.BS_HAVE_STANDOWN.getCode());
                    helper.clearWaring(jzMessage);//更新预警时间和状态
                    UserWarning userWarning = new UserWarning();
                    userWarning.setJzId(bussinessId);
                    userWarningServiceImpl.dealAllWarning(userWarning);
                    /* jzMessage.setJzWaitReason(RegionEnum.MAINTAINSTANDDOWN.getKey());*/
                } else if (select.equals(ProcessMapBpmn.BS_MAINTANCE_CHANGE.getCode())) {
                    //维护部修改
                    //更新workflow_task_data数据
                    updateWorkflowData(jzMessage);
                    //调用修改基站信息方法
                    jzMessage = updateJzmessage(jzMessage);
                    //设置修改基站信息原因为维护部修改
                    jzMessage.setJzWaitReason(RegionEnum.MAINTAINUPDATEBSINFO.getKey());

                }
                //移动会审
                else if (ProcessMapBpmn.MC_JOINT_HEARING.getCode().equals(select)) {
                    jzMessage = CommonMethod.jsonToData(jzMessage);
                    jzMessage.setJzState(mapBpmn.getStatus());//获取基站状态
                    jzMessage.setIsImport(0);
                    jzMessage.setProjectCodeImport(0);

                }
                //铁塔立项
                else if (ProcessMapBpmn.IT_PROJECT_APPROVAL.getCode().equals(select)) {
                    jzMessage = CommonMethod.jsonToData(jzMessage);
                    jzMessage.setJzState(mapBpmn.getStatus());//设置基站状态
                    jzMessage.setIsImport(0);
                    jzMessage.setProjectCodeImport(0);
                }
                //拆站
                else if (ProcessMapBpmn.BS_STAND_DOWN.getCode().equals(select)) {
                    helper.clearWaring(jzMessage);
                    UserWarning userWarning = new UserWarning();
                    userWarning.setJzId(bussinessId);
                    userWarningServiceImpl.dealAllWarning(userWarning);
                    jzMessage.setJzState(mapBpmn.getStatus());//设置基站状态
                    /* jzMessage.setJzWaitReason(RegionEnum.STANDDOWN.getKey());*/
                }
                //移动交维
                else if (ProcessMapBpmn.MC_DELIVER_MAINTEANCE.getCode().equals(select)) {
                    jzMessage = matingProcess(jzMessage);
                    jzMessage.setJzState(mapBpmn.getStatus());

                }
                //铁塔交维
                else if (ProcessMapBpmn.IT_DELIVER_MAINTEANCE.getCode().equals(select)) {
                    //获取当前分公司下维护部门所有角色
                    jzMessage = matingProcess(jzMessage);
                    jzMessage.setJzState(mapBpmn.getStatus());
                } else {
                    //当静态资源字段不为空时，先解析静态字段，然后设置流程状态
                    if (org.apache.commons.lang3.StringUtils.isNotEmpty(jzMessage.getFlowJsonStr())) {
                        JzMessage jsonMessage = CommonMethod.jsonToData(jzMessage);
                        if (null != jsonMessage) {
                            jzMessage.setJzState(mapBpmn.getStatus());
                        } else {
                            //静态资源字段为空
                            jzMessage.setJzState(mapBpmn.getStatus());
                        }
                    } else {
                        //静态资源字段为空
                        if (StartProcessHelper.xzSpecialProcess().contains(jzMessage.getSelect())) {
                            //为选址时，更新预警时间和状态，清空预警
                            jzMessage.setJzJdDate(new Date());
                            jzMessage.setJzJdWaring("0");
                            helper.clearUserWaring(jzMessage);
                        }
                        jzMessage.setJzState(mapBpmn.getStatus());
                    }
                }

            }
        }
        if (StartProcessHelper.getSpecialProcess().contains(jzMessage.getSelect())) {
            //基站警告状态设为0
            jzMessage.setJzJdWaring("0");
            //更新进度日期为当前日期
            jzMessage.setJzJdDate(new Date());
        }
        //更新数据信息
        jzMessageRepository.updateByPrimaryKeySelective(jzMessage);
        //  jzMessageRepository.updateJzMessage(jzMessage);
        //读取资源数据表不为空,插入到历史表中，同时更新 路径字段名称
        if (org.apache.commons.lang3.StringUtils.isNotEmpty(jzMessage.getFlowJsonStr())) {
            JzMessage queryJzMes = jzMessageRepository.selectByPrimaryKey(jzMessage.getBusinessId());//查询更新后的数据
            log.debug("查询主键:" + queryJzMes.getBusinessId());
            HiJzMessage insertHiJzMes = ChangeUtil.jzMessageToHistory(queryJzMes);
            insertHiJzMes.setJzWaitReason(jzMessage.getJzWaitReason());
            insertHiJzMes.setJzProState("0");
            log.debug("主键：" + jzMessage.getBusinessId());
            /**
             * 添加deflag和flag
             */
            insertHiJzMes.setNormal();
            Map hiJzMessage = hiJzMessageRepository.getMaxVersionByJzId(insertHiJzMes);//查询历史表数据
            log.debug("ss");
            if (hiJzMessage != null && hiJzMessage.containsKey(JZVERSION)) {
                insertHiJzMes.setJzVersion(Integer.parseInt(hiJzMessage.get(JZVERSION).toString()) + 1);
            } else {
                insertHiJzMes.setJzVersion(1);
            }
            //插入到历史表中
            hiJzMessageServiceImpl.save(insertHiJzMes);
        }

    }

    //删除流程 需求取消
    private void deletProcess(JzMessage jzMessage, String processId) {
        List<ProcessMid> ProcessMidList = processMidRepository.quryRunningProcess(jzMessage);
        if (!CollectionUtils.isEmpty(ProcessMidList)) {
            for (ProcessMid item : ProcessMidList) {
                if (!item.getProcessid().equals(processId)) {
                    if (Integer.valueOf(jzMessage.getJzState()) > 12) {
                        //进行拆站操作
                        cyWfServiceImpl.deleteProcessInstance(item.getProcessid(), RegionEnum.STANDDOWN.getReason());
                    } else {
                        //需求取消
                        cyWfServiceImpl.deleteProcessInstance(item.getProcessid(), RegionEnum.CANCLE.getReason());
                    }
                }
            }
        }
    }

    //修改基站信息
    private JzMessage updateJzmessage(JzMessage jzMessage) {
      /*  //查询需要修改基站信息的流程id
        ProcessMid processMid =  midRepository.queryCurProExist(jzMessage);
        String processid = processMid.getProcessid();*/
        //通过流程id查询workflow_task_date_mes表，获取数据
        WorkflowTaskDateMes workflowTaskDateMes = workflowTaskDateMesRepository.getMessDataHiByProcessId(jzMessage.getProcessId());
        jzMessage.setFlowJsonStr(workflowTaskDateMes.getRegionStr());
        JzMessage xgIDjzMessage = jsonToData(jzMessage);//获取修改id
        /**
         * 根据修改id查询
         */
        XgJzMessage xgJzMessage = xgJzMessageRepository.selectByPrimaryKey(xgIDjzMessage.getJzXgid());
        JzMessage tempJzmessage = ChangeUtil.XgJzMessageToJzMessage(xgJzMessage);
        tempJzmessage.setBusinessId(jzMessage.getBusinessId());
        tempJzmessage.setFlowJsonStr(jzMessage.getFlowJsonStr());
        //如果修改了运营商，需求号置空
        if(StringUtils.isEmpty(tempJzmessage.getJzRequire())){
            jzMessageRepository.updateJzRequire(tempJzmessage);
        }
        return tempJzmessage;
    }


    /**
     * 根据流程id 对workflow_task_data表进行更新
     *
     * @param jzMessage
     */
    private void updateWorkflowData(JzMessage jzMessage) {
        //存入WorkflowTaskData表中
        List<WorkflowTaskData> data = new ArrayList<>();
        if (!org.apache.commons.lang.StringUtils.isEmpty(jzMessage.getJsonStrs())) {
            try {
                JSONArray jsonArray = JSONArray.parseArray(jzMessage.getJsonStrs());
                for (int i = 0; i < jsonArray.size(); i++) {
                    for (Map.Entry<String, Object> entry : jsonArray.getJSONObject(i).entrySet()) {
                        Object value = entry.getValue();
                        JSONArray jsonArray1 = (JSONArray) JSON.toJSON(value);
                        for (int j = 0; j < jsonArray1.size(); j++) {
                            for (Map.Entry<String, Object> entry1 : jsonArray1.getJSONObject(j).entrySet()) {
                                WorkflowTaskData workflowTaskData = new WorkflowTaskData();
                                workflowTaskData.setProcessId(entry.getKey());
                                workflowTaskData.setFieldId(entry1.getKey());
                                workflowTaskData.setFieldValue(entry1.getValue().toString());
                                workflowTaskData.setIsFirst("1");
                                data.add(workflowTaskData);
                            }
                        }
                    }
                }

            } catch (Exception e) {
                log.error("解析json error" + e.getMessage());
            }
        }
        //list更新
        if (!CollectionUtils.isEmpty(data))
            workflowTaskDataRepository.updateListByProcessIdFileId(data);
    }

    //交维流程
    public JzMessage matingProcess(JzMessage jzMessage) {
        //获取当前分公司下维护部门所有角色
        SUser sUser = new SUser();
        sUser.setNormal();
        List<SUser> sUsers = sUserServiceImpl.getMaintainPersonList();
        List<String> matingRole = new ArrayList<>();
        //添加数据字典二级维护经理的role_id
        for (String value : sDictionaryServiceImpl.maintManager.values()) {
            matingRole.add(value);
        }
        //获取维护部门人员的businessids
        for (SUser user : sUsers) {
            sUser.setBusinessIds(user.getBusinessIds());
        }
        sUser.setMainRoleList(matingRole);
        List<SUser> mainSuser = sUserRepository.querySecondMaintainUserInfo(sUser);
        if (CollectionUtils.isNotEmpty(mainSuser)) {
            jzMessage.setJzProjectOwner(mainSuser.get(0).getBusinessId());
        }
        jzMessage = CommonMethod.jsonToData(jzMessage);

        return jzMessage;
    }
}
